@@ -1,14 +1,16 @@
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct IXsltProcessor(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IXsltProcessor {
+unsafe impl ::windows::core::Vtable for IXsltProcessor {
     type Vtable = IXsltProcessor_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IXsltProcessor {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x7b64703f_550c_48c6_a90f_93a5b964518f);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IXsltProcessor_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     #[cfg(feature = "Data_Xml_Dom")]
     pub TransformToString: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, inputnode: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Data_Xml_Dom"))]
@@ -17,14 +19,16 @@ pub struct IXsltProcessor_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct IXsltProcessor2(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IXsltProcessor2 {
+unsafe impl ::windows::core::Vtable for IXsltProcessor2 {
     type Vtable = IXsltProcessor2_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IXsltProcessor2 {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x8da45c56_97a5_44cb_a8be_27d86280c70a);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IXsltProcessor2_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     #[cfg(feature = "Data_Xml_Dom")]
     pub TransformToDocument: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, inputnode: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Data_Xml_Dom"))]
@@ -33,14 +37,16 @@ pub struct IXsltProcessor2_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct IXsltProcessorFactory(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IXsltProcessorFactory {
+unsafe impl ::windows::core::Vtable for IXsltProcessorFactory {
     type Vtable = IXsltProcessorFactory_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IXsltProcessorFactory {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x274146c0_9a51_4663_bf30_0ef742146f20);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IXsltProcessorFactory_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     #[cfg(feature = "Data_Xml_Dom")]
     pub CreateInstance: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, document: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Data_Xml_Dom"))]
@@ -60,7 +66,7 @@ impl XsltProcessor {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).TransformToString)(::windows::core::Interface::as_raw(this), inputnode.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).TransformToString)(::windows::core::Vtable::as_raw(this), inputnode.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
     #[doc = "*Required features: `\"Data_Xml_Dom\"`*"]
@@ -73,18 +79,15 @@ impl XsltProcessor {
         let this = &::windows::core::Interface::cast::<IXsltProcessor2>(self)?;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).TransformToDocument)(::windows::core::Interface::as_raw(this), inputnode.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<super::Dom::XmlDocument>(result__)
+            (::windows::core::Vtable::vtable(this).TransformToDocument)(::windows::core::Vtable::as_raw(this), inputnode.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<super::Dom::XmlDocument>(result__)
         }
     }
     #[doc = "*Required features: `\"Data_Xml_Dom\"`*"]
     #[cfg(feature = "Data_Xml_Dom")]
-    pub fn CreateInstance<'a, P0>(document: P0) -> ::windows::core::Result<XsltProcessor>
-    where
-        P0: ::std::convert::Into<::windows::core::InParam<'a, super::Dom::XmlDocument>>,
-    {
+    pub fn CreateInstance(document: &super::Dom::XmlDocument) -> ::windows::core::Result<XsltProcessor> {
         Self::IXsltProcessorFactory(|this| unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).CreateInstance)(::windows::core::Interface::as_raw(this), document.into().abi(), result__.as_mut_ptr()).from_abi::<XsltProcessor>(result__)
+            (::windows::core::Vtable::vtable(this).CreateInstance)(::windows::core::Vtable::as_raw(this), ::core::mem::transmute_copy(document), result__.as_mut_ptr()).from_abi::<XsltProcessor>(result__)
         })
     }
     #[doc(hidden)]
@@ -116,43 +119,16 @@ unsafe impl ::windows::core::RuntimeType for XsltProcessor {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for XsltProcessor {
+unsafe impl ::windows::core::Vtable for XsltProcessor {
     type Vtable = IXsltProcessor_Vtbl;
+}
+unsafe impl ::windows::core::Interface for XsltProcessor {
     const IID: ::windows::core::GUID = <IXsltProcessor as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for XsltProcessor {
     const NAME: &'static str = "Windows.Data.Xml.Xsl.XsltProcessor";
 }
-impl ::core::convert::From<XsltProcessor> for ::windows::core::IUnknown {
-    fn from(value: XsltProcessor) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&XsltProcessor> for ::windows::core::IUnknown {
-    fn from(value: &XsltProcessor) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&XsltProcessor> for &::windows::core::IUnknown {
-    fn from(value: &XsltProcessor) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<XsltProcessor> for ::windows::core::IInspectable {
-    fn from(value: XsltProcessor) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&XsltProcessor> for ::windows::core::IInspectable {
-    fn from(value: &XsltProcessor) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&XsltProcessor> for &::windows::core::IInspectable {
-    fn from(value: &XsltProcessor) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(XsltProcessor, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for XsltProcessor {}
 unsafe impl ::core::marker::Sync for XsltProcessor {}
 #[cfg(feature = "implement")]
