@@ -1,3 +1,25 @@
+#[doc(hidden)]
+#[repr(transparent)]
+pub struct IGameControllerProviderInfoStatics(::windows::core::IUnknown);
+unsafe impl ::windows::core::Vtable for IGameControllerProviderInfoStatics {
+    type Vtable = IGameControllerProviderInfoStatics_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IGameControllerProviderInfoStatics {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x0be1e6c5_d9bd_44ee_8362_488b2e464bfb);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IGameControllerProviderInfoStatics_Vtbl {
+    pub base__: ::windows::core::IInspectable_Vtbl,
+    #[cfg(feature = "Gaming_Input_Custom")]
+    pub GetParentProviderId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, provider: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+    #[cfg(not(feature = "Gaming_Input_Custom"))]
+    GetParentProviderId: usize,
+    #[cfg(feature = "Gaming_Input_Custom")]
+    pub GetProviderId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, provider: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+    #[cfg(not(feature = "Gaming_Input_Custom"))]
+    GetProviderId: usize,
+}
 #[doc = "*Required features: `\"Gaming_Input_Preview\"`*"]
 pub struct GameControllerProviderInfo;
 impl GameControllerProviderInfo {
@@ -10,7 +32,7 @@ impl GameControllerProviderInfo {
     {
         Self::IGameControllerProviderInfoStatics(|this| unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).GetParentProviderId)(::windows::core::Interface::as_raw(this), provider.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).GetParentProviderId)(::windows::core::Vtable::as_raw(this), provider.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         })
     }
     #[doc = "*Required features: `\"Gaming_Input_Custom\"`*"]
@@ -22,7 +44,7 @@ impl GameControllerProviderInfo {
     {
         Self::IGameControllerProviderInfoStatics(|this| unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).GetProviderId)(::windows::core::Interface::as_raw(this), provider.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).GetProviderId)(::windows::core::Vtable::as_raw(this), provider.try_into().map_err(|e| e.into())?.abi(), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         })
     }
     #[doc(hidden)]
@@ -34,25 +56,5 @@ impl GameControllerProviderInfo {
 impl ::windows::core::RuntimeName for GameControllerProviderInfo {
     const NAME: &'static str = "Windows.Gaming.Input.Preview.GameControllerProviderInfo";
 }
-#[doc(hidden)]
-#[repr(transparent)]
-pub struct IGameControllerProviderInfoStatics(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IGameControllerProviderInfoStatics {
-    type Vtable = IGameControllerProviderInfoStatics_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x0be1e6c5_d9bd_44ee_8362_488b2e464bfb);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IGameControllerProviderInfoStatics_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
-    #[cfg(feature = "Gaming_Input_Custom")]
-    pub GetParentProviderId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, provider: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-    #[cfg(not(feature = "Gaming_Input_Custom"))]
-    GetParentProviderId: usize,
-    #[cfg(feature = "Gaming_Input_Custom")]
-    pub GetProviderId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, provider: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-    #[cfg(not(feature = "Gaming_Input_Custom"))]
-    GetProviderId: usize,
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
