@@ -1,14 +1,16 @@
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFont(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for ILanguageFont {
+unsafe impl ::windows::core::Vtable for ILanguageFont {
     type Vtable = ILanguageFont_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILanguageFont {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xb12e5c3a_b76d_459b_beeb_901151cd77d1);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILanguageFont_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     pub FontFamily: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
     #[cfg(feature = "UI_Text")]
     pub FontWeight: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut super::super::UI::Text::FontWeight) -> ::windows::core::HRESULT,
@@ -27,14 +29,16 @@ pub struct ILanguageFont_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFontGroup(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for ILanguageFontGroup {
+unsafe impl ::windows::core::Vtable for ILanguageFontGroup {
     type Vtable = ILanguageFontGroup_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILanguageFontGroup {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xf33a7fc3_3a5c_4aea_b9ff_b39fb242f7f6);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILanguageFontGroup_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     pub UITextFont: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     pub UIHeadingFont: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     pub UITitleFont: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
@@ -50,14 +54,16 @@ pub struct ILanguageFontGroup_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct ILanguageFontGroupFactory(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for ILanguageFontGroupFactory {
+unsafe impl ::windows::core::Vtable for ILanguageFontGroupFactory {
     type Vtable = ILanguageFontGroupFactory_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILanguageFontGroupFactory {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xfcaeac67_4e77_49c7_b856_dde934fc735b);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILanguageFontGroupFactory_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     pub CreateLanguageFontGroup: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, languagetag: ::core::mem::ManuallyDrop<::windows::core::HSTRING>, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
 #[doc = "*Required features: `\"Globalization_Fonts\"`*"]
@@ -68,7 +74,7 @@ impl LanguageFont {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).FontFamily)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).FontFamily)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -77,7 +83,7 @@ impl LanguageFont {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).FontWeight)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontWeight>(result__)
+            (::windows::core::Vtable::vtable(this).FontWeight)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontWeight>(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -86,7 +92,7 @@ impl LanguageFont {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).FontStretch)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStretch>(result__)
+            (::windows::core::Vtable::vtable(this).FontStretch)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStretch>(result__)
         }
     }
     #[doc = "*Required features: `\"UI_Text\"`*"]
@@ -95,14 +101,14 @@ impl LanguageFont {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).FontStyle)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStyle>(result__)
+            (::windows::core::Vtable::vtable(this).FontStyle)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<super::super::UI::Text::FontStyle>(result__)
         }
     }
     pub fn ScaleFactor(&self) -> ::windows::core::Result<f64> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).ScaleFactor)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<f64>(result__)
+            (::windows::core::Vtable::vtable(this).ScaleFactor)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<f64>(result__)
         }
     }
 }
@@ -129,43 +135,16 @@ unsafe impl ::windows::core::RuntimeType for LanguageFont {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for LanguageFont {
+unsafe impl ::windows::core::Vtable for LanguageFont {
     type Vtable = ILanguageFont_Vtbl;
+}
+unsafe impl ::windows::core::Interface for LanguageFont {
     const IID: ::windows::core::GUID = <ILanguageFont as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for LanguageFont {
     const NAME: &'static str = "Windows.Globalization.Fonts.LanguageFont";
 }
-impl ::core::convert::From<LanguageFont> for ::windows::core::IUnknown {
-    fn from(value: LanguageFont) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&LanguageFont> for ::windows::core::IUnknown {
-    fn from(value: &LanguageFont) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&LanguageFont> for &::windows::core::IUnknown {
-    fn from(value: &LanguageFont) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<LanguageFont> for ::windows::core::IInspectable {
-    fn from(value: LanguageFont) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&LanguageFont> for ::windows::core::IInspectable {
-    fn from(value: &LanguageFont) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&LanguageFont> for &::windows::core::IInspectable {
-    fn from(value: &LanguageFont) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(LanguageFont, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for LanguageFont {}
 unsafe impl ::core::marker::Sync for LanguageFont {}
 #[doc = "*Required features: `\"Globalization_Fonts\"`*"]
@@ -176,83 +155,83 @@ impl LanguageFontGroup {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).UITextFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).UITextFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn UIHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).UIHeadingFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).UIHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn UITitleFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).UITitleFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).UITitleFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn UICaptionFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).UICaptionFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).UICaptionFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn UINotificationHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).UINotificationHeadingFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).UINotificationHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn TraditionalDocumentFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).TraditionalDocumentFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).TraditionalDocumentFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn ModernDocumentFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).ModernDocumentFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).ModernDocumentFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn DocumentHeadingFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).DocumentHeadingFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).DocumentHeadingFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn FixedWidthTextFont(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).FixedWidthTextFont)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).FixedWidthTextFont)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn DocumentAlternate1Font(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).DocumentAlternate1Font)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).DocumentAlternate1Font)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn DocumentAlternate2Font(&self) -> ::windows::core::Result<LanguageFont> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).DocumentAlternate2Font)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
+            (::windows::core::Vtable::vtable(this).DocumentAlternate2Font)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<LanguageFont>(result__)
         }
     }
     pub fn CreateLanguageFontGroup(languagetag: &::windows::core::HSTRING) -> ::windows::core::Result<LanguageFontGroup> {
         Self::ILanguageFontGroupFactory(|this| unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).CreateLanguageFontGroup)(::windows::core::Interface::as_raw(this), ::core::mem::transmute_copy(languagetag), result__.as_mut_ptr()).from_abi::<LanguageFontGroup>(result__)
+            (::windows::core::Vtable::vtable(this).CreateLanguageFontGroup)(::windows::core::Vtable::as_raw(this), ::core::mem::transmute_copy(languagetag), result__.as_mut_ptr()).from_abi::<LanguageFontGroup>(result__)
         })
     }
     #[doc(hidden)]
@@ -284,43 +263,16 @@ unsafe impl ::windows::core::RuntimeType for LanguageFontGroup {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for LanguageFontGroup {
+unsafe impl ::windows::core::Vtable for LanguageFontGroup {
     type Vtable = ILanguageFontGroup_Vtbl;
+}
+unsafe impl ::windows::core::Interface for LanguageFontGroup {
     const IID: ::windows::core::GUID = <ILanguageFontGroup as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for LanguageFontGroup {
     const NAME: &'static str = "Windows.Globalization.Fonts.LanguageFontGroup";
 }
-impl ::core::convert::From<LanguageFontGroup> for ::windows::core::IUnknown {
-    fn from(value: LanguageFontGroup) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&LanguageFontGroup> for ::windows::core::IUnknown {
-    fn from(value: &LanguageFontGroup) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&LanguageFontGroup> for &::windows::core::IUnknown {
-    fn from(value: &LanguageFontGroup) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<LanguageFontGroup> for ::windows::core::IInspectable {
-    fn from(value: LanguageFontGroup) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&LanguageFontGroup> for ::windows::core::IInspectable {
-    fn from(value: &LanguageFontGroup) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&LanguageFontGroup> for &::windows::core::IInspectable {
-    fn from(value: &LanguageFontGroup) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(LanguageFontGroup, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for LanguageFontGroup {}
 unsafe impl ::core::marker::Sync for LanguageFontGroup {}
 #[cfg(feature = "implement")]
