@@ -1,14 +1,16 @@
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct IVibrationDevice(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IVibrationDevice {
+unsafe impl ::windows::core::Vtable for IVibrationDevice {
     type Vtable = IVibrationDevice_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IVibrationDevice {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x1b4a6595_cfcd_4e08_92fb_c1906d04498c);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IVibrationDevice_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     #[cfg(feature = "Foundation")]
     pub Vibrate: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, duration: super::super::super::Foundation::TimeSpan) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Foundation"))]
@@ -18,14 +20,16 @@ pub struct IVibrationDevice_Vtbl {
 #[doc(hidden)]
 #[repr(transparent)]
 pub struct IVibrationDeviceStatics(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IVibrationDeviceStatics {
+unsafe impl ::windows::core::Vtable for IVibrationDeviceStatics {
     type Vtable = IVibrationDeviceStatics_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IVibrationDeviceStatics {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x332fd2f1_1c69_4c91_949e_4bb67a85bdc7);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IVibrationDeviceStatics_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     pub GetDefault: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
 #[doc = "*Required features: `\"Phone_Devices_Notification\"`*"]
@@ -36,16 +40,16 @@ impl VibrationDevice {
     #[cfg(feature = "Foundation")]
     pub fn Vibrate(&self, duration: super::super::super::Foundation::TimeSpan) -> ::windows::core::Result<()> {
         let this = self;
-        unsafe { (::windows::core::Interface::vtable(this).Vibrate)(::windows::core::Interface::as_raw(this), duration).ok() }
+        unsafe { (::windows::core::Vtable::vtable(this).Vibrate)(::windows::core::Vtable::as_raw(this), duration).ok() }
     }
     pub fn Cancel(&self) -> ::windows::core::Result<()> {
         let this = self;
-        unsafe { (::windows::core::Interface::vtable(this).Cancel)(::windows::core::Interface::as_raw(this)).ok() }
+        unsafe { (::windows::core::Vtable::vtable(this).Cancel)(::windows::core::Vtable::as_raw(this)).ok() }
     }
     pub fn GetDefault() -> ::windows::core::Result<VibrationDevice> {
         Self::IVibrationDeviceStatics(|this| unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).GetDefault)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<VibrationDevice>(result__)
+            (::windows::core::Vtable::vtable(this).GetDefault)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<VibrationDevice>(result__)
         })
     }
     #[doc(hidden)]
@@ -77,43 +81,16 @@ unsafe impl ::windows::core::RuntimeType for VibrationDevice {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for VibrationDevice {
+unsafe impl ::windows::core::Vtable for VibrationDevice {
     type Vtable = IVibrationDevice_Vtbl;
+}
+unsafe impl ::windows::core::Interface for VibrationDevice {
     const IID: ::windows::core::GUID = <IVibrationDevice as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for VibrationDevice {
     const NAME: &'static str = "Windows.Phone.Devices.Notification.VibrationDevice";
 }
-impl ::core::convert::From<VibrationDevice> for ::windows::core::IUnknown {
-    fn from(value: VibrationDevice) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&VibrationDevice> for ::windows::core::IUnknown {
-    fn from(value: &VibrationDevice) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&VibrationDevice> for &::windows::core::IUnknown {
-    fn from(value: &VibrationDevice) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<VibrationDevice> for ::windows::core::IInspectable {
-    fn from(value: VibrationDevice) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&VibrationDevice> for ::windows::core::IInspectable {
-    fn from(value: &VibrationDevice) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&VibrationDevice> for &::windows::core::IInspectable {
-    fn from(value: &VibrationDevice) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(VibrationDevice, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for VibrationDevice {}
 unsafe impl ::core::marker::Sync for VibrationDevice {}
 #[cfg(feature = "implement")]
