@@ -4,7 +4,7 @@ impl ::windows::core::RuntimeName for IRemoteSystemFilter {
 }
 impl IRemoteSystemFilter_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IRemoteSystemFilter_Impl, const OFFSET: isize>() -> IRemoteSystemFilter_Vtbl {
-        Self { base__: ::windows::core::IInspectableVtbl::new::<Identity, IRemoteSystemFilter, OFFSET>() }
+        Self { base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IRemoteSystemFilter, OFFSET>() }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IRemoteSystemFilter as ::windows::core::Interface>::IID
