@@ -1,5 +1,68 @@
 #[cfg(feature = "UI_UIAutomation_Core")]
 pub mod Core;
+#[doc(hidden)]
+#[repr(transparent)]
+pub struct IAutomationConnection(::windows::core::IUnknown);
+unsafe impl ::windows::core::Vtable for IAutomationConnection {
+    type Vtable = IAutomationConnection_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IAutomationConnection {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xaad262ed_0ef4_5d43_97be_a834e27b65b9);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IAutomationConnection_Vtbl {
+    pub base__: ::windows::core::IInspectable_Vtbl,
+    pub IsRemoteSystem: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut bool) -> ::windows::core::HRESULT,
+    pub AppUserModelId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+    pub ExecutableFileName: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+}
+#[doc(hidden)]
+#[repr(transparent)]
+pub struct IAutomationConnectionBoundObject(::windows::core::IUnknown);
+unsafe impl ::windows::core::Vtable for IAutomationConnectionBoundObject {
+    type Vtable = IAutomationConnectionBoundObject_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IAutomationConnectionBoundObject {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x5e8558fb_ca52_5b65_9830_dd2905816093);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IAutomationConnectionBoundObject_Vtbl {
+    pub base__: ::windows::core::IInspectable_Vtbl,
+    pub Connection: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+}
+#[doc(hidden)]
+#[repr(transparent)]
+pub struct IAutomationElement(::windows::core::IUnknown);
+unsafe impl ::windows::core::Vtable for IAutomationElement {
+    type Vtable = IAutomationElement_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IAutomationElement {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xa1898370_2c07_56fd_993f_61a72a08058c);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IAutomationElement_Vtbl {
+    pub base__: ::windows::core::IInspectable_Vtbl,
+    pub IsRemoteSystem: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut bool) -> ::windows::core::HRESULT,
+    pub AppUserModelId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+    pub ExecutableFileName: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
+}
+#[doc(hidden)]
+#[repr(transparent)]
+pub struct IAutomationTextRange(::windows::core::IUnknown);
+unsafe impl ::windows::core::Vtable for IAutomationTextRange {
+    type Vtable = IAutomationTextRange_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IAutomationTextRange {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x7e101b65_40d3_5994_85a9_0a0cb9a4ec98);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IAutomationTextRange_Vtbl {
+    pub base__: ::windows::core::IInspectable_Vtbl,
+}
 #[doc = "*Required features: `\"UI_UIAutomation\"`*"]
 #[repr(transparent)]
 pub struct AutomationConnection(::windows::core::IUnknown);
@@ -8,21 +71,21 @@ impl AutomationConnection {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).IsRemoteSystem)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<bool>(result__)
+            (::windows::core::Vtable::vtable(this).IsRemoteSystem)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<bool>(result__)
         }
     }
     pub fn AppUserModelId(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).AppUserModelId)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).AppUserModelId)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
     pub fn ExecutableFileName(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).ExecutableFileName)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).ExecutableFileName)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
 }
@@ -49,43 +112,16 @@ unsafe impl ::windows::core::RuntimeType for AutomationConnection {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for AutomationConnection {
+unsafe impl ::windows::core::Vtable for AutomationConnection {
     type Vtable = IAutomationConnection_Vtbl;
+}
+unsafe impl ::windows::core::Interface for AutomationConnection {
     const IID: ::windows::core::GUID = <IAutomationConnection as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for AutomationConnection {
     const NAME: &'static str = "Windows.UI.UIAutomation.AutomationConnection";
 }
-impl ::core::convert::From<AutomationConnection> for ::windows::core::IUnknown {
-    fn from(value: AutomationConnection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationConnection> for ::windows::core::IUnknown {
-    fn from(value: &AutomationConnection) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationConnection> for &::windows::core::IUnknown {
-    fn from(value: &AutomationConnection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<AutomationConnection> for ::windows::core::IInspectable {
-    fn from(value: AutomationConnection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationConnection> for ::windows::core::IInspectable {
-    fn from(value: &AutomationConnection) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationConnection> for &::windows::core::IInspectable {
-    fn from(value: &AutomationConnection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(AutomationConnection, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for AutomationConnection {}
 unsafe impl ::core::marker::Sync for AutomationConnection {}
 #[doc = "*Required features: `\"UI_UIAutomation\"`*"]
@@ -96,7 +132,7 @@ impl AutomationConnectionBoundObject {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).Connection)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<AutomationConnection>(result__)
+            (::windows::core::Vtable::vtable(this).Connection)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<AutomationConnection>(result__)
         }
     }
 }
@@ -123,43 +159,16 @@ unsafe impl ::windows::core::RuntimeType for AutomationConnectionBoundObject {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for AutomationConnectionBoundObject {
+unsafe impl ::windows::core::Vtable for AutomationConnectionBoundObject {
     type Vtable = IAutomationConnectionBoundObject_Vtbl;
+}
+unsafe impl ::windows::core::Interface for AutomationConnectionBoundObject {
     const IID: ::windows::core::GUID = <IAutomationConnectionBoundObject as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for AutomationConnectionBoundObject {
     const NAME: &'static str = "Windows.UI.UIAutomation.AutomationConnectionBoundObject";
 }
-impl ::core::convert::From<AutomationConnectionBoundObject> for ::windows::core::IUnknown {
-    fn from(value: AutomationConnectionBoundObject) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationConnectionBoundObject> for ::windows::core::IUnknown {
-    fn from(value: &AutomationConnectionBoundObject) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationConnectionBoundObject> for &::windows::core::IUnknown {
-    fn from(value: &AutomationConnectionBoundObject) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<AutomationConnectionBoundObject> for ::windows::core::IInspectable {
-    fn from(value: AutomationConnectionBoundObject) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationConnectionBoundObject> for ::windows::core::IInspectable {
-    fn from(value: &AutomationConnectionBoundObject) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationConnectionBoundObject> for &::windows::core::IInspectable {
-    fn from(value: &AutomationConnectionBoundObject) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(AutomationConnectionBoundObject, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for AutomationConnectionBoundObject {}
 unsafe impl ::core::marker::Sync for AutomationConnectionBoundObject {}
 #[doc = "*Required features: `\"UI_UIAutomation\"`*"]
@@ -170,21 +179,21 @@ impl AutomationElement {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).IsRemoteSystem)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<bool>(result__)
+            (::windows::core::Vtable::vtable(this).IsRemoteSystem)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<bool>(result__)
         }
     }
     pub fn AppUserModelId(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).AppUserModelId)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).AppUserModelId)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
     pub fn ExecutableFileName(&self) -> ::windows::core::Result<::windows::core::HSTRING> {
         let this = self;
         unsafe {
             let mut result__ = ::core::mem::MaybeUninit::zeroed();
-            (::windows::core::Interface::vtable(this).ExecutableFileName)(::windows::core::Interface::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
+            (::windows::core::Vtable::vtable(this).ExecutableFileName)(::windows::core::Vtable::as_raw(this), result__.as_mut_ptr()).from_abi::<::windows::core::HSTRING>(result__)
         }
     }
 }
@@ -211,43 +220,16 @@ unsafe impl ::windows::core::RuntimeType for AutomationElement {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for AutomationElement {
+unsafe impl ::windows::core::Vtable for AutomationElement {
     type Vtable = IAutomationElement_Vtbl;
+}
+unsafe impl ::windows::core::Interface for AutomationElement {
     const IID: ::windows::core::GUID = <IAutomationElement as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for AutomationElement {
     const NAME: &'static str = "Windows.UI.UIAutomation.AutomationElement";
 }
-impl ::core::convert::From<AutomationElement> for ::windows::core::IUnknown {
-    fn from(value: AutomationElement) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationElement> for ::windows::core::IUnknown {
-    fn from(value: &AutomationElement) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationElement> for &::windows::core::IUnknown {
-    fn from(value: &AutomationElement) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<AutomationElement> for ::windows::core::IInspectable {
-    fn from(value: AutomationElement) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationElement> for ::windows::core::IInspectable {
-    fn from(value: &AutomationElement) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationElement> for &::windows::core::IInspectable {
-    fn from(value: &AutomationElement) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(AutomationElement, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for AutomationElement {}
 unsafe impl ::core::marker::Sync for AutomationElement {}
 #[doc = "*Required features: `\"UI_UIAutomation\"`*"]
@@ -277,99 +259,17 @@ unsafe impl ::windows::core::RuntimeType for AutomationTextRange {
         from.as_ref().cloned().ok_or(::windows::core::Error::OK)
     }
 }
-unsafe impl ::windows::core::Interface for AutomationTextRange {
+unsafe impl ::windows::core::Vtable for AutomationTextRange {
     type Vtable = IAutomationTextRange_Vtbl;
+}
+unsafe impl ::windows::core::Interface for AutomationTextRange {
     const IID: ::windows::core::GUID = <IAutomationTextRange as ::windows::core::Interface>::IID;
 }
 impl ::windows::core::RuntimeName for AutomationTextRange {
     const NAME: &'static str = "Windows.UI.UIAutomation.AutomationTextRange";
 }
-impl ::core::convert::From<AutomationTextRange> for ::windows::core::IUnknown {
-    fn from(value: AutomationTextRange) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationTextRange> for ::windows::core::IUnknown {
-    fn from(value: &AutomationTextRange) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationTextRange> for &::windows::core::IUnknown {
-    fn from(value: &AutomationTextRange) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<AutomationTextRange> for ::windows::core::IInspectable {
-    fn from(value: AutomationTextRange) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&AutomationTextRange> for ::windows::core::IInspectable {
-    fn from(value: &AutomationTextRange) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<&AutomationTextRange> for &::windows::core::IInspectable {
-    fn from(value: &AutomationTextRange) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
+::windows::core::interface_hierarchy!(AutomationTextRange, ::windows::core::IUnknown, ::windows::core::IInspectable);
 unsafe impl ::core::marker::Send for AutomationTextRange {}
 unsafe impl ::core::marker::Sync for AutomationTextRange {}
-#[doc(hidden)]
-#[repr(transparent)]
-pub struct IAutomationConnection(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IAutomationConnection {
-    type Vtable = IAutomationConnection_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xaad262ed_0ef4_5d43_97be_a834e27b65b9);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IAutomationConnection_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
-    pub IsRemoteSystem: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut bool) -> ::windows::core::HRESULT,
-    pub AppUserModelId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-    pub ExecutableFileName: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-}
-#[doc(hidden)]
-#[repr(transparent)]
-pub struct IAutomationConnectionBoundObject(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IAutomationConnectionBoundObject {
-    type Vtable = IAutomationConnectionBoundObject_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x5e8558fb_ca52_5b65_9830_dd2905816093);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IAutomationConnectionBoundObject_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
-    pub Connection: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-}
-#[doc(hidden)]
-#[repr(transparent)]
-pub struct IAutomationElement(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IAutomationElement {
-    type Vtable = IAutomationElement_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xa1898370_2c07_56fd_993f_61a72a08058c);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IAutomationElement_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
-    pub IsRemoteSystem: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut bool) -> ::windows::core::HRESULT,
-    pub AppUserModelId: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-    pub ExecutableFileName: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result__: *mut ::core::mem::ManuallyDrop<::windows::core::HSTRING>) -> ::windows::core::HRESULT,
-}
-#[doc(hidden)]
-#[repr(transparent)]
-pub struct IAutomationTextRange(::windows::core::IUnknown);
-unsafe impl ::windows::core::Interface for IAutomationTextRange {
-    type Vtable = IAutomationTextRange_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x7e101b65_40d3_5994_85a9_0a0cb9a4ec98);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IAutomationTextRange_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
