@@ -40,7 +40,7 @@ impl IMLOperatorAttributes_Vtbl {
             this.GetStringAttributeElement(::core::mem::transmute(&name), ::core::mem::transmute_copy(&elementindex), ::core::mem::transmute_copy(&attributeelementbytesize), ::core::mem::transmute_copy(&attributeelement)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetAttributeElementCount: GetAttributeElementCount::<Identity, Impl, OFFSET>,
             GetAttribute: GetAttribute::<Identity, Impl, OFFSET>,
             GetStringAttributeElementLength: GetStringAttributeElementLength::<Identity, Impl, OFFSET>,
@@ -62,7 +62,7 @@ impl IMLOperatorKernel_Vtbl {
             let this = (*this).get_impl();
             this.Compute(::core::mem::transmute(&context)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), Compute: Compute::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), Compute: Compute::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IMLOperatorKernel as ::windows::core::Interface>::IID
@@ -128,7 +128,7 @@ impl IMLOperatorKernelContext_Vtbl {
             this.GetExecutionInterface(::core::mem::transmute_copy(&executionobject))
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetInputTensor: GetInputTensor::<Identity, Impl, OFFSET>,
             GetOutputTensor: GetOutputTensor::<Identity, Impl, OFFSET>,
             GetOutputTensor2: GetOutputTensor2::<Identity, Impl, OFFSET>,
@@ -251,7 +251,7 @@ impl IMLOperatorKernelFactory_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), CreateKernel: CreateKernel::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), CreateKernel: CreateKernel::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IMLOperatorKernelFactory as ::windows::core::Interface>::IID
@@ -275,7 +275,7 @@ impl IMLOperatorRegistry_Vtbl {
             this.RegisterOperatorKernel(::core::mem::transmute_copy(&operatorkernel), ::core::mem::transmute(&operatorkernelfactory), ::core::mem::transmute(&shapeinferrer)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             RegisterOperatorSetSchema: RegisterOperatorSetSchema::<Identity, Impl, OFFSET>,
             RegisterOperatorKernel: RegisterOperatorKernel::<Identity, Impl, OFFSET>,
         }
@@ -376,7 +376,7 @@ impl IMLOperatorShapeInferrer_Vtbl {
             let this = (*this).get_impl();
             this.InferOutputShapes(::core::mem::transmute(&context)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), InferOutputShapes: InferOutputShapes::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), InferOutputShapes: InferOutputShapes::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IMLOperatorShapeInferrer as ::windows::core::Interface>::IID
@@ -430,7 +430,7 @@ impl IMLOperatorTensor_Vtbl {
             this.GetDataInterface(::core::mem::transmute_copy(&datainterface))
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetDimensionCount: GetDimensionCount::<Identity, Impl, OFFSET>,
             GetShape: GetShape::<Identity, Impl, OFFSET>,
             GetTensorDataType: GetTensorDataType::<Identity, Impl, OFFSET>,
@@ -492,7 +492,7 @@ impl IMLOperatorTensorShapeDescription_Vtbl {
             this.GetOutputTensorShape(::core::mem::transmute_copy(&outputindex), ::core::mem::transmute_copy(&dimensioncount), ::core::mem::transmute_copy(&dimensions)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetInputTensorDimensionCount: GetInputTensorDimensionCount::<Identity, Impl, OFFSET>,
             GetInputTensorShape: GetInputTensorShape::<Identity, Impl, OFFSET>,
             HasOutputShapeDescription: HasOutputShapeDescription::<Identity, Impl, OFFSET>,
@@ -576,7 +576,7 @@ impl IMLOperatorTypeInferrer_Vtbl {
             let this = (*this).get_impl();
             this.InferOutputTypes(::core::mem::transmute(&context)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), InferOutputTypes: InferOutputTypes::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), InferOutputTypes: InferOutputTypes::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IMLOperatorTypeInferrer as ::windows::core::Interface>::IID
@@ -593,12 +593,12 @@ impl ::windows::core::RuntimeName for IWinMLEvaluationContext {}
 #[cfg(feature = "Win32_Graphics_Direct3D12")]
 impl IWinMLEvaluationContext_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IWinMLEvaluationContext_Impl, const OFFSET: isize>() -> IWinMLEvaluationContext_Vtbl {
-        unsafe extern "system" fn BindValue<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IWinMLEvaluationContext_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pdescriptor: *const WINML_BINDING_DESC) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn BindValue<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IWinMLEvaluationContext_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, pdescriptor: *const ::core::mem::ManuallyDrop<WINML_BINDING_DESC>) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
             this.BindValue(::core::mem::transmute_copy(&pdescriptor)).into()
         }
-        unsafe extern "system" fn GetValueByName<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IWinMLEvaluationContext_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, name: ::windows::core::PCWSTR, pdescriptor: *mut *mut WINML_BINDING_DESC) -> ::windows::core::HRESULT {
+        unsafe extern "system" fn GetValueByName<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IWinMLEvaluationContext_Impl, const OFFSET: isize>(this: *mut ::core::ffi::c_void, name: ::windows::core::PCWSTR, pdescriptor: *mut *mut ::core::mem::ManuallyDrop<WINML_BINDING_DESC>) -> ::windows::core::HRESULT {
             let this = (this as *const *const ()).offset(OFFSET) as *const Identity;
             let this = (*this).get_impl();
             match this.GetValueByName(::core::mem::transmute(&name)) {
@@ -615,7 +615,7 @@ impl IWinMLEvaluationContext_Vtbl {
             this.Clear().into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             BindValue: BindValue::<Identity, Impl, OFFSET>,
             GetValueByName: GetValueByName::<Identity, Impl, OFFSET>,
             Clear: Clear::<Identity, Impl, OFFSET>,
@@ -676,7 +676,7 @@ impl IWinMLModel_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetDescription: GetDescription::<Identity, Impl, OFFSET>,
             EnumerateMetadata: EnumerateMetadata::<Identity, Impl, OFFSET>,
             EnumerateModelInputs: EnumerateModelInputs::<Identity, Impl, OFFSET>,
@@ -726,7 +726,7 @@ impl IWinMLRuntime_Vtbl {
             this.EvaluateModel(::core::mem::transmute(&pcontext)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             LoadModel: LoadModel::<Identity, Impl, OFFSET>,
             CreateEvaluationContext: CreateEvaluationContext::<Identity, Impl, OFFSET>,
             EvaluateModel: EvaluateModel::<Identity, Impl, OFFSET>,
@@ -753,7 +753,7 @@ impl IWinMLRuntimeFactory_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), CreateRuntime: CreateRuntime::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), CreateRuntime: CreateRuntime::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IWinMLRuntimeFactory as ::windows::core::Interface>::IID
