@@ -1,6 +1,6 @@
 pub const GUID_DEVINTERFACE_PWM_CONTROLLER: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x60824b4c_eed1_4c9c_b49c_1b961461a819);
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const GUID_DEVINTERFACE_PWM_CONTROLLER_WSZ: &str = "{60824B4C-EED1-4C9C-B49C-1B961461A819}";
+pub const GUID_DEVINTERFACE_PWM_CONTROLLER_WSZ: ::windows::core::PCWSTR = ::windows::w!("{60824B4C-EED1-4C9C-B49C-1B961461A819}");
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
 pub const IOCTL_PWM_CONTROLLER_GET_ACTUAL_PERIOD: u32 = 262148u32;
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
@@ -21,6 +21,53 @@ pub const IOCTL_PWM_PIN_SET_POLARITY: u32 = 295324u32;
 pub const IOCTL_PWM_PIN_START: u32 = 295331u32;
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
 pub const IOCTL_PWM_PIN_STOP: u32 = 295335u32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_CONTROLLER_GET_ACTUAL_PERIOD: i32 = 1i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_CONTROLLER_GET_INFO: i32 = 0i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_CONTROLLER_SET_DESIRED_PERIOD: i32 = 2i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_GET_ACTIVE_DUTY_CYCLE_PERCENTAGE: i32 = 100i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_GET_POLARITY: i32 = 102i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_IS_STARTED: i32 = 106i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_SET_ACTIVE_DUTY_CYCLE_PERCENTAGE: i32 = 101i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_SET_POLARITY: i32 = 103i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_START: i32 = 104i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_IOCTL_ID_PIN_STOP: i32 = 105i32;
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct PWM_POLARITY(pub i32);
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_ACTIVE_HIGH: PWM_POLARITY = PWM_POLARITY(0i32);
+#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
+pub const PWM_ACTIVE_LOW: PWM_POLARITY = PWM_POLARITY(1i32);
+impl ::core::marker::Copy for PWM_POLARITY {}
+impl ::core::clone::Clone for PWM_POLARITY {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for PWM_POLARITY {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for PWM_POLARITY {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for PWM_POLARITY {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("PWM_POLARITY").field(&self.0).finish()
+    }
+}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
 pub struct PWM_CONTROLLER_GET_ACTUAL_PERIOD_OUTPUT {
@@ -144,26 +191,6 @@ impl ::core::default::Default for PWM_CONTROLLER_SET_DESIRED_PERIOD_OUTPUT {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_CONTROLLER_GET_ACTUAL_PERIOD: i32 = 1i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_CONTROLLER_GET_INFO: i32 = 0i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_CONTROLLER_SET_DESIRED_PERIOD: i32 = 2i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_GET_ACTIVE_DUTY_CYCLE_PERCENTAGE: i32 = 100i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_GET_POLARITY: i32 = 102i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_IS_STARTED: i32 = 106i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_SET_ACTIVE_DUTY_CYCLE_PERCENTAGE: i32 = 101i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_SET_POLARITY: i32 = 103i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_START: i32 = 104i32;
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_IOCTL_ID_PIN_STOP: i32 = 105i32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
 pub struct PWM_PIN_GET_ACTIVE_DUTY_CYCLE_PERCENTAGE_OUTPUT {
@@ -322,32 +349,5 @@ impl ::core::default::Default for PWM_PIN_SET_POLARITY_INPUT {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct PWM_POLARITY(pub i32);
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_ACTIVE_HIGH: PWM_POLARITY = PWM_POLARITY(0i32);
-#[doc = "*Required features: `\"Win32_Devices_Pwm\"`*"]
-pub const PWM_ACTIVE_LOW: PWM_POLARITY = PWM_POLARITY(1i32);
-impl ::core::marker::Copy for PWM_POLARITY {}
-impl ::core::clone::Clone for PWM_POLARITY {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for PWM_POLARITY {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for PWM_POLARITY {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for PWM_POLARITY {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("PWM_POLARITY").field(&self.0).finish()
-    }
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
