@@ -1,111 +1,6 @@
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_DLL_A: &str = "d3dcompiler_47.dll";
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_DLL_W: &str = "d3dcompiler_47.dll";
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct D3DCOMPILER_STRIP_FLAGS(pub i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_REFLECTION_DATA: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(1i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_DEBUG_INFO: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(2i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_TEST_BLOBS: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(4i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_PRIVATE_DATA: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(8i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_ROOT_SIGNATURE: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(16i32);
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILER_STRIP_FORCE_DWORD: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(2147483647i32);
-impl ::core::marker::Copy for D3DCOMPILER_STRIP_FLAGS {}
-impl ::core::clone::Clone for D3DCOMPILER_STRIP_FLAGS {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for D3DCOMPILER_STRIP_FLAGS {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for D3DCOMPILER_STRIP_FLAGS {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for D3DCOMPILER_STRIP_FLAGS {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("D3DCOMPILER_STRIP_FLAGS").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_ALL_RESOURCES_BOUND: u32 = 2097152u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_AVOID_FLOW_CONTROL: u32 = 512u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_DEBUG: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_DEBUG_NAME_FOR_BINARY: u32 = 8388608u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_DEBUG_NAME_FOR_SOURCE: u32 = 4194304u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_EFFECT_ALLOW_SLOW_OPS: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_EFFECT_CHILD_EFFECT: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_ENABLE_BACKWARDS_COMPATIBILITY: u32 = 4096u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_ENABLE_STRICTNESS: u32 = 2048u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_ENABLE_UNBOUNDED_DESCRIPTOR_TABLES: u32 = 1048576u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_1_0: u32 = 16u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_1_1: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_LATEST: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_FORCE_PS_SOFTWARE_NO_OPT: u32 = 128u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_FORCE_VS_SOFTWARE_NO_OPT: u32 = 64u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_IEEE_STRICTNESS: u32 = 8192u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_NO_PRESHADER: u32 = 256u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_OPTIMIZATION_LEVEL0: u32 = 16384u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_OPTIMIZATION_LEVEL1: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_OPTIMIZATION_LEVEL3: u32 = 32768u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_PACK_MATRIX_COLUMN_MAJOR: u32 = 16u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_PACK_MATRIX_ROW_MAJOR: u32 = 8u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_PARTIAL_PRECISION: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_PREFER_FLOW_CONTROL: u32 = 1024u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_RESERVED16: u32 = 65536u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_RESERVED17: u32 = 131072u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_RESOURCES_MAY_ALIAS: u32 = 524288u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_SECDATA_MERGE_UAV_SLOTS: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_SECDATA_PRESERVE_TEMPLATE_SLOTS: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_SECDATA_REQUIRE_TEMPLATE_MATCH: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_SKIP_OPTIMIZATION: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_SKIP_VALIDATION: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3DCOMPILE_WARNINGS_ARE_ERRORS: u32 = 262144u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DCompile<'a, P0, P1, P2, P3>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: *const super::D3D_SHADER_MACRO, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
+pub unsafe fn D3DCompile<'a, P0, P1, P2, P3>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: ::core::option::Option<*const super::D3D_SHADER_MACRO>, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: ::core::option::Option<*mut ::core::option::Option<super::ID3DBlob>>) -> ::windows::core::Result<()>
 where
     P0: ::std::convert::Into<::windows::core::PCSTR>,
     P1: ::std::convert::Into<::windows::core::InParam<'a, super::ID3DInclude>>,
@@ -116,11 +11,11 @@ where
     extern "system" {
         fn D3DCompile(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: ::windows::core::PCSTR, pdefines: *const super::D3D_SHADER_MACRO, pinclude: *mut ::core::ffi::c_void, pentrypoint: ::windows::core::PCSTR, ptarget: ::windows::core::PCSTR, flags1: u32, flags2: u32, ppcode: *mut *mut ::core::ffi::c_void, pperrormsgs: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
-    D3DCompile(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs)).ok()
+    D3DCompile(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines.unwrap_or(::std::ptr::null())), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DCompile2<'a, P0, P1, P2, P3>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: *const super::D3D_SHADER_MACRO, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, secondarydataflags: u32, psecondarydata: *const ::core::ffi::c_void, secondarydatasize: usize, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
+pub unsafe fn D3DCompile2<'a, P0, P1, P2, P3>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: ::core::option::Option<*const super::D3D_SHADER_MACRO>, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, secondarydataflags: u32, psecondarydata: ::core::option::Option<*const ::core::ffi::c_void>, secondarydatasize: usize, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: ::core::option::Option<*mut ::core::option::Option<super::ID3DBlob>>) -> ::windows::core::Result<()>
 where
     P0: ::std::convert::Into<::windows::core::PCSTR>,
     P1: ::std::convert::Into<::windows::core::InParam<'a, super::ID3DInclude>>,
@@ -131,11 +26,11 @@ where
     extern "system" {
         fn D3DCompile2(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: ::windows::core::PCSTR, pdefines: *const super::D3D_SHADER_MACRO, pinclude: *mut ::core::ffi::c_void, pentrypoint: ::windows::core::PCSTR, ptarget: ::windows::core::PCSTR, flags1: u32, flags2: u32, secondarydataflags: u32, psecondarydata: *const ::core::ffi::c_void, secondarydatasize: usize, ppcode: *mut *mut ::core::ffi::c_void, pperrormsgs: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
-    D3DCompile2(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, secondarydataflags, ::core::mem::transmute(psecondarydata), secondarydatasize, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs)).ok()
+    D3DCompile2(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines.unwrap_or(::std::ptr::null())), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, secondarydataflags, ::core::mem::transmute(psecondarydata.unwrap_or(::std::ptr::null())), secondarydatasize, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DCompileFromFile<'a, P0, P1, P2, P3>(pfilename: P0, pdefines: *const super::D3D_SHADER_MACRO, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
+pub unsafe fn D3DCompileFromFile<'a, P0, P1, P2, P3>(pfilename: P0, pdefines: ::core::option::Option<*const super::D3D_SHADER_MACRO>, pinclude: P1, pentrypoint: P2, ptarget: P3, flags1: u32, flags2: u32, ppcode: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: ::core::option::Option<*mut ::core::option::Option<super::ID3DBlob>>) -> ::windows::core::Result<()>
 where
     P0: ::std::convert::Into<::windows::core::PCWSTR>,
     P1: ::std::convert::Into<::windows::core::InParam<'a, super::ID3DInclude>>,
@@ -146,7 +41,7 @@ where
     extern "system" {
         fn D3DCompileFromFile(pfilename: ::windows::core::PCWSTR, pdefines: *const super::D3D_SHADER_MACRO, pinclude: *mut ::core::ffi::c_void, pentrypoint: ::windows::core::PCSTR, ptarget: ::windows::core::PCSTR, flags1: u32, flags2: u32, ppcode: *mut *mut ::core::ffi::c_void, pperrormsgs: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
-    D3DCompileFromFile(pfilename.into(), ::core::mem::transmute(pdefines), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs)).ok()
+    D3DCompileFromFile(pfilename.into(), ::core::mem::transmute(pdefines.unwrap_or(::std::ptr::null())), pinclude.into().abi(), pentrypoint.into(), ptarget.into(), flags1, flags2, ::core::mem::transmute(ppcode), ::core::mem::transmute(pperrormsgs.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
@@ -156,7 +51,7 @@ pub unsafe fn D3DCompressShaders(pshaderdata: &[D3D_SHADER_DATA], uflags: u32) -
         fn D3DCompressShaders(unumshaders: u32, pshaderdata: *const D3D_SHADER_DATA, uflags: u32, ppcompresseddata: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
     let mut result__ = ::core::mem::MaybeUninit::zeroed();
-    D3DCompressShaders(pshaderdata.len() as _, ::core::mem::transmute(::windows::core::as_ptr_or_null(pshaderdata)), uflags, ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::ID3DBlob>(result__)
+    D3DCompressShaders(pshaderdata.len() as _, ::core::mem::transmute(pshaderdata.as_ptr()), uflags, ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::ID3DBlob>(result__)
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
@@ -192,12 +87,12 @@ pub unsafe fn D3DCreateLinker() -> ::windows::core::Result<super::super::Direct3
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DDecompressShaders(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, unumshaders: u32, ustartindex: u32, pindices: *const u32, uflags: u32, ppshaders: *mut ::core::option::Option<super::ID3DBlob>, ptotalshaders: *mut u32) -> ::windows::core::Result<()> {
+pub unsafe fn D3DDecompressShaders(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, unumshaders: u32, ustartindex: u32, pindices: ::core::option::Option<*const u32>, uflags: u32, ppshaders: *mut ::core::option::Option<super::ID3DBlob>, ptotalshaders: ::core::option::Option<*mut u32>) -> ::windows::core::Result<()> {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn D3DDecompressShaders(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, unumshaders: u32, ustartindex: u32, pindices: *const u32, uflags: u32, ppshaders: *mut *mut ::core::ffi::c_void, ptotalshaders: *mut u32) -> ::windows::core::HRESULT;
     }
-    D3DDecompressShaders(::core::mem::transmute(psrcdata), srcdatasize, ::core::mem::transmute(unumshaders), ustartindex, ::core::mem::transmute(pindices), uflags, ::core::mem::transmute(ppshaders), ::core::mem::transmute(ptotalshaders)).ok()
+    D3DDecompressShaders(::core::mem::transmute(psrcdata), srcdatasize, unumshaders, ustartindex, ::core::mem::transmute(pindices.unwrap_or(::std::ptr::null())), uflags, ::core::mem::transmute(ppshaders), ::core::mem::transmute(ptotalshaders.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
@@ -228,7 +123,7 @@ where
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DDisassembleRegion<'a, P0>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, szcomments: P0, startbyteoffset: usize, numinsts: usize, pfinishbyteoffset: *mut usize, ppdisassembly: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
+pub unsafe fn D3DDisassembleRegion<'a, P0>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, szcomments: P0, startbyteoffset: usize, numinsts: usize, pfinishbyteoffset: ::core::option::Option<*mut usize>, ppdisassembly: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
 where
     P0: ::std::convert::Into<::windows::core::PCSTR>,
 {
@@ -236,7 +131,7 @@ where
     extern "system" {
         fn D3DDisassembleRegion(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, szcomments: ::windows::core::PCSTR, startbyteoffset: usize, numinsts: usize, pfinishbyteoffset: *mut usize, ppdisassembly: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
-    D3DDisassembleRegion(::core::mem::transmute(psrcdata), srcdatasize, flags, szcomments.into(), startbyteoffset, numinsts, ::core::mem::transmute(pfinishbyteoffset), ::core::mem::transmute(ppdisassembly)).ok()
+    D3DDisassembleRegion(::core::mem::transmute(psrcdata), srcdatasize, flags, szcomments.into(), startbyteoffset, numinsts, ::core::mem::transmute(pfinishbyteoffset.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(ppdisassembly)).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
@@ -290,12 +185,12 @@ pub unsafe fn D3DGetOutputSignatureBlob(psrcdata: *const ::core::ffi::c_void, sr
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DGetTraceInstructionOffsets(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, startinstindex: usize, poffsets: &mut [usize], ptotalinsts: *mut usize) -> ::windows::core::Result<()> {
+pub unsafe fn D3DGetTraceInstructionOffsets(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, startinstindex: usize, poffsets: ::core::option::Option<&mut [usize]>, ptotalinsts: ::core::option::Option<*mut usize>) -> ::windows::core::Result<()> {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn D3DGetTraceInstructionOffsets(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, flags: u32, startinstindex: usize, numinsts: usize, poffsets: *mut usize, ptotalinsts: *mut usize) -> ::windows::core::HRESULT;
     }
-    D3DGetTraceInstructionOffsets(::core::mem::transmute(psrcdata), srcdatasize, flags, startinstindex, poffsets.len() as _, ::core::mem::transmute(::windows::core::as_mut_ptr_or_null(poffsets)), ::core::mem::transmute(ptotalinsts)).ok()
+    D3DGetTraceInstructionOffsets(::core::mem::transmute(psrcdata), srcdatasize, flags, startinstindex, poffsets.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(poffsets.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())), ::core::mem::transmute(ptotalinsts.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`, `\"Win32_Graphics_Direct3D11\"`*"]
 #[cfg(feature = "Win32_Graphics_Direct3D11")]
@@ -310,7 +205,7 @@ pub unsafe fn D3DLoadModule(psrcdata: *const ::core::ffi::c_void, cbsrcdatasize:
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
-pub unsafe fn D3DPreprocess<'a, P0, P1>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: *const super::D3D_SHADER_MACRO, pinclude: P1, ppcodetext: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: *mut ::core::option::Option<super::ID3DBlob>) -> ::windows::core::Result<()>
+pub unsafe fn D3DPreprocess<'a, P0, P1>(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: P0, pdefines: ::core::option::Option<*const super::D3D_SHADER_MACRO>, pinclude: P1, ppcodetext: *mut ::core::option::Option<super::ID3DBlob>, pperrormsgs: ::core::option::Option<*mut ::core::option::Option<super::ID3DBlob>>) -> ::windows::core::Result<()>
 where
     P0: ::std::convert::Into<::windows::core::PCSTR>,
     P1: ::std::convert::Into<::windows::core::InParam<'a, super::ID3DInclude>>,
@@ -319,7 +214,7 @@ where
     extern "system" {
         fn D3DPreprocess(psrcdata: *const ::core::ffi::c_void, srcdatasize: usize, psourcename: ::windows::core::PCSTR, pdefines: *const super::D3D_SHADER_MACRO, pinclude: *mut ::core::ffi::c_void, ppcodetext: *mut *mut ::core::ffi::c_void, pperrormsgs: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT;
     }
-    D3DPreprocess(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines), pinclude.into().abi(), ::core::mem::transmute(ppcodetext), ::core::mem::transmute(pperrormsgs)).ok()
+    D3DPreprocess(::core::mem::transmute(psrcdata), srcdatasize, psourcename.into(), ::core::mem::transmute(pdefines.unwrap_or(::std::ptr::null())), pinclude.into().abi(), ::core::mem::transmute(ppcodetext), ::core::mem::transmute(pperrormsgs.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[inline]
@@ -388,6 +283,133 @@ where
     D3DWriteBlobToFile(pblob.into().abi(), pfilename.into(), boverwrite.into()).ok()
 }
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_DLL_A: ::windows::core::PCSTR = ::windows::s!("d3dcompiler_47.dll");
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_DLL_W: ::windows::core::PCWSTR = ::windows::w!("d3dcompiler_47.dll");
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_ALL_RESOURCES_BOUND: u32 = 2097152u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_AVOID_FLOW_CONTROL: u32 = 512u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_DEBUG: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_DEBUG_NAME_FOR_BINARY: u32 = 8388608u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_DEBUG_NAME_FOR_SOURCE: u32 = 4194304u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_EFFECT_ALLOW_SLOW_OPS: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_EFFECT_CHILD_EFFECT: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_ENABLE_BACKWARDS_COMPATIBILITY: u32 = 4096u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_ENABLE_STRICTNESS: u32 = 2048u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_ENABLE_UNBOUNDED_DESCRIPTOR_TABLES: u32 = 1048576u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_1_0: u32 = 16u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_1_1: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_LATEST: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_FORCE_PS_SOFTWARE_NO_OPT: u32 = 128u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_FORCE_VS_SOFTWARE_NO_OPT: u32 = 64u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_IEEE_STRICTNESS: u32 = 8192u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_NO_PRESHADER: u32 = 256u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_OPTIMIZATION_LEVEL0: u32 = 16384u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_OPTIMIZATION_LEVEL1: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_OPTIMIZATION_LEVEL3: u32 = 32768u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_PACK_MATRIX_COLUMN_MAJOR: u32 = 16u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_PACK_MATRIX_ROW_MAJOR: u32 = 8u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_PARTIAL_PRECISION: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_PREFER_FLOW_CONTROL: u32 = 1024u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_RESERVED16: u32 = 65536u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_RESERVED17: u32 = 131072u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_RESOURCES_MAY_ALIAS: u32 = 524288u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_SECDATA_MERGE_UAV_SLOTS: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_SECDATA_PRESERVE_TEMPLATE_SLOTS: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_SECDATA_REQUIRE_TEMPLATE_MATCH: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_SKIP_OPTIMIZATION: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_SKIP_VALIDATION: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILE_WARNINGS_ARE_ERRORS: u32 = 262144u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_COMPILER_VERSION: u32 = 47u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_COMPRESS_SHADER_KEEP_ALL_PARTS: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_DISABLE_DEBUG_INFO: u32 = 16u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_ENABLE_COLOR_CODE: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_ENABLE_DEFAULT_VALUE_PRINTS: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_ENABLE_INSTRUCTION_CYCLE: u32 = 8u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_ENABLE_INSTRUCTION_NUMBERING: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_ENABLE_INSTRUCTION_OFFSET: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_INSTRUCTION_ONLY: u32 = 64u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_DISASM_PRINT_HEX_LITERALS: u32 = 128u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3D_GET_INST_OFFSETS_INCLUDE_NON_EXECUTABLE: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct D3DCOMPILER_STRIP_FLAGS(pub i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_REFLECTION_DATA: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(1i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_DEBUG_INFO: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(2i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_TEST_BLOBS: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(4i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_PRIVATE_DATA: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(8i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_ROOT_SIGNATURE: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(16i32);
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
+pub const D3DCOMPILER_STRIP_FORCE_DWORD: D3DCOMPILER_STRIP_FLAGS = D3DCOMPILER_STRIP_FLAGS(2147483647i32);
+impl ::core::marker::Copy for D3DCOMPILER_STRIP_FLAGS {}
+impl ::core::clone::Clone for D3DCOMPILER_STRIP_FLAGS {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for D3DCOMPILER_STRIP_FLAGS {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for D3DCOMPILER_STRIP_FLAGS {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for D3DCOMPILER_STRIP_FLAGS {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("D3DCOMPILER_STRIP_FLAGS").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct D3D_BLOB_PART(pub i32);
@@ -444,28 +466,6 @@ impl ::core::fmt::Debug for D3D_BLOB_PART {
         f.debug_tuple("D3D_BLOB_PART").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_COMPILER_VERSION: u32 = 47u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_COMPRESS_SHADER_KEEP_ALL_PARTS: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_DISABLE_DEBUG_INFO: u32 = 16u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_ENABLE_COLOR_CODE: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_ENABLE_DEFAULT_VALUE_PRINTS: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_ENABLE_INSTRUCTION_CYCLE: u32 = 8u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_ENABLE_INSTRUCTION_NUMBERING: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_ENABLE_INSTRUCTION_OFFSET: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_INSTRUCTION_ONLY: u32 = 64u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_DISASM_PRINT_HEX_LITERALS: u32 = 128u32;
-#[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
-pub const D3D_GET_INST_OFFSETS_INCLUDE_NON_EXECUTABLE: u32 = 1u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Graphics_Direct3D_Fxc\"`*"]
 pub struct D3D_SHADER_DATA {
