@@ -61,7 +61,7 @@ impl IDirectMusic_Vtbl {
             this.SetDirectSound(::core::mem::transmute(&pdirectsound), ::core::mem::transmute_copy(&hwnd)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             EnumPort: EnumPort::<Identity, Impl, OFFSET>,
             CreateMusicBuffer: CreateMusicBuffer::<Identity, Impl, OFFSET>,
             CreatePort: CreatePort::<Identity, Impl, OFFSET>,
@@ -181,7 +181,7 @@ impl IDirectMusicBuffer_Vtbl {
             this.SetUsedBytes(::core::mem::transmute_copy(&cb)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Flush: Flush::<Identity, Impl, OFFSET>,
             TotalTime: TotalTime::<Identity, Impl, OFFSET>,
             PackStructured: PackStructured::<Identity, Impl, OFFSET>,
@@ -225,7 +225,7 @@ impl IDirectMusicCollection_Vtbl {
             this.EnumInstrument(::core::mem::transmute_copy(&dwindex), ::core::mem::transmute_copy(&pdwpatch), ::core::mem::transmute(&pwszname), ::core::mem::transmute_copy(&dwnamelen)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetInstrument: GetInstrument::<Identity, Impl, OFFSET>,
             EnumInstrument: EnumInstrument::<Identity, Impl, OFFSET>,
         }
@@ -245,7 +245,7 @@ impl IDirectMusicDownload_Vtbl {
             let this = (*this).get_impl();
             this.GetBuffer(::core::mem::transmute_copy(&ppvbuffer), ::core::mem::transmute_copy(&pdwsize)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), GetBuffer: GetBuffer::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), GetBuffer: GetBuffer::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IDirectMusicDownload as ::windows::core::Interface>::IID
@@ -255,7 +255,7 @@ pub trait IDirectMusicDownloadedInstrument_Impl: Sized {}
 impl ::windows::core::RuntimeName for IDirectMusicDownloadedInstrument {}
 impl IDirectMusicDownloadedInstrument_Vtbl {
     pub const fn new<Identity: ::windows::core::IUnknownImpl<Impl = Impl>, Impl: IDirectMusicDownloadedInstrument_Impl, const OFFSET: isize>() -> IDirectMusicDownloadedInstrument_Vtbl {
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>() }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>() }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IDirectMusicDownloadedInstrument as ::windows::core::Interface>::IID
@@ -279,7 +279,7 @@ impl IDirectMusicInstrument_Vtbl {
             this.SetPatch(::core::mem::transmute_copy(&dwpatch)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetPatch: GetPatch::<Identity, Impl, OFFSET>,
             SetPatch: SetPatch::<Identity, Impl, OFFSET>,
         }
@@ -405,7 +405,7 @@ impl IDirectMusicPort_Vtbl {
             this.GetFormat(::core::mem::transmute_copy(&pwaveformatex), ::core::mem::transmute_copy(&pdwwaveformatexsize), ::core::mem::transmute_copy(&pdwbuffersize)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             PlayBuffer: PlayBuffer::<Identity, Impl, OFFSET>,
             SetReadNotificationHandle: SetReadNotificationHandle::<Identity, Impl, OFFSET>,
             Read: Read::<Identity, Impl, OFFSET>,
@@ -483,7 +483,7 @@ impl IDirectMusicPortDownload_Vtbl {
             this.Unload(::core::mem::transmute(&pidmdownload)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetBuffer: GetBuffer::<Identity, Impl, OFFSET>,
             AllocateBuffer: AllocateBuffer::<Identity, Impl, OFFSET>,
             GetDLId: GetDLId::<Identity, Impl, OFFSET>,
@@ -613,7 +613,7 @@ impl IDirectMusicSynth_Vtbl {
             this.GetAppend(::core::mem::transmute_copy(&pdwappend)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Open: Open::<Identity, Impl, OFFSET>,
             Close: Close::<Identity, Impl, OFFSET>,
             SetNumChannelGroups: SetNumChannelGroups::<Identity, Impl, OFFSET>,
@@ -751,7 +751,7 @@ impl IDirectMusicSynthSink_Vtbl {
             this.GetDesiredBufferSize(::core::mem::transmute_copy(&pdwbuffersizeinsamples)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Init: Init::<Identity, Impl, OFFSET>,
             SetMasterClock: SetMasterClock::<Identity, Impl, OFFSET>,
             GetLatencyClock: GetLatencyClock::<Identity, Impl, OFFSET>,
@@ -777,7 +777,7 @@ impl IDirectMusicThru_Vtbl {
             let this = (*this).get_impl();
             this.ThruChannel(::core::mem::transmute_copy(&dwsourcechannelgroup), ::core::mem::transmute_copy(&dwsourcechannel), ::core::mem::transmute_copy(&dwdestinationchannelgroup), ::core::mem::transmute_copy(&dwdestinationchannel), ::core::mem::transmute(&pdestinationport)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), ThruChannel: ThruChannel::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), ThruChannel: ThruChannel::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IDirectMusicThru as ::windows::core::Interface>::IID
