@@ -11,7 +11,7 @@ pub unsafe fn FreeInterfaceContextTable(interfacecontexttable: *const NET_INTERF
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn GetInterfaceContextTableForHostName<'a, P0, P1>(hostname: P0, proxyname: P1, flags: u32, connectionprofilefilterrawdata: *const u8, connectionprofilefilterrawdatasize: u32) -> ::windows::core::Result<*mut NET_INTERFACE_CONTEXT_TABLE>
+pub unsafe fn GetInterfaceContextTableForHostName<'a, P0, P1>(hostname: P0, proxyname: P1, flags: u32, connectionprofilefilterrawdata: ::core::option::Option<&[u8]>) -> ::windows::core::Result<*mut NET_INTERFACE_CONTEXT_TABLE>
 where
     P0: ::std::convert::Into<::windows::core::PCWSTR>,
     P1: ::std::convert::Into<::windows::core::PCWSTR>,
@@ -21,7 +21,253 @@ where
         fn GetInterfaceContextTableForHostName(hostname: ::windows::core::PCWSTR, proxyname: ::windows::core::PCWSTR, flags: u32, connectionprofilefilterrawdata: *const u8, connectionprofilefilterrawdatasize: u32, interfacecontexttable: *mut *mut NET_INTERFACE_CONTEXT_TABLE) -> ::windows::core::HRESULT;
     }
     let mut result__ = ::core::mem::MaybeUninit::zeroed();
-    GetInterfaceContextTableForHostName(hostname.into(), proxyname.into(), flags, ::core::mem::transmute(connectionprofilefilterrawdata), connectionprofilefilterrawdatasize, ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<*mut NET_INTERFACE_CONTEXT_TABLE>(result__)
+    GetInterfaceContextTableForHostName(hostname.into(), proxyname.into(), flags, ::core::mem::transmute(connectionprofilefilterrawdata.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())), connectionprofilefilterrawdata.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<*mut NET_INTERFACE_CONTEXT_TABLE>(result__)
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[inline]
+pub unsafe fn OnDemandGetRoutingHint<'a, P0>(destinationhostname: P0) -> ::windows::core::Result<u32>
+where
+    P0: ::std::convert::Into<::windows::core::PCWSTR>,
+{
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn OnDemandGetRoutingHint(destinationhostname: ::windows::core::PCWSTR, interfaceindex: *mut u32) -> ::windows::core::HRESULT;
+    }
+    let mut result__ = ::core::mem::MaybeUninit::zeroed();
+    OnDemandGetRoutingHint(destinationhostname.into(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn OnDemandRegisterNotification(callback: ONDEMAND_NOTIFICATION_CALLBACK, callbackcontext: ::core::option::Option<*const ::core::ffi::c_void>) -> ::windows::core::Result<super::super::Foundation::HANDLE> {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn OnDemandRegisterNotification(callback: *mut ::core::ffi::c_void, callbackcontext: *const ::core::ffi::c_void, registrationhandle: *mut super::super::Foundation::HANDLE) -> ::windows::core::HRESULT;
+    }
+    let mut result__ = ::core::mem::MaybeUninit::zeroed();
+    OnDemandRegisterNotification(::core::mem::transmute(callback), ::core::mem::transmute(callbackcontext.unwrap_or(::std::ptr::null())), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::HANDLE>(result__)
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn OnDemandUnRegisterNotification<'a, P0>(registrationhandle: P0) -> ::windows::core::Result<()>
+where
+    P0: ::std::convert::Into<super::super::Foundation::HANDLE>,
+{
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn OnDemandUnRegisterNotification(registrationhandle: super::super::Foundation::HANDLE) -> ::windows::core::HRESULT;
+    }
+    OnDemandUnRegisterNotification(registrationhandle.into()).ok()
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[inline]
+pub unsafe fn WcmFreeMemory(pmemory: *mut ::core::ffi::c_void) {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn WcmFreeMemory(pmemory: *mut ::core::ffi::c_void);
+    }
+    WcmFreeMemory(::core::mem::transmute(pmemory))
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[inline]
+pub unsafe fn WcmGetProfileList(preserved: ::core::option::Option<*mut ::core::ffi::c_void>, ppprofilelist: *mut *mut WCM_PROFILE_INFO_LIST) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn WcmGetProfileList(preserved: *mut ::core::ffi::c_void, ppprofilelist: *mut *mut WCM_PROFILE_INFO_LIST) -> u32;
+    }
+    WcmGetProfileList(::core::mem::transmute(preserved.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(ppprofilelist))
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[inline]
+pub unsafe fn WcmQueryProperty<'a, P0>(pinterface: ::core::option::Option<*const ::windows::core::GUID>, strprofilename: P0, property: WCM_PROPERTY, preserved: ::core::option::Option<*mut ::core::ffi::c_void>, pdwdatasize: *mut u32, ppdata: ::core::option::Option<*mut *mut u8>) -> u32
+where
+    P0: ::std::convert::Into<::windows::core::PCWSTR>,
+{
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn WcmQueryProperty(pinterface: *const ::windows::core::GUID, strprofilename: ::windows::core::PCWSTR, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, pdwdatasize: *mut u32, ppdata: *mut *mut u8) -> u32;
+    }
+    WcmQueryProperty(::core::mem::transmute(pinterface.unwrap_or(::std::ptr::null())), strprofilename.into(), property, ::core::mem::transmute(preserved.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(pdwdatasize), ::core::mem::transmute(ppdata.unwrap_or(::std::ptr::null_mut())))
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn WcmSetProfileList<'a, P0>(pprofilelist: *const WCM_PROFILE_INFO_LIST, dwposition: u32, fignoreunknownprofiles: P0, preserved: ::core::option::Option<*mut ::core::ffi::c_void>) -> u32
+where
+    P0: ::std::convert::Into<super::super::Foundation::BOOL>,
+{
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn WcmSetProfileList(pprofilelist: *const WCM_PROFILE_INFO_LIST, dwposition: u32, fignoreunknownprofiles: super::super::Foundation::BOOL, preserved: *mut ::core::ffi::c_void) -> u32;
+    }
+    WcmSetProfileList(::core::mem::transmute(pprofilelist), dwposition, fignoreunknownprofiles.into(), ::core::mem::transmute(preserved.unwrap_or(::std::ptr::null_mut())))
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[inline]
+pub unsafe fn WcmSetProperty<'a, P0>(pinterface: ::core::option::Option<*const ::windows::core::GUID>, strprofilename: P0, property: WCM_PROPERTY, preserved: ::core::option::Option<*mut ::core::ffi::c_void>, pbdata: ::core::option::Option<&[u8]>) -> u32
+where
+    P0: ::std::convert::Into<::windows::core::PCWSTR>,
+{
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn WcmSetProperty(pinterface: *const ::windows::core::GUID, strprofilename: ::windows::core::PCWSTR, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, dwdatasize: u32, pbdata: *const u8) -> u32;
+    }
+    WcmSetProperty(::core::mem::transmute(pinterface.unwrap_or(::std::ptr::null())), strprofilename.into(), property, ::core::mem::transmute(preserved.unwrap_or(::std::ptr::null_mut())), pbdata.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(pbdata.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())))
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const NET_INTERFACE_FLAG_CONNECT_IF_NEEDED: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const NET_INTERFACE_FLAG_NONE: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_API_VERSION: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_API_VERSION_1_0: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_MAX_PROFILE_NAME: u32 = 256u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_UNKNOWN_DATAPLAN_STATUS: u32 = 4294967295u32;
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct WCM_CONNECTION_COST(pub i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_UNKNOWN: WCM_CONNECTION_COST = WCM_CONNECTION_COST(0i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_UNRESTRICTED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(1i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_FIXED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(2i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_VARIABLE: WCM_CONNECTION_COST = WCM_CONNECTION_COST(4i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_OVERDATALIMIT: WCM_CONNECTION_COST = WCM_CONNECTION_COST(65536i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_CONGESTED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(131072i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_ROAMING: WCM_CONNECTION_COST = WCM_CONNECTION_COST(262144i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_APPROACHINGDATALIMIT: WCM_CONNECTION_COST = WCM_CONNECTION_COST(524288i32);
+impl ::core::marker::Copy for WCM_CONNECTION_COST {}
+impl ::core::clone::Clone for WCM_CONNECTION_COST {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for WCM_CONNECTION_COST {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for WCM_CONNECTION_COST {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for WCM_CONNECTION_COST {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("WCM_CONNECTION_COST").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct WCM_CONNECTION_COST_SOURCE(pub i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_SOURCE_DEFAULT: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(0i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_SOURCE_GP: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(1i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_SOURCE_USER: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(2i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const WCM_CONNECTION_COST_SOURCE_OPERATOR: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(3i32);
+impl ::core::marker::Copy for WCM_CONNECTION_COST_SOURCE {}
+impl ::core::clone::Clone for WCM_CONNECTION_COST_SOURCE {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for WCM_CONNECTION_COST_SOURCE {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for WCM_CONNECTION_COST_SOURCE {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for WCM_CONNECTION_COST_SOURCE {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("WCM_CONNECTION_COST_SOURCE").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct WCM_MEDIA_TYPE(pub i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_unknown: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(0i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_ethernet: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(1i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_wlan: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(2i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_mbn: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(3i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_invalid: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(4i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_media_max: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(5i32);
+impl ::core::marker::Copy for WCM_MEDIA_TYPE {}
+impl ::core::clone::Clone for WCM_MEDIA_TYPE {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for WCM_MEDIA_TYPE {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for WCM_MEDIA_TYPE {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for WCM_MEDIA_TYPE {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("WCM_MEDIA_TYPE").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct WCM_PROPERTY(pub i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_global_property_domain_policy: WCM_PROPERTY = WCM_PROPERTY(0i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_global_property_minimize_policy: WCM_PROPERTY = WCM_PROPERTY(1i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_global_property_roaming_policy: WCM_PROPERTY = WCM_PROPERTY(2i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_global_property_powermanagement_policy: WCM_PROPERTY = WCM_PROPERTY(3i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_intf_property_connection_cost: WCM_PROPERTY = WCM_PROPERTY(4i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_intf_property_dataplan_status: WCM_PROPERTY = WCM_PROPERTY(5i32);
+#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
+pub const wcm_intf_property_hotspot_profile: WCM_PROPERTY = WCM_PROPERTY(6i32);
+impl ::core::marker::Copy for WCM_PROPERTY {}
+impl ::core::clone::Clone for WCM_PROPERTY {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for WCM_PROPERTY {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for WCM_PROPERTY {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for WCM_PROPERTY {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("WCM_PROPERTY").field(&self.0).finish()
+    }
 }
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
@@ -94,53 +340,6 @@ impl ::core::default::Default for NET_INTERFACE_CONTEXT_TABLE {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const NET_INTERFACE_FLAG_CONNECT_IF_NEEDED: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const NET_INTERFACE_FLAG_NONE: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub type ONDEMAND_NOTIFICATION_CALLBACK = ::core::option::Option<unsafe extern "system" fn(param0: *const ::core::ffi::c_void)>;
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[inline]
-pub unsafe fn OnDemandGetRoutingHint<'a, P0>(destinationhostname: P0) -> ::windows::core::Result<u32>
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn OnDemandGetRoutingHint(destinationhostname: ::windows::core::PCWSTR, interfaceindex: *mut u32) -> ::windows::core::HRESULT;
-    }
-    let mut result__ = ::core::mem::MaybeUninit::zeroed();
-    OnDemandGetRoutingHint(destinationhostname.into(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn OnDemandRegisterNotification(callback: ONDEMAND_NOTIFICATION_CALLBACK, callbackcontext: *const ::core::ffi::c_void) -> ::windows::core::Result<super::super::Foundation::HANDLE> {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn OnDemandRegisterNotification(callback: *mut ::core::ffi::c_void, callbackcontext: *const ::core::ffi::c_void, registrationhandle: *mut super::super::Foundation::HANDLE) -> ::windows::core::HRESULT;
-    }
-    let mut result__ = ::core::mem::MaybeUninit::zeroed();
-    OnDemandRegisterNotification(::core::mem::transmute(callback), ::core::mem::transmute(callbackcontext), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::HANDLE>(result__)
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn OnDemandUnRegisterNotification<'a, P0>(registrationhandle: P0) -> ::windows::core::Result<()>
-where
-    P0: ::std::convert::Into<super::super::Foundation::HANDLE>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn OnDemandUnRegisterNotification(registrationhandle: super::super::Foundation::HANDLE) -> ::windows::core::HRESULT;
-    }
-    OnDemandUnRegisterNotification(registrationhandle.into()).ok()
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_API_VERSION: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_API_VERSION_1_0: u32 = 1u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -181,45 +380,6 @@ impl ::core::default::Default for WCM_BILLING_CYCLE_INFO {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct WCM_CONNECTION_COST(pub i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_UNKNOWN: WCM_CONNECTION_COST = WCM_CONNECTION_COST(0i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_UNRESTRICTED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(1i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_FIXED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(2i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_VARIABLE: WCM_CONNECTION_COST = WCM_CONNECTION_COST(4i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_OVERDATALIMIT: WCM_CONNECTION_COST = WCM_CONNECTION_COST(65536i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_CONGESTED: WCM_CONNECTION_COST = WCM_CONNECTION_COST(131072i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_ROAMING: WCM_CONNECTION_COST = WCM_CONNECTION_COST(262144i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_APPROACHINGDATALIMIT: WCM_CONNECTION_COST = WCM_CONNECTION_COST(524288i32);
-impl ::core::marker::Copy for WCM_CONNECTION_COST {}
-impl ::core::clone::Clone for WCM_CONNECTION_COST {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for WCM_CONNECTION_COST {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for WCM_CONNECTION_COST {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for WCM_CONNECTION_COST {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("WCM_CONNECTION_COST").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
 pub struct WCM_CONNECTION_COST_DATA {
@@ -251,37 +411,6 @@ impl ::core::default::Default for WCM_CONNECTION_COST_DATA {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct WCM_CONNECTION_COST_SOURCE(pub i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_SOURCE_DEFAULT: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(0i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_SOURCE_GP: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(1i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_SOURCE_USER: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(2i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_CONNECTION_COST_SOURCE_OPERATOR: WCM_CONNECTION_COST_SOURCE = WCM_CONNECTION_COST_SOURCE(3i32);
-impl ::core::marker::Copy for WCM_CONNECTION_COST_SOURCE {}
-impl ::core::clone::Clone for WCM_CONNECTION_COST_SOURCE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for WCM_CONNECTION_COST_SOURCE {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for WCM_CONNECTION_COST_SOURCE {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for WCM_CONNECTION_COST_SOURCE {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("WCM_CONNECTION_COST_SOURCE").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -326,43 +455,6 @@ impl ::core::default::Default for WCM_DATAPLAN_STATUS {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_MAX_PROFILE_NAME: u32 = 256u32;
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct WCM_MEDIA_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_unknown: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_ethernet: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_wlan: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(2i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_mbn: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(3i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_invalid: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(4i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_media_max: WCM_MEDIA_TYPE = WCM_MEDIA_TYPE(5i32);
-impl ::core::marker::Copy for WCM_MEDIA_TYPE {}
-impl ::core::clone::Clone for WCM_MEDIA_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for WCM_MEDIA_TYPE {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for WCM_MEDIA_TYPE {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for WCM_MEDIA_TYPE {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("WCM_MEDIA_TYPE").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -465,43 +557,6 @@ impl ::core::default::Default for WCM_PROFILE_INFO_LIST {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct WCM_PROPERTY(pub i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_global_property_domain_policy: WCM_PROPERTY = WCM_PROPERTY(0i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_global_property_minimize_policy: WCM_PROPERTY = WCM_PROPERTY(1i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_global_property_roaming_policy: WCM_PROPERTY = WCM_PROPERTY(2i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_global_property_powermanagement_policy: WCM_PROPERTY = WCM_PROPERTY(3i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_intf_property_connection_cost: WCM_PROPERTY = WCM_PROPERTY(4i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_intf_property_dataplan_status: WCM_PROPERTY = WCM_PROPERTY(5i32);
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const wcm_intf_property_hotspot_profile: WCM_PROPERTY = WCM_PROPERTY(6i32);
-impl ::core::marker::Copy for WCM_PROPERTY {}
-impl ::core::clone::Clone for WCM_PROPERTY {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for WCM_PROPERTY {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for WCM_PROPERTY {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for WCM_PROPERTY {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("WCM_PROPERTY").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
 pub struct WCM_TIME_INTERVAL {
@@ -538,8 +593,6 @@ impl ::core::default::Default for WCM_TIME_INTERVAL {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-pub const WCM_UNKNOWN_DATAPLAN_STATUS: u32 = 4294967295u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -580,59 +633,6 @@ impl ::core::default::Default for WCM_USAGE_DATA {
     }
 }
 #[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[inline]
-pub unsafe fn WcmFreeMemory(pmemory: *mut ::core::ffi::c_void) {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn WcmFreeMemory(pmemory: *mut ::core::ffi::c_void);
-    }
-    WcmFreeMemory(::core::mem::transmute(pmemory))
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[inline]
-pub unsafe fn WcmGetProfileList(preserved: *mut ::core::ffi::c_void, ppprofilelist: *mut *mut WCM_PROFILE_INFO_LIST) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn WcmGetProfileList(preserved: *mut ::core::ffi::c_void, ppprofilelist: *mut *mut WCM_PROFILE_INFO_LIST) -> u32;
-    }
-    WcmGetProfileList(::core::mem::transmute(preserved), ::core::mem::transmute(ppprofilelist))
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[inline]
-pub unsafe fn WcmQueryProperty<'a, P0>(pinterface: *const ::windows::core::GUID, strprofilename: P0, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, pdwdatasize: *mut u32, ppdata: *mut *mut u8) -> u32
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn WcmQueryProperty(pinterface: *const ::windows::core::GUID, strprofilename: ::windows::core::PCWSTR, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, pdwdatasize: *mut u32, ppdata: *mut *mut u8) -> u32;
-    }
-    WcmQueryProperty(::core::mem::transmute(pinterface), strprofilename.into(), property, ::core::mem::transmute(preserved), ::core::mem::transmute(pdwdatasize), ::core::mem::transmute(ppdata))
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn WcmSetProfileList<'a, P0>(pprofilelist: *const WCM_PROFILE_INFO_LIST, dwposition: u32, fignoreunknownprofiles: P0, preserved: *mut ::core::ffi::c_void) -> u32
-where
-    P0: ::std::convert::Into<super::super::Foundation::BOOL>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn WcmSetProfileList(pprofilelist: *const WCM_PROFILE_INFO_LIST, dwposition: u32, fignoreunknownprofiles: super::super::Foundation::BOOL, preserved: *mut ::core::ffi::c_void) -> u32;
-    }
-    WcmSetProfileList(::core::mem::transmute(pprofilelist), dwposition, fignoreunknownprofiles.into(), ::core::mem::transmute(preserved))
-}
-#[doc = "*Required features: `\"Win32_NetworkManagement_WindowsConnectionManager\"`*"]
-#[inline]
-pub unsafe fn WcmSetProperty<'a, P0>(pinterface: *const ::windows::core::GUID, strprofilename: P0, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, pbdata: &[u8]) -> u32
-where
-    P0: ::std::convert::Into<::windows::core::PCWSTR>,
-{
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn WcmSetProperty(pinterface: *const ::windows::core::GUID, strprofilename: ::windows::core::PCWSTR, property: WCM_PROPERTY, preserved: *mut ::core::ffi::c_void, dwdatasize: u32, pbdata: *const u8) -> u32;
-    }
-    WcmSetProperty(::core::mem::transmute(pinterface), strprofilename.into(), property, ::core::mem::transmute(preserved), pbdata.len() as _, ::core::mem::transmute(::windows::core::as_ptr_or_null(pbdata)))
-}
+pub type ONDEMAND_NOTIFICATION_CALLBACK = ::core::option::Option<unsafe extern "system" fn(param0: *const ::core::ffi::c_void)>;
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
