@@ -22,7 +22,7 @@ impl IFindSimilarResults_Vtbl {
             this.GetNextFileId(::core::mem::transmute_copy(&numtraitsmatched), ::core::mem::transmute_copy(&similarityfileid)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetSize: GetSize::<Identity, Impl, OFFSET>,
             GetNextFileId: GetNextFileId::<Identity, Impl, OFFSET>,
         }
@@ -45,7 +45,7 @@ impl IRdcComparator_Vtbl {
             let this = (*this).get_impl();
             this.Process(::core::mem::transmute_copy(&endofinput), ::core::mem::transmute_copy(&endofoutput), ::core::mem::transmute_copy(&inputbuffer), ::core::mem::transmute_copy(&outputbuffer), ::core::mem::transmute_copy(&rdc_errorcode)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), Process: Process::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), Process: Process::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IRdcComparator as ::windows::core::Interface>::IID
@@ -90,7 +90,7 @@ impl IRdcFileReader_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetFileSize: GetFileSize::<Identity, Impl, OFFSET>,
             Read: Read::<Identity, Impl, OFFSET>,
             GetFilePosition: GetFilePosition::<Identity, Impl, OFFSET>,
@@ -170,7 +170,7 @@ impl IRdcGenerator_Vtbl {
             this.Process(::core::mem::transmute_copy(&endofinput), ::core::mem::transmute_copy(&endofoutput), ::core::mem::transmute_copy(&inputbuffer), ::core::mem::transmute_copy(&depth), ::core::mem::transmute_copy(&outputbuffers), ::core::mem::transmute_copy(&rdc_errorcode)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetGeneratorParameters: GetGeneratorParameters::<Identity, Impl, OFFSET>,
             Process: Process::<Identity, Impl, OFFSET>,
         }
@@ -221,7 +221,7 @@ impl IRdcGeneratorFilterMaxParameters_Vtbl {
             this.SetHashWindowSize(::core::mem::transmute_copy(&hashwindowsize)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetHorizonSize: GetHorizonSize::<Identity, Impl, OFFSET>,
             SetHorizonSize: SetHorizonSize::<Identity, Impl, OFFSET>,
             GetHashWindowSize: GetHashWindowSize::<Identity, Impl, OFFSET>,
@@ -274,7 +274,7 @@ impl IRdcGeneratorParameters_Vtbl {
             this.Serialize(::core::mem::transmute_copy(&size), ::core::mem::transmute_copy(&parametersblob), ::core::mem::transmute_copy(&byteswritten)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetGeneratorParametersType: GetGeneratorParametersType::<Identity, Impl, OFFSET>,
             GetParametersVersion: GetParametersVersion::<Identity, Impl, OFFSET>,
             GetSerializeSize: GetSerializeSize::<Identity, Impl, OFFSET>,
@@ -369,7 +369,7 @@ impl IRdcLibrary_Vtbl {
             this.GetRDCVersion(::core::mem::transmute_copy(&currentversion), ::core::mem::transmute_copy(&minimumcompatibleappversion)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             ComputeDefaultRecursionDepth: ComputeDefaultRecursionDepth::<Identity, Impl, OFFSET>,
             CreateGeneratorParameters: CreateGeneratorParameters::<Identity, Impl, OFFSET>,
             OpenGeneratorParameters: OpenGeneratorParameters::<Identity, Impl, OFFSET>,
@@ -410,7 +410,7 @@ impl IRdcSignatureReader_Vtbl {
             this.ReadSignatures(::core::mem::transmute_copy(&rdcsignaturepointer), ::core::mem::transmute_copy(&endofoutput)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             ReadHeader: ReadHeader::<Identity, Impl, OFFSET>,
             ReadSignatures: ReadSignatures::<Identity, Impl, OFFSET>,
         }
@@ -443,7 +443,7 @@ impl IRdcSimilarityGenerator_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             EnableSimilarity: EnableSimilarity::<Identity, Impl, OFFSET>,
             Results: Results::<Identity, Impl, OFFSET>,
         }
@@ -527,7 +527,7 @@ impl ISimilarity_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             CreateTable: CreateTable::<Identity, Impl, OFFSET>,
             CreateTableIndirect: CreateTableIndirect::<Identity, Impl, OFFSET>,
             CloseTable: CloseTable::<Identity, Impl, OFFSET>,
@@ -622,7 +622,7 @@ impl ISimilarityFileIdTable_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             CreateTable: CreateTable::<Identity, Impl, OFFSET>,
             CreateTableIndirect: CreateTableIndirect::<Identity, Impl, OFFSET>,
             CloseTable: CloseTable::<Identity, Impl, OFFSET>,
@@ -647,7 +647,7 @@ impl ISimilarityReportProgress_Vtbl {
             let this = (*this).get_impl();
             this.ReportProgress(::core::mem::transmute_copy(&percentcompleted)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), ReportProgress: ReportProgress::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), ReportProgress: ReportProgress::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<ISimilarityReportProgress as ::windows::core::Interface>::IID
@@ -667,7 +667,7 @@ impl ISimilarityTableDumpState_Vtbl {
             let this = (*this).get_impl();
             this.GetNextData(::core::mem::transmute_copy(&resultssize), ::core::mem::transmute_copy(&resultsused), ::core::mem::transmute_copy(&eof), ::core::mem::transmute_copy(&results)).into()
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), GetNextData: GetNextData::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), GetNextData: GetNextData::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<ISimilarityTableDumpState as ::windows::core::Interface>::IID
@@ -712,7 +712,7 @@ impl ISimilarityTraitsMappedView_Vtbl {
             this.GetView(::core::mem::transmute_copy(&mappedpagebegin), ::core::mem::transmute_copy(&mappedpageend))
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Flush: Flush::<Identity, Impl, OFFSET>,
             Unmap: Unmap::<Identity, Impl, OFFSET>,
             Get: Get::<Identity, Impl, OFFSET>,
@@ -795,7 +795,7 @@ impl ISimilarityTraitsMapping_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             CloseMapping: CloseMapping::<Identity, Impl, OFFSET>,
             SetFileSize: SetFileSize::<Identity, Impl, OFFSET>,
             GetFileSize: GetFileSize::<Identity, Impl, OFFSET>,
@@ -884,7 +884,7 @@ impl ISimilarityTraitsTable_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             CreateTable: CreateTable::<Identity, Impl, OFFSET>,
             CreateTableIndirect: CreateTableIndirect::<Identity, Impl, OFFSET>,
             CloseTable: CloseTable::<Identity, Impl, OFFSET>,
