@@ -31,12 +31,12 @@ pub unsafe fn CryptSIPGetCaps(psubjinfo: *const SIP_SUBJECTINFO, pcaps: *mut SIP
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`, `\"Win32_Security_Cryptography_Catalog\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security_Cryptography_Catalog"))]
 #[inline]
-pub unsafe fn CryptSIPGetSealedDigest(psubjectinfo: *const SIP_SUBJECTINFO, psig: &[u8], pbdigest: *mut u8, pcbdigest: *mut u32) -> super::super::super::Foundation::BOOL {
+pub unsafe fn CryptSIPGetSealedDigest(psubjectinfo: *const SIP_SUBJECTINFO, psig: ::core::option::Option<&[u8]>, pbdigest: ::core::option::Option<*mut u8>, pcbdigest: *mut u32) -> super::super::super::Foundation::BOOL {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn CryptSIPGetSealedDigest(psubjectinfo: *const SIP_SUBJECTINFO, psig: *const u8, dwsig: u32, pbdigest: *mut u8, pcbdigest: *mut u32) -> super::super::super::Foundation::BOOL;
     }
-    CryptSIPGetSealedDigest(::core::mem::transmute(psubjectinfo), ::core::mem::transmute(::windows::core::as_ptr_or_null(psig)), psig.len() as _, ::core::mem::transmute(pbdigest), ::core::mem::transmute(pcbdigest))
+    CryptSIPGetSealedDigest(::core::mem::transmute(psubjectinfo), ::core::mem::transmute(psig.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())), psig.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(pbdigest.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(pcbdigest))
 }
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`, `\"Win32_Security_Cryptography_Catalog\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security_Cryptography_Catalog"))]
@@ -142,6 +142,38 @@ pub const MSSIP_FLAGS_MULTI_HASH: u32 = 262144u32;
 pub const MSSIP_FLAGS_PROHIBIT_RESIZE_ON_CREATE: u32 = 65536u32;
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
 pub const MSSIP_FLAGS_USE_CATALOG: u32 = 131072u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SIP_CAP_FLAG_SEALING: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SIP_CAP_SET_CUR_VER: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SIP_CAP_SET_VERSION_2: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SIP_CAP_SET_VERSION_3: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SIP_MAX_MAGIC_NUMBER: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_DIGEST_GENERATE_FLAG: u32 = 512u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_DIGEST_SIGN_EX_FLAG: u32 = 16384u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_DIGEST_SIGN_FLAG: u32 = 1024u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_EXC_PE_PAGE_HASHES_FLAG: u32 = 16u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_INC_PE_DEBUG_INFO_FLAG: u32 = 64u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_INC_PE_IMPORT_ADDR_TABLE_FLAG: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_INC_PE_PAGE_HASHES_FLAG: u32 = 256u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_INC_PE_RESOURCES_FLAG: u32 = 128u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_MARKER_CHECK_CURRENTLY_SUPPORTED_FLAGS: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_MARKER_CHECK_SKIP_SIP_INDIRECT_DATA_FLAG: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
+pub const SPC_RELAXED_PE_MARKER_CHECK: u32 = 2048u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
 pub struct MS_ADDINFO_BLOB {
@@ -261,10 +293,6 @@ impl ::core::default::Default for SIP_ADD_NEWPROVIDER {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SIP_CAP_FLAG_SEALING: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SIP_CAP_SET_CUR_VER: u32 = 3u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -374,10 +402,6 @@ impl ::core::default::Default for SIP_CAP_SET_V3_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SIP_CAP_SET_VERSION_2: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SIP_CAP_SET_VERSION_3: u32 = 3u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`, `\"Win32_Security_Cryptography_Catalog\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security_Cryptography_Catalog"))]
@@ -454,8 +478,6 @@ impl ::core::default::Default for SIP_INDIRECT_DATA {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SIP_MAX_MAGIC_NUMBER: u32 = 4u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`, `\"Win32_Security_Cryptography_Catalog\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security_Cryptography_Catalog"))]
@@ -539,28 +561,6 @@ impl ::core::default::Default for SIP_SUBJECTINFO_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_DIGEST_GENERATE_FLAG: u32 = 512u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_DIGEST_SIGN_EX_FLAG: u32 = 16384u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_DIGEST_SIGN_FLAG: u32 = 1024u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_EXC_PE_PAGE_HASHES_FLAG: u32 = 16u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_INC_PE_DEBUG_INFO_FLAG: u32 = 64u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_INC_PE_IMPORT_ADDR_TABLE_FLAG: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_INC_PE_PAGE_HASHES_FLAG: u32 = 256u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_INC_PE_RESOURCES_FLAG: u32 = 128u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_MARKER_CHECK_CURRENTLY_SUPPORTED_FLAGS: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_MARKER_CHECK_SKIP_SIP_INDIRECT_DATA_FLAG: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`*"]
-pub const SPC_RELAXED_PE_MARKER_CHECK: u32 = 2048u32;
 #[doc = "*Required features: `\"Win32_Security_Cryptography_Sip\"`, `\"Win32_Foundation\"`, `\"Win32_Security_Cryptography_Catalog\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security_Cryptography_Catalog"))]
 pub type pCryptSIPCreateIndirectData = ::core::option::Option<unsafe extern "system" fn(psubjectinfo: *mut SIP_SUBJECTINFO, pcbindirectdata: *mut u32, pindirectdata: *mut SIP_INDIRECT_DATA) -> super::super::super::Foundation::BOOL>;
