@@ -10,24 +10,7 @@ impl ITpmVirtualSmartCardManager {
         P1: ::std::convert::Into<super::super::Foundation::BOOL>,
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
-        (::windows::core::Interface::vtable(self).CreateVirtualSmartCard)(
-            ::windows::core::Interface::as_raw(self),
-            pszfriendlyname.into(),
-            badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
-            pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
-            pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
-            pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
-            pbpin.len() as _,
-            fgenerate.into(),
-            pstatuscallback.into().abi(),
-            ::core::mem::transmute(ppszinstanceid),
-            ::core::mem::transmute(pfneedreboot),
-        )
-        .ok()
+        (::windows::core::Vtable::vtable(self).CreateVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszfriendlyname.into(), badminalgid, ::core::mem::transmute(pbadminkey.as_ptr()), pbadminkey.len() as _, ::core::mem::transmute(pbadminkcv.as_ptr()), pbadminkcv.len() as _, ::core::mem::transmute(pbpuk.as_ptr()), pbpuk.len() as _, ::core::mem::transmute(pbpin.as_ptr()), pbpin.len() as _, fgenerate.into(), pstatuscallback.into().abi(), ::core::mem::transmute(ppszinstanceid), ::core::mem::transmute(pfneedreboot)).ok()
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -37,24 +20,10 @@ impl ITpmVirtualSmartCardManager {
         P1: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).DestroyVirtualSmartCard)(::windows::core::Interface::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
-    }
-}
-impl ::core::convert::From<ITpmVirtualSmartCardManager> for ::windows::core::IUnknown {
-    fn from(value: ITpmVirtualSmartCardManager) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITpmVirtualSmartCardManager) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager> for ::windows::core::IUnknown {
-    fn from(value: &ITpmVirtualSmartCardManager) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).DestroyVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
     }
 }
+::windows::core::interface_hierarchy!(ITpmVirtualSmartCardManager, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ITpmVirtualSmartCardManager {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -71,14 +40,16 @@ impl ::core::fmt::Debug for ITpmVirtualSmartCardManager {
         f.debug_tuple("ITpmVirtualSmartCardManager").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager {
+unsafe impl ::windows::core::Vtable for ITpmVirtualSmartCardManager {
     type Vtable = ITpmVirtualSmartCardManager_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x112b1dff_d9dc_41f7_869f_d67fee7cb591);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ITpmVirtualSmartCardManager_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_Foundation")]
     pub CreateVirtualSmartCard: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pszfriendlyname: ::windows::core::PCWSTR, badminalgid: u8, pbadminkey: *const u8, cbadminkey: u32, pbadminkcv: *const u8, cbadminkcv: u32, pbpuk: *const u8, cbpuk: u32, pbpin: *const u8, cbpin: u32, fgenerate: super::super::Foundation::BOOL, pstatuscallback: *mut ::core::ffi::c_void, ppszinstanceid: *mut ::windows::core::PWSTR, pfneedreboot: *mut super::super::Foundation::BOOL) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Foundation"))]
@@ -100,24 +71,7 @@ impl ITpmVirtualSmartCardManager2 {
         P1: ::std::convert::Into<super::super::Foundation::BOOL>,
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
-        (::windows::core::Interface::vtable(self).base__.CreateVirtualSmartCard)(
-            ::windows::core::Interface::as_raw(self),
-            pszfriendlyname.into(),
-            badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
-            pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
-            pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
-            pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
-            pbpin.len() as _,
-            fgenerate.into(),
-            pstatuscallback.into().abi(),
-            ::core::mem::transmute(ppszinstanceid),
-            ::core::mem::transmute(pfneedreboot),
-        )
-        .ok()
+        (::windows::core::Vtable::vtable(self).base__.CreateVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszfriendlyname.into(), badminalgid, ::core::mem::transmute(pbadminkey.as_ptr()), pbadminkey.len() as _, ::core::mem::transmute(pbadminkcv.as_ptr()), pbadminkcv.len() as _, ::core::mem::transmute(pbpuk.as_ptr()), pbpuk.len() as _, ::core::mem::transmute(pbpin.as_ptr()), pbpin.len() as _, fgenerate.into(), pstatuscallback.into().abi(), ::core::mem::transmute(ppszinstanceid), ::core::mem::transmute(pfneedreboot)).ok()
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -127,7 +81,7 @@ impl ITpmVirtualSmartCardManager2 {
         P1: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).base__.DestroyVirtualSmartCard)(::windows::core::Interface::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
+        (::windows::core::Vtable::vtable(self).base__.DestroyVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -137,19 +91,19 @@ impl ITpmVirtualSmartCardManager2 {
         P1: ::std::convert::Into<super::super::Foundation::BOOL>,
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
-        (::windows::core::Interface::vtable(self).CreateVirtualSmartCardWithPinPolicy)(
-            ::windows::core::Interface::as_raw(self),
+        (::windows::core::Vtable::vtable(self).CreateVirtualSmartCardWithPinPolicy)(
+            ::windows::core::Vtable::as_raw(self),
             pszfriendlyname.into(),
             badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
+            ::core::mem::transmute(pbadminkey.as_ptr()),
             pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
+            ::core::mem::transmute(pbadminkcv.as_ptr()),
             pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
+            ::core::mem::transmute(pbpuk.as_ptr()),
             pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
+            ::core::mem::transmute(pbpin.as_ptr()),
             pbpin.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpinpolicy)),
+            ::core::mem::transmute(pbpinpolicy.as_ptr()),
             pbpinpolicy.len() as _,
             fgenerate.into(),
             pstatuscallback.into().abi(),
@@ -159,36 +113,7 @@ impl ITpmVirtualSmartCardManager2 {
         .ok()
     }
 }
-impl ::core::convert::From<ITpmVirtualSmartCardManager2> for ::windows::core::IUnknown {
-    fn from(value: ITpmVirtualSmartCardManager2) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager2> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITpmVirtualSmartCardManager2) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager2> for ::windows::core::IUnknown {
-    fn from(value: &ITpmVirtualSmartCardManager2) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<ITpmVirtualSmartCardManager2> for ITpmVirtualSmartCardManager {
-    fn from(value: ITpmVirtualSmartCardManager2) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager2> for &'a ITpmVirtualSmartCardManager {
-    fn from(value: &'a ITpmVirtualSmartCardManager2) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager2> for ITpmVirtualSmartCardManager {
-    fn from(value: &ITpmVirtualSmartCardManager2) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
+::windows::core::interface_hierarchy!(ITpmVirtualSmartCardManager2, ::windows::core::IUnknown, ITpmVirtualSmartCardManager);
 impl ::core::clone::Clone for ITpmVirtualSmartCardManager2 {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -205,8 +130,10 @@ impl ::core::fmt::Debug for ITpmVirtualSmartCardManager2 {
         f.debug_tuple("ITpmVirtualSmartCardManager2").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager2 {
+unsafe impl ::windows::core::Vtable for ITpmVirtualSmartCardManager2 {
     type Vtable = ITpmVirtualSmartCardManager2_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager2 {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xfdf8a2b9_02de_47f4_bc26_aa85ab5e5267);
 }
 #[repr(C)]
@@ -230,24 +157,7 @@ impl ITpmVirtualSmartCardManager3 {
         P1: ::std::convert::Into<super::super::Foundation::BOOL>,
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
-        (::windows::core::Interface::vtable(self).base__.base__.CreateVirtualSmartCard)(
-            ::windows::core::Interface::as_raw(self),
-            pszfriendlyname.into(),
-            badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
-            pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
-            pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
-            pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
-            pbpin.len() as _,
-            fgenerate.into(),
-            pstatuscallback.into().abi(),
-            ::core::mem::transmute(ppszinstanceid),
-            ::core::mem::transmute(pfneedreboot),
-        )
-        .ok()
+        (::windows::core::Vtable::vtable(self).base__.base__.CreateVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszfriendlyname.into(), badminalgid, ::core::mem::transmute(pbadminkey.as_ptr()), pbadminkey.len() as _, ::core::mem::transmute(pbadminkcv.as_ptr()), pbadminkcv.len() as _, ::core::mem::transmute(pbpuk.as_ptr()), pbpuk.len() as _, ::core::mem::transmute(pbpin.as_ptr()), pbpin.len() as _, fgenerate.into(), pstatuscallback.into().abi(), ::core::mem::transmute(ppszinstanceid), ::core::mem::transmute(pfneedreboot)).ok()
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -257,7 +167,7 @@ impl ITpmVirtualSmartCardManager3 {
         P1: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).base__.base__.DestroyVirtualSmartCard)(::windows::core::Interface::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
+        (::windows::core::Vtable::vtable(self).base__.base__.DestroyVirtualSmartCard)(::windows::core::Vtable::as_raw(self), pszinstanceid.into(), pstatuscallback.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::Foundation::BOOL>(result__)
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -267,19 +177,19 @@ impl ITpmVirtualSmartCardManager3 {
         P1: ::std::convert::Into<super::super::Foundation::BOOL>,
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
-        (::windows::core::Interface::vtable(self).base__.CreateVirtualSmartCardWithPinPolicy)(
-            ::windows::core::Interface::as_raw(self),
+        (::windows::core::Vtable::vtable(self).base__.CreateVirtualSmartCardWithPinPolicy)(
+            ::windows::core::Vtable::as_raw(self),
             pszfriendlyname.into(),
             badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
+            ::core::mem::transmute(pbadminkey.as_ptr()),
             pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
+            ::core::mem::transmute(pbadminkcv.as_ptr()),
             pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
+            ::core::mem::transmute(pbpuk.as_ptr()),
             pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
+            ::core::mem::transmute(pbpin.as_ptr()),
             pbpin.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpinpolicy)),
+            ::core::mem::transmute(pbpinpolicy.as_ptr()),
             pbpinpolicy.len() as _,
             fgenerate.into(),
             pstatuscallback.into().abi(),
@@ -297,19 +207,19 @@ impl ITpmVirtualSmartCardManager3 {
         P2: ::std::convert::Into<::windows::core::InParam<'a, ITpmVirtualSmartCardManagerStatusCallback>>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).CreateVirtualSmartCardWithAttestation)(
-            ::windows::core::Interface::as_raw(self),
+        (::windows::core::Vtable::vtable(self).CreateVirtualSmartCardWithAttestation)(
+            ::windows::core::Vtable::as_raw(self),
             pszfriendlyname.into(),
             badminalgid,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkey)),
+            ::core::mem::transmute(pbadminkey.as_ptr()),
             pbadminkey.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbadminkcv)),
+            ::core::mem::transmute(pbadminkcv.as_ptr()),
             pbadminkcv.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpuk)),
+            ::core::mem::transmute(pbpuk.as_ptr()),
             pbpuk.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpin)),
+            ::core::mem::transmute(pbpin.as_ptr()),
             pbpin.len() as _,
-            ::core::mem::transmute(::windows::core::as_ptr_or_null(pbpinpolicy)),
+            ::core::mem::transmute(pbpinpolicy.as_ptr()),
             pbpinpolicy.len() as _,
             attestationtype,
             fgenerate.into(),
@@ -319,51 +229,7 @@ impl ITpmVirtualSmartCardManager3 {
         .from_abi::<::windows::core::PWSTR>(result__)
     }
 }
-impl ::core::convert::From<ITpmVirtualSmartCardManager3> for ::windows::core::IUnknown {
-    fn from(value: ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager3> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager3> for ::windows::core::IUnknown {
-    fn from(value: &ITpmVirtualSmartCardManager3) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<ITpmVirtualSmartCardManager3> for ITpmVirtualSmartCardManager {
-    fn from(value: ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager3> for &'a ITpmVirtualSmartCardManager {
-    fn from(value: &'a ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager3> for ITpmVirtualSmartCardManager {
-    fn from(value: &ITpmVirtualSmartCardManager3) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<ITpmVirtualSmartCardManager3> for ITpmVirtualSmartCardManager2 {
-    fn from(value: ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManager3> for &'a ITpmVirtualSmartCardManager2 {
-    fn from(value: &'a ITpmVirtualSmartCardManager3) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManager3> for ITpmVirtualSmartCardManager2 {
-    fn from(value: &ITpmVirtualSmartCardManager3) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
+::windows::core::interface_hierarchy!(ITpmVirtualSmartCardManager3, ::windows::core::IUnknown, ITpmVirtualSmartCardManager, ITpmVirtualSmartCardManager2);
 impl ::core::clone::Clone for ITpmVirtualSmartCardManager3 {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -380,8 +246,10 @@ impl ::core::fmt::Debug for ITpmVirtualSmartCardManager3 {
         f.debug_tuple("ITpmVirtualSmartCardManager3").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager3 {
+unsafe impl ::windows::core::Vtable for ITpmVirtualSmartCardManager3 {
     type Vtable = ITpmVirtualSmartCardManager3_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManager3 {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x3c745a97_f375_4150_be17_5950f694c699);
 }
 #[repr(C)]
@@ -398,27 +266,13 @@ pub struct ITpmVirtualSmartCardManager3_Vtbl {
 pub struct ITpmVirtualSmartCardManagerStatusCallback(::windows::core::IUnknown);
 impl ITpmVirtualSmartCardManagerStatusCallback {
     pub unsafe fn ReportProgress(&self, status: TPMVSCMGR_STATUS) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).ReportProgress)(::windows::core::Interface::as_raw(self), status).ok()
+        (::windows::core::Vtable::vtable(self).ReportProgress)(::windows::core::Vtable::as_raw(self), status).ok()
     }
     pub unsafe fn ReportError(&self, error: TPMVSCMGR_ERROR) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).ReportError)(::windows::core::Interface::as_raw(self), error).ok()
-    }
-}
-impl ::core::convert::From<ITpmVirtualSmartCardManagerStatusCallback> for ::windows::core::IUnknown {
-    fn from(value: ITpmVirtualSmartCardManagerStatusCallback) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITpmVirtualSmartCardManagerStatusCallback> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITpmVirtualSmartCardManagerStatusCallback) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITpmVirtualSmartCardManagerStatusCallback> for ::windows::core::IUnknown {
-    fn from(value: &ITpmVirtualSmartCardManagerStatusCallback) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).ReportError)(::windows::core::Vtable::as_raw(self), error).ok()
     }
 }
+::windows::core::interface_hierarchy!(ITpmVirtualSmartCardManagerStatusCallback, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ITpmVirtualSmartCardManagerStatusCallback {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -435,19 +289,24 @@ impl ::core::fmt::Debug for ITpmVirtualSmartCardManagerStatusCallback {
         f.debug_tuple("ITpmVirtualSmartCardManagerStatusCallback").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManagerStatusCallback {
+unsafe impl ::windows::core::Vtable for ITpmVirtualSmartCardManagerStatusCallback {
     type Vtable = ITpmVirtualSmartCardManagerStatusCallback_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITpmVirtualSmartCardManagerStatusCallback {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x1a1bb35f_abb8_451c_a1ae_33d98f1bef4a);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ITpmVirtualSmartCardManagerStatusCallback_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub ReportProgress: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, status: TPMVSCMGR_STATUS) -> ::windows::core::HRESULT,
     pub ReportError: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, error: TPMVSCMGR_ERROR) -> ::windows::core::HRESULT,
 }
 pub const RemoteTpmVirtualSmartCardManager: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x152ea2a8_70dc_4c59_8b2a_32aa3ca0dcac);
 #[doc = "*Required features: `\"Win32_Security_Tpm\"`*"]
+pub const TPMVSC_DEFAULT_ADMIN_ALGORITHM_ID: u32 = 130u32;
+pub const TpmVirtualSmartCardManager: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x16a18e86_7f6e_4c20_ad89_4ffc0db7a96a);
+#[doc = "*Required features: `\"Win32_Security_Tpm\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct TPMVSCMGR_ERROR(pub i32);
@@ -588,8 +447,5 @@ impl ::core::fmt::Debug for TPMVSC_ATTESTATION_TYPE {
         f.debug_tuple("TPMVSC_ATTESTATION_TYPE").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_Security_Tpm\"`*"]
-pub const TPMVSC_DEFAULT_ADMIN_ALGORITHM_ID: u32 = 130u32;
-pub const TpmVirtualSmartCardManager: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x16a18e86_7f6e_4c20_ad89_4ffc0db7a96a);
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
