@@ -16,7 +16,7 @@ impl IAmsiStream_Vtbl {
             this.Read(::core::mem::transmute_copy(&position), ::core::mem::transmute_copy(&size), ::core::mem::transmute_copy(&buffer), ::core::mem::transmute_copy(&readsize)).into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             GetAttribute: GetAttribute::<Identity, Impl, OFFSET>,
             Read: Read::<Identity, Impl, OFFSET>,
         }
@@ -43,7 +43,7 @@ impl IAntimalware_Vtbl {
             this.CloseSession(::core::mem::transmute_copy(&session))
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Scan: Scan::<Identity, Impl, OFFSET>,
             CloseSession: CloseSession::<Identity, Impl, OFFSET>,
         }
@@ -111,7 +111,7 @@ impl IAntimalwareProvider_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             Scan: Scan::<Identity, Impl, OFFSET>,
             CloseSession: CloseSession::<Identity, Impl, OFFSET>,
             DisplayName: DisplayName::<Identity, Impl, OFFSET>,
@@ -177,7 +177,7 @@ impl IAntimalwareUacProvider_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             UacScan: UacScan::<Identity, Impl, OFFSET>,
             DisplayName: DisplayName::<Identity, Impl, OFFSET>,
         }
