@@ -1,19 +1,13 @@
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JS_SOURCE_CONTEXT_NONE: u64 = 18446744073709551615u64;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsAddRef(r#ref: *const ::core::ffi::c_void, count: *mut u32) -> JsErrorCode {
+pub unsafe fn JsAddRef(r#ref: *const ::core::ffi::c_void, count: ::core::option::Option<*mut u32>) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsAddRef(r#ref: *const ::core::ffi::c_void, count: *mut u32) -> JsErrorCode;
     }
-    JsAddRef(::core::mem::transmute(r#ref), ::core::mem::transmute(count))
+    JsAddRef(::core::mem::transmute(r#ref), ::core::mem::transmute(count.unwrap_or(::std::ptr::null_mut())))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsBackgroundWorkItemCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void)>;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsBeforeCollectCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void)>;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
 pub unsafe fn JsBoolToBoolean(value: u8, booleanvalue: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
@@ -33,12 +27,12 @@ pub unsafe fn JsBooleanToBool(value: *const ::core::ffi::c_void, boolvalue: *mut
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsCallFunction(function: *const ::core::ffi::c_void, arguments: &[*const ::core::ffi::c_void], result: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
+pub unsafe fn JsCallFunction(function: *const ::core::ffi::c_void, arguments: &[*const ::core::ffi::c_void], result: ::core::option::Option<*mut *mut ::core::ffi::c_void>) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsCallFunction(function: *const ::core::ffi::c_void, arguments: *const *const ::core::ffi::c_void, argumentcount: u16, result: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsCallFunction(::core::mem::transmute(function), ::core::mem::transmute(::windows::core::as_ptr_or_null(arguments)), arguments.len() as _, ::core::mem::transmute(result))
+    JsCallFunction(::core::mem::transmute(function), ::core::mem::transmute(arguments.as_ptr()), arguments.len() as _, ::core::mem::transmute(result.unwrap_or(::std::ptr::null_mut())))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -56,7 +50,7 @@ pub unsafe fn JsConstructObject(function: *const ::core::ffi::c_void, arguments:
     extern "system" {
         fn JsConstructObject(function: *const ::core::ffi::c_void, arguments: *const *const ::core::ffi::c_void, argumentcount: u16, result: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsConstructObject(::core::mem::transmute(function), ::core::mem::transmute(::windows::core::as_ptr_or_null(arguments)), arguments.len() as _, ::core::mem::transmute(result))
+    JsConstructObject(::core::mem::transmute(function), ::core::mem::transmute(arguments.as_ptr()), arguments.len() as _, ::core::mem::transmute(result))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -142,21 +136,21 @@ pub unsafe fn JsCreateError(message: *const ::core::ffi::c_void, error: *mut *mu
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsCreateExternalObject(data: *const ::core::ffi::c_void, finalizecallback: JsFinalizeCallback, object: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
+pub unsafe fn JsCreateExternalObject(data: ::core::option::Option<*const ::core::ffi::c_void>, finalizecallback: JsFinalizeCallback, object: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsCreateExternalObject(data: *const ::core::ffi::c_void, finalizecallback: *mut ::core::ffi::c_void, object: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsCreateExternalObject(::core::mem::transmute(data), ::core::mem::transmute(finalizecallback), ::core::mem::transmute(object))
+    JsCreateExternalObject(::core::mem::transmute(data.unwrap_or(::std::ptr::null())), ::core::mem::transmute(finalizecallback), ::core::mem::transmute(object))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsCreateFunction(nativefunction: JsNativeFunction, callbackstate: *const ::core::ffi::c_void, function: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
+pub unsafe fn JsCreateFunction(nativefunction: JsNativeFunction, callbackstate: ::core::option::Option<*const ::core::ffi::c_void>, function: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsCreateFunction(nativefunction: *mut ::core::ffi::c_void, callbackstate: *const ::core::ffi::c_void, function: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsCreateFunction(::core::mem::transmute(nativefunction), ::core::mem::transmute(callbackstate), ::core::mem::transmute(function))
+    JsCreateFunction(::core::mem::transmute(nativefunction), ::core::mem::transmute(callbackstate.unwrap_or(::std::ptr::null())), ::core::mem::transmute(function))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -304,89 +298,6 @@ pub unsafe fn JsEquals(object1: *const ::core::ffi::c_void, object2: *const ::co
     JsEquals(::core::mem::transmute(object1), ::core::mem::transmute(object2), ::core::mem::transmute(result))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct JsErrorCode(pub u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsNoError: JsErrorCode = JsErrorCode(0u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCategoryUsage: JsErrorCode = JsErrorCode(65536u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorInvalidArgument: JsErrorCode = JsErrorCode(65537u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorNullArgument: JsErrorCode = JsErrorCode(65538u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorNoCurrentContext: JsErrorCode = JsErrorCode(65539u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorInExceptionState: JsErrorCode = JsErrorCode(65540u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorNotImplemented: JsErrorCode = JsErrorCode(65541u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorWrongThread: JsErrorCode = JsErrorCode(65542u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorRuntimeInUse: JsErrorCode = JsErrorCode(65543u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorBadSerializedScript: JsErrorCode = JsErrorCode(65544u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorInDisabledState: JsErrorCode = JsErrorCode(65545u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCannotDisableExecution: JsErrorCode = JsErrorCode(65546u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorHeapEnumInProgress: JsErrorCode = JsErrorCode(65547u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorArgumentNotObject: JsErrorCode = JsErrorCode(65548u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorInProfileCallback: JsErrorCode = JsErrorCode(65549u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorInThreadServiceCallback: JsErrorCode = JsErrorCode(65550u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCannotSerializeDebugScript: JsErrorCode = JsErrorCode(65551u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorAlreadyDebuggingContext: JsErrorCode = JsErrorCode(65552u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorAlreadyProfilingContext: JsErrorCode = JsErrorCode(65553u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorIdleNotEnabled: JsErrorCode = JsErrorCode(65554u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCategoryEngine: JsErrorCode = JsErrorCode(131072u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorOutOfMemory: JsErrorCode = JsErrorCode(131073u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCategoryScript: JsErrorCode = JsErrorCode(196608u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorScriptException: JsErrorCode = JsErrorCode(196609u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorScriptCompile: JsErrorCode = JsErrorCode(196610u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorScriptTerminated: JsErrorCode = JsErrorCode(196611u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorScriptEvalDisabled: JsErrorCode = JsErrorCode(196612u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorCategoryFatal: JsErrorCode = JsErrorCode(262144u32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsErrorFatal: JsErrorCode = JsErrorCode(262145u32);
-impl ::core::marker::Copy for JsErrorCode {}
-impl ::core::clone::Clone for JsErrorCode {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for JsErrorCode {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for JsErrorCode {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for JsErrorCode {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("JsErrorCode").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsFinalizeCallback = ::core::option::Option<unsafe extern "system" fn(data: *const ::core::ffi::c_void)>;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
 pub unsafe fn JsGetAndClearException(exception: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
@@ -616,12 +527,12 @@ pub unsafe fn JsHasProperty(object: *const ::core::ffi::c_void, propertyid: *con
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsIdle(nextidletick: *mut u32) -> JsErrorCode {
+pub unsafe fn JsIdle(nextidletick: ::core::option::Option<*mut u32>) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsIdle(nextidletick: *mut u32) -> JsErrorCode;
     }
-    JsIdle(::core::mem::transmute(nextidletick))
+    JsIdle(::core::mem::transmute(nextidletick.unwrap_or(::std::ptr::null_mut())))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -651,39 +562,6 @@ pub unsafe fn JsIsRuntimeExecutionDisabled(runtime: *const ::core::ffi::c_void,
     JsIsRuntimeExecutionDisabled(::core::mem::transmute(runtime), ::core::mem::transmute(isdisabled))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsMemoryAllocationCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void, allocationevent: JsMemoryEventType, allocationsize: usize) -> bool>;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct JsMemoryEventType(pub i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsMemoryAllocate: JsMemoryEventType = JsMemoryEventType(0i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsMemoryFree: JsMemoryEventType = JsMemoryEventType(1i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsMemoryFailure: JsMemoryEventType = JsMemoryEventType(2i32);
-impl ::core::marker::Copy for JsMemoryEventType {}
-impl ::core::clone::Clone for JsMemoryEventType {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for JsMemoryEventType {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for JsMemoryEventType {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for JsMemoryEventType {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("JsMemoryEventType").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsNativeFunction = ::core::option::Option<unsafe extern "system" fn(callee: *const ::core::ffi::c_void, isconstructcall: bool, arguments: *const *const ::core::ffi::c_void, argumentcount: u16, callbackstate: *const ::core::ffi::c_void) -> *mut ::core::ffi::c_void>;
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
 pub unsafe fn JsNumberToDouble(value: *const ::core::ffi::c_void, doublevalue: *mut f64) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
@@ -725,7 +603,7 @@ pub unsafe fn JsPointerToString(stringvalue: &[u16], value: *mut *mut ::core::ff
     extern "system" {
         fn JsPointerToString(stringvalue: ::windows::core::PCWSTR, stringlength: usize, value: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsPointerToString(::core::mem::transmute(::windows::core::as_ptr_or_null(stringvalue)), stringvalue.len() as _, ::core::mem::transmute(value))
+    JsPointerToString(::core::mem::transmute(stringvalue.as_ptr()), stringvalue.len() as _, ::core::mem::transmute(value))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -738,12 +616,12 @@ pub unsafe fn JsPreventExtension(object: *const ::core::ffi::c_void) -> JsErrorC
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsRelease(r#ref: *const ::core::ffi::c_void, count: *mut u32) -> JsErrorCode {
+pub unsafe fn JsRelease(r#ref: *const ::core::ffi::c_void, count: ::core::option::Option<*mut u32>) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsRelease(r#ref: *const ::core::ffi::c_void, count: *mut u32) -> JsErrorCode;
     }
-    JsRelease(::core::mem::transmute(r#ref), ::core::mem::transmute(count))
+    JsRelease(::core::mem::transmute(r#ref), ::core::mem::transmute(count.unwrap_or(::std::ptr::null_mut())))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -772,72 +650,8 @@ where
     JsRunSerializedScript(script.into(), ::core::mem::transmute(buffer), sourcecontext, sourceurl.into(), ::core::mem::transmute(result))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct JsRuntimeAttributes(pub i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeNone: JsRuntimeAttributes = JsRuntimeAttributes(0i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeDisableBackgroundWork: JsRuntimeAttributes = JsRuntimeAttributes(1i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeAllowScriptInterrupt: JsRuntimeAttributes = JsRuntimeAttributes(2i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeEnableIdleProcessing: JsRuntimeAttributes = JsRuntimeAttributes(4i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeDisableNativeCodeGeneration: JsRuntimeAttributes = JsRuntimeAttributes(8i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeAttributeDisableEval: JsRuntimeAttributes = JsRuntimeAttributes(16i32);
-impl ::core::marker::Copy for JsRuntimeAttributes {}
-impl ::core::clone::Clone for JsRuntimeAttributes {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for JsRuntimeAttributes {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for JsRuntimeAttributes {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for JsRuntimeAttributes {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("JsRuntimeAttributes").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct JsRuntimeVersion(pub i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeVersion10: JsRuntimeVersion = JsRuntimeVersion(0i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeVersion11: JsRuntimeVersion = JsRuntimeVersion(1i32);
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub const JsRuntimeVersionEdge: JsRuntimeVersion = JsRuntimeVersion(-1i32);
-impl ::core::marker::Copy for JsRuntimeVersion {}
-impl ::core::clone::Clone for JsRuntimeVersion {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for JsRuntimeVersion {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for JsRuntimeVersion {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for JsRuntimeVersion {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("JsRuntimeVersion").field(&self.0).finish()
-    }
-}
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsSerializeScript<'a, P0>(script: P0, buffer: *mut u8, buffersize: *mut u32) -> JsErrorCode
+pub unsafe fn JsSerializeScript<'a, P0>(script: P0, buffer: ::core::option::Option<*mut u8>, buffersize: *mut u32) -> JsErrorCode
 where
     P0: ::std::convert::Into<::windows::core::PCWSTR>,
 {
@@ -845,7 +659,7 @@ where
     extern "system" {
         fn JsSerializeScript(script: ::windows::core::PCWSTR, buffer: *mut u8, buffersize: *mut u32) -> JsErrorCode;
     }
-    JsSerializeScript(script.into(), ::core::mem::transmute(buffer), ::core::mem::transmute(buffersize))
+    JsSerializeScript(script.into(), ::core::mem::transmute(buffer.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(buffersize))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -867,12 +681,12 @@ pub unsafe fn JsSetException(exception: *const ::core::ffi::c_void) -> JsErrorCo
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsSetExternalData(object: *const ::core::ffi::c_void, externaldata: *const ::core::ffi::c_void) -> JsErrorCode {
+pub unsafe fn JsSetExternalData(object: *const ::core::ffi::c_void, externaldata: ::core::option::Option<*const ::core::ffi::c_void>) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsSetExternalData(object: *const ::core::ffi::c_void, externaldata: *const ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsSetExternalData(::core::mem::transmute(object), ::core::mem::transmute(externaldata))
+    JsSetExternalData(::core::mem::transmute(object), ::core::mem::transmute(externaldata.unwrap_or(::std::ptr::null())))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -903,21 +717,21 @@ pub unsafe fn JsSetPrototype(object: *const ::core::ffi::c_void, prototypeobject
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsSetRuntimeBeforeCollectCallback(runtime: *const ::core::ffi::c_void, callbackstate: *const ::core::ffi::c_void, beforecollectcallback: JsBeforeCollectCallback) -> JsErrorCode {
+pub unsafe fn JsSetRuntimeBeforeCollectCallback(runtime: *const ::core::ffi::c_void, callbackstate: ::core::option::Option<*const ::core::ffi::c_void>, beforecollectcallback: JsBeforeCollectCallback) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsSetRuntimeBeforeCollectCallback(runtime: *const ::core::ffi::c_void, callbackstate: *const ::core::ffi::c_void, beforecollectcallback: *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsSetRuntimeBeforeCollectCallback(::core::mem::transmute(runtime), ::core::mem::transmute(callbackstate), ::core::mem::transmute(beforecollectcallback))
+    JsSetRuntimeBeforeCollectCallback(::core::mem::transmute(runtime), ::core::mem::transmute(callbackstate.unwrap_or(::std::ptr::null())), ::core::mem::transmute(beforecollectcallback))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
-pub unsafe fn JsSetRuntimeMemoryAllocationCallback(runtime: *const ::core::ffi::c_void, callbackstate: *const ::core::ffi::c_void, allocationcallback: JsMemoryAllocationCallback) -> JsErrorCode {
+pub unsafe fn JsSetRuntimeMemoryAllocationCallback(runtime: *const ::core::ffi::c_void, callbackstate: ::core::option::Option<*const ::core::ffi::c_void>, allocationcallback: JsMemoryAllocationCallback) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn JsSetRuntimeMemoryAllocationCallback(runtime: *const ::core::ffi::c_void, callbackstate: *const ::core::ffi::c_void, allocationcallback: *mut ::core::ffi::c_void) -> JsErrorCode;
     }
-    JsSetRuntimeMemoryAllocationCallback(::core::mem::transmute(runtime), ::core::mem::transmute(callbackstate), ::core::mem::transmute(allocationcallback))
+    JsSetRuntimeMemoryAllocationCallback(::core::mem::transmute(runtime), ::core::mem::transmute(callbackstate.unwrap_or(::std::ptr::null())), ::core::mem::transmute(allocationcallback))
 }
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[inline]
@@ -996,18 +810,202 @@ pub unsafe fn JsStringToPointer(value: *const ::core::ffi::c_void, stringvalue:
     }
     JsStringToPointer(::core::mem::transmute(value), ::core::mem::transmute(stringvalue), ::core::mem::transmute(stringlength))
 }
-#[doc = "*Required features: `\"Win32_System_Js\"`*"]
-pub type JsThreadServiceCallback = ::core::option::Option<unsafe extern "system" fn(callback: JsBackgroundWorkItemCallback, callbackstate: *const ::core::ffi::c_void) -> bool>;
 #[doc = "*Required features: `\"Win32_System_Js\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
 #[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
 #[inline]
 pub unsafe fn JsValueToVariant(object: *const ::core::ffi::c_void, variant: *mut super::Com::VARIANT) -> JsErrorCode {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
-        fn JsValueToVariant(object: *const ::core::ffi::c_void, variant: *mut super::Com::VARIANT) -> JsErrorCode;
+        fn JsValueToVariant(object: *const ::core::ffi::c_void, variant: *mut ::core::mem::ManuallyDrop<super::Com::VARIANT>) -> JsErrorCode;
     }
     JsValueToVariant(::core::mem::transmute(object), ::core::mem::transmute(variant))
 }
+#[doc = "*Required features: `\"Win32_System_Js\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
+#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
+#[inline]
+pub unsafe fn JsVariantToValue(variant: *const super::Com::VARIANT, value: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn JsVariantToValue(variant: *const ::core::mem::ManuallyDrop<super::Com::VARIANT>, value: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
+    }
+    JsVariantToValue(::core::mem::transmute(variant), ::core::mem::transmute(value))
+}
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JS_SOURCE_CONTEXT_NONE: u64 = 18446744073709551615u64;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct JsErrorCode(pub u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsNoError: JsErrorCode = JsErrorCode(0u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCategoryUsage: JsErrorCode = JsErrorCode(65536u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorInvalidArgument: JsErrorCode = JsErrorCode(65537u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorNullArgument: JsErrorCode = JsErrorCode(65538u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorNoCurrentContext: JsErrorCode = JsErrorCode(65539u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorInExceptionState: JsErrorCode = JsErrorCode(65540u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorNotImplemented: JsErrorCode = JsErrorCode(65541u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorWrongThread: JsErrorCode = JsErrorCode(65542u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorRuntimeInUse: JsErrorCode = JsErrorCode(65543u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorBadSerializedScript: JsErrorCode = JsErrorCode(65544u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorInDisabledState: JsErrorCode = JsErrorCode(65545u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCannotDisableExecution: JsErrorCode = JsErrorCode(65546u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorHeapEnumInProgress: JsErrorCode = JsErrorCode(65547u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorArgumentNotObject: JsErrorCode = JsErrorCode(65548u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorInProfileCallback: JsErrorCode = JsErrorCode(65549u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorInThreadServiceCallback: JsErrorCode = JsErrorCode(65550u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCannotSerializeDebugScript: JsErrorCode = JsErrorCode(65551u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorAlreadyDebuggingContext: JsErrorCode = JsErrorCode(65552u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorAlreadyProfilingContext: JsErrorCode = JsErrorCode(65553u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorIdleNotEnabled: JsErrorCode = JsErrorCode(65554u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCategoryEngine: JsErrorCode = JsErrorCode(131072u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorOutOfMemory: JsErrorCode = JsErrorCode(131073u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCategoryScript: JsErrorCode = JsErrorCode(196608u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorScriptException: JsErrorCode = JsErrorCode(196609u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorScriptCompile: JsErrorCode = JsErrorCode(196610u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorScriptTerminated: JsErrorCode = JsErrorCode(196611u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorScriptEvalDisabled: JsErrorCode = JsErrorCode(196612u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorCategoryFatal: JsErrorCode = JsErrorCode(262144u32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsErrorFatal: JsErrorCode = JsErrorCode(262145u32);
+impl ::core::marker::Copy for JsErrorCode {}
+impl ::core::clone::Clone for JsErrorCode {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for JsErrorCode {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for JsErrorCode {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for JsErrorCode {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("JsErrorCode").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct JsMemoryEventType(pub i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsMemoryAllocate: JsMemoryEventType = JsMemoryEventType(0i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsMemoryFree: JsMemoryEventType = JsMemoryEventType(1i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsMemoryFailure: JsMemoryEventType = JsMemoryEventType(2i32);
+impl ::core::marker::Copy for JsMemoryEventType {}
+impl ::core::clone::Clone for JsMemoryEventType {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for JsMemoryEventType {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for JsMemoryEventType {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for JsMemoryEventType {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("JsMemoryEventType").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct JsRuntimeAttributes(pub i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeNone: JsRuntimeAttributes = JsRuntimeAttributes(0i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeDisableBackgroundWork: JsRuntimeAttributes = JsRuntimeAttributes(1i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeAllowScriptInterrupt: JsRuntimeAttributes = JsRuntimeAttributes(2i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeEnableIdleProcessing: JsRuntimeAttributes = JsRuntimeAttributes(4i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeDisableNativeCodeGeneration: JsRuntimeAttributes = JsRuntimeAttributes(8i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeAttributeDisableEval: JsRuntimeAttributes = JsRuntimeAttributes(16i32);
+impl ::core::marker::Copy for JsRuntimeAttributes {}
+impl ::core::clone::Clone for JsRuntimeAttributes {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for JsRuntimeAttributes {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for JsRuntimeAttributes {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for JsRuntimeAttributes {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("JsRuntimeAttributes").field(&self.0).finish()
+    }
+}
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct JsRuntimeVersion(pub i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeVersion10: JsRuntimeVersion = JsRuntimeVersion(0i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeVersion11: JsRuntimeVersion = JsRuntimeVersion(1i32);
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub const JsRuntimeVersionEdge: JsRuntimeVersion = JsRuntimeVersion(-1i32);
+impl ::core::marker::Copy for JsRuntimeVersion {}
+impl ::core::clone::Clone for JsRuntimeVersion {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for JsRuntimeVersion {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for JsRuntimeVersion {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for JsRuntimeVersion {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("JsRuntimeVersion").field(&self.0).finish()
+    }
+}
 #[doc = "*Required features: `\"Win32_System_Js\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
@@ -1049,15 +1047,17 @@ impl ::core::fmt::Debug for JsValueType {
         f.debug_tuple("JsValueType").field(&self.0).finish()
     }
 }
-#[doc = "*Required features: `\"Win32_System_Js\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
-#[inline]
-pub unsafe fn JsVariantToValue(variant: *const super::Com::VARIANT, value: *mut *mut ::core::ffi::c_void) -> JsErrorCode {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn JsVariantToValue(variant: *const super::Com::VARIANT, value: *mut *mut ::core::ffi::c_void) -> JsErrorCode;
-    }
-    JsVariantToValue(::core::mem::transmute(variant), ::core::mem::transmute(value))
-}
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsBackgroundWorkItemCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void)>;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsBeforeCollectCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void)>;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsFinalizeCallback = ::core::option::Option<unsafe extern "system" fn(data: *const ::core::ffi::c_void)>;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsMemoryAllocationCallback = ::core::option::Option<unsafe extern "system" fn(callbackstate: *const ::core::ffi::c_void, allocationevent: JsMemoryEventType, allocationsize: usize) -> bool>;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsNativeFunction = ::core::option::Option<unsafe extern "system" fn(callee: *const ::core::ffi::c_void, isconstructcall: bool, arguments: *const *const ::core::ffi::c_void, argumentcount: u16, callbackstate: *const ::core::ffi::c_void) -> *mut ::core::ffi::c_void>;
+#[doc = "*Required features: `\"Win32_System_Js\"`*"]
+pub type JsThreadServiceCallback = ::core::option::Option<unsafe extern "system" fn(callback: JsBackgroundWorkItemCallback, callbackstate: *const ::core::ffi::c_void) -> bool>;
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
