@@ -1,34 +1,3 @@
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_System_Memory_NonVolatile\"`*"]
-pub struct NV_MEMORY_RANGE {
-    pub BaseAddress: *mut ::core::ffi::c_void,
-    pub Length: usize,
-}
-impl ::core::marker::Copy for NV_MEMORY_RANGE {}
-impl ::core::clone::Clone for NV_MEMORY_RANGE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::fmt::Debug for NV_MEMORY_RANGE {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_struct("NV_MEMORY_RANGE").field("BaseAddress", &self.BaseAddress).field("Length", &self.Length).finish()
-    }
-}
-unsafe impl ::windows::core::Abi for NV_MEMORY_RANGE {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for NV_MEMORY_RANGE {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NV_MEMORY_RANGE>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for NV_MEMORY_RANGE {}
-impl ::core::default::Default for NV_MEMORY_RANGE {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
 #[doc = "*Required features: `\"Win32_System_Memory_NonVolatile\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 #[inline]
@@ -67,7 +36,7 @@ pub unsafe fn RtlFlushNonVolatileMemoryRanges(nvtoken: *const ::core::ffi::c_voi
     extern "system" {
         fn RtlFlushNonVolatileMemoryRanges(nvtoken: *const ::core::ffi::c_void, nvranges: *const NV_MEMORY_RANGE, numranges: usize, flags: u32) -> u32;
     }
-    RtlFlushNonVolatileMemoryRanges(::core::mem::transmute(nvtoken), ::core::mem::transmute(::windows::core::as_ptr_or_null(nvranges)), nvranges.len() as _, flags)
+    RtlFlushNonVolatileMemoryRanges(::core::mem::transmute(nvtoken), ::core::mem::transmute(nvranges.as_ptr()), nvranges.len() as _, flags)
 }
 #[doc = "*Required features: `\"Win32_System_Memory_NonVolatile\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
@@ -99,5 +68,36 @@ pub unsafe fn RtlWriteNonVolatileMemory(nvtoken: *const ::core::ffi::c_void, nvd
     }
     RtlWriteNonVolatileMemory(::core::mem::transmute(nvtoken), ::core::mem::transmute(nvdestination), ::core::mem::transmute(source), size, flags)
 }
+#[repr(C)]
+#[doc = "*Required features: `\"Win32_System_Memory_NonVolatile\"`*"]
+pub struct NV_MEMORY_RANGE {
+    pub BaseAddress: *mut ::core::ffi::c_void,
+    pub Length: usize,
+}
+impl ::core::marker::Copy for NV_MEMORY_RANGE {}
+impl ::core::clone::Clone for NV_MEMORY_RANGE {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::fmt::Debug for NV_MEMORY_RANGE {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("NV_MEMORY_RANGE").field("BaseAddress", &self.BaseAddress).field("Length", &self.Length).finish()
+    }
+}
+unsafe impl ::windows::core::Abi for NV_MEMORY_RANGE {
+    type Abi = Self;
+}
+impl ::core::cmp::PartialEq for NV_MEMORY_RANGE {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<NV_MEMORY_RANGE>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for NV_MEMORY_RANGE {}
+impl ::core::default::Default for NV_MEMORY_RANGE {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
