@@ -1,7 +1,6 @@
-#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 pub const PERCEPTIONFIELD_StateStream_TimeStamps: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xaa886119_f32f_49bf_92ca_f9ddf784d297);
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_MixedReality'*"]
+#[doc = "*Required features: `\"Win32_System_MixedReality\"`*"]
 pub struct PERCEPTION_PAYLOAD_FIELD {
     pub FieldId: ::windows::core::GUID,
     pub OffsetInBytes: u32,
@@ -33,7 +32,7 @@ impl ::core::default::Default for PERCEPTION_PAYLOAD_FIELD {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_System_MixedReality'*"]
+#[doc = "*Required features: `\"Win32_System_MixedReality\"`*"]
 pub struct PERCEPTION_STATE_STREAM_TIMESTAMPS {
     pub InputTimestampInQpcCounts: i64,
     pub AvailableTimestampInQpcCounts: i64,
