@@ -1,3 +1,23 @@
+#[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn SRSetRestorePointA(prestoreptspec: *const RESTOREPOINTINFOA, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn SRSetRestorePointA(prestoreptspec: *const RESTOREPOINTINFOA, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL;
+    }
+    SRSetRestorePointA(::core::mem::transmute(prestoreptspec), ::core::mem::transmute(psmgrstatus))
+}
+#[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn SRSetRestorePointW(prestoreptspec: *const RESTOREPOINTINFOW, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn SRSetRestorePointW(prestoreptspec: *const RESTOREPOINTINFOW, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL;
+    }
+    SRSetRestorePointW(::core::mem::transmute(prestoreptspec), ::core::mem::transmute(psmgrstatus))
+}
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
 pub const ACCESSIBILITY_SETTING: u32 = 3u32;
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
@@ -34,69 +54,12 @@ pub const MIN_RPT: u32 = 0u32;
 pub const OE_SETTING: u32 = 4u32;
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
 pub const RESTORE: u32 = 6u32;
-#[repr(C, packed(1))]
-#[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-pub struct RESTOREPOINTINFOA {
-    pub dwEventType: RESTOREPOINTINFO_EVENT_TYPE,
-    pub dwRestorePtType: RESTOREPOINTINFO_TYPE,
-    pub llSequenceNumber: i64,
-    pub szDescription: [super::super::Foundation::CHAR; 64],
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::marker::Copy for RESTOREPOINTINFOA {}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::clone::Clone for RESTOREPOINTINFOA {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for RESTOREPOINTINFOA {
-    type Abi = Self;
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::cmp::PartialEq for RESTOREPOINTINFOA {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<RESTOREPOINTINFOA>()) == 0 }
-    }
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::cmp::Eq for RESTOREPOINTINFOA {}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::default::Default for RESTOREPOINTINFOA {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[repr(C, packed(1))]
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
-pub struct RESTOREPOINTINFOW {
-    pub dwEventType: RESTOREPOINTINFO_EVENT_TYPE,
-    pub dwRestorePtType: RESTOREPOINTINFO_TYPE,
-    pub llSequenceNumber: i64,
-    pub szDescription: [u16; 256],
-}
-impl ::core::marker::Copy for RESTOREPOINTINFOW {}
-impl ::core::clone::Clone for RESTOREPOINTINFOW {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-unsafe impl ::windows::core::Abi for RESTOREPOINTINFOW {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for RESTOREPOINTINFOW {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<RESTOREPOINTINFOW>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for RESTOREPOINTINFOW {}
-impl ::core::default::Default for RESTOREPOINTINFOW {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
+pub const WINDOWS_BOOT: u32 = 9u32;
+#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
+pub const WINDOWS_SHUTDOWN: u32 = 8u32;
+#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
+pub const WINDOWS_UPDATE: u32 = 17u32;
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
@@ -161,25 +124,104 @@ impl ::core::fmt::Debug for RESTOREPOINTINFO_TYPE {
         f.debug_tuple("RESTOREPOINTINFO_TYPE").field(&self.0).finish()
     }
 }
+#[repr(C, packed(1))]
 #[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn SRSetRestorePointA(prestoreptspec: *const RESTOREPOINTINFOA, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn SRSetRestorePointA(prestoreptspec: *const RESTOREPOINTINFOA, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL;
-    }
-    SRSetRestorePointA(::core::mem::transmute(prestoreptspec), ::core::mem::transmute(psmgrstatus))
+pub struct RESTOREPOINTINFOA {
+    pub dwEventType: RESTOREPOINTINFO_EVENT_TYPE,
+    pub dwRestorePtType: RESTOREPOINTINFO_TYPE,
+    pub llSequenceNumber: i64,
+    pub szDescription: [super::super::Foundation::CHAR; 64],
 }
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::marker::Copy for RESTOREPOINTINFOA {}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::clone::Clone for RESTOREPOINTINFOA {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+#[cfg(feature = "Win32_Foundation")]
+unsafe impl ::windows::core::Abi for RESTOREPOINTINFOA {
+    type Abi = Self;
+}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::cmp::PartialEq for RESTOREPOINTINFOA {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<RESTOREPOINTINFOA>()) == 0 }
+    }
+}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::cmp::Eq for RESTOREPOINTINFOA {}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::default::Default for RESTOREPOINTINFOA {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
+#[repr(C, packed(1))]
 #[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
-#[inline]
-pub unsafe fn SRSetRestorePointW(prestoreptspec: *const RESTOREPOINTINFOW, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn SRSetRestorePointW(prestoreptspec: *const RESTOREPOINTINFOW, psmgrstatus: *mut STATEMGRSTATUS) -> super::super::Foundation::BOOL;
+pub struct RESTOREPOINTINFOEX {
+    pub ftCreation: super::super::Foundation::FILETIME,
+    pub dwEventType: u32,
+    pub dwRestorePtType: u32,
+    pub dwRPNum: u32,
+    pub szDescription: [u16; 256],
+}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::marker::Copy for RESTOREPOINTINFOEX {}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::clone::Clone for RESTOREPOINTINFOEX {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+#[cfg(feature = "Win32_Foundation")]
+unsafe impl ::windows::core::Abi for RESTOREPOINTINFOEX {
+    type Abi = Self;
+}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::cmp::PartialEq for RESTOREPOINTINFOEX {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<RESTOREPOINTINFOEX>()) == 0 }
+    }
+}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::cmp::Eq for RESTOREPOINTINFOEX {}
+#[cfg(feature = "Win32_Foundation")]
+impl ::core::default::Default for RESTOREPOINTINFOEX {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
+#[repr(C, packed(1))]
+#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
+pub struct RESTOREPOINTINFOW {
+    pub dwEventType: RESTOREPOINTINFO_EVENT_TYPE,
+    pub dwRestorePtType: RESTOREPOINTINFO_TYPE,
+    pub llSequenceNumber: i64,
+    pub szDescription: [u16; 256],
+}
+impl ::core::marker::Copy for RESTOREPOINTINFOW {}
+impl ::core::clone::Clone for RESTOREPOINTINFOW {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+unsafe impl ::windows::core::Abi for RESTOREPOINTINFOW {
+    type Abi = Self;
+}
+impl ::core::cmp::PartialEq for RESTOREPOINTINFOW {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<RESTOREPOINTINFOW>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for RESTOREPOINTINFOW {}
+impl ::core::default::Default for RESTOREPOINTINFOW {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
     }
-    SRSetRestorePointW(::core::mem::transmute(prestoreptspec), ::core::mem::transmute(psmgrstatus))
 }
 #[repr(C, packed(1))]
 #[doc = "*Required features: `\"Win32_System_Restore\"`*"]
@@ -207,47 +249,5 @@ impl ::core::default::Default for STATEMGRSTATUS {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
-pub const WINDOWS_BOOT: u32 = 9u32;
-#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
-pub const WINDOWS_SHUTDOWN: u32 = 8u32;
-#[doc = "*Required features: `\"Win32_System_Restore\"`*"]
-pub const WINDOWS_UPDATE: u32 = 17u32;
-#[repr(C, packed(1))]
-#[doc = "*Required features: `\"Win32_System_Restore\"`, `\"Win32_Foundation\"`*"]
-#[cfg(feature = "Win32_Foundation")]
-pub struct _RESTOREPTINFOEX {
-    pub ftCreation: super::super::Foundation::FILETIME,
-    pub dwEventType: u32,
-    pub dwRestorePtType: u32,
-    pub dwRPNum: u32,
-    pub szDescription: [u16; 256],
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::marker::Copy for _RESTOREPTINFOEX {}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::clone::Clone for _RESTOREPTINFOEX {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-#[cfg(feature = "Win32_Foundation")]
-unsafe impl ::windows::core::Abi for _RESTOREPTINFOEX {
-    type Abi = Self;
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::cmp::PartialEq for _RESTOREPTINFOEX {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<_RESTOREPTINFOEX>()) == 0 }
-    }
-}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::cmp::Eq for _RESTOREPTINFOEX {}
-#[cfg(feature = "Win32_Foundation")]
-impl ::core::default::Default for _RESTOREPTINFOEX {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
