@@ -4,27 +4,13 @@ pub struct IWsbApplicationAsync(::windows::core::IUnknown);
 impl IWsbApplicationAsync {
     pub unsafe fn QueryStatus(&self) -> ::windows::core::Result<::windows::core::HRESULT> {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).QueryStatus)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<::windows::core::HRESULT>(result__)
+        (::windows::core::Vtable::vtable(self).QueryStatus)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<::windows::core::HRESULT>(result__)
     }
     pub unsafe fn Abort(&self) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).Abort)(::windows::core::Interface::as_raw(self)).ok()
-    }
-}
-impl ::core::convert::From<IWsbApplicationAsync> for ::windows::core::IUnknown {
-    fn from(value: IWsbApplicationAsync) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IWsbApplicationAsync> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IWsbApplicationAsync) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IWsbApplicationAsync> for ::windows::core::IUnknown {
-    fn from(value: &IWsbApplicationAsync) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).Abort)(::windows::core::Vtable::as_raw(self)).ok()
     }
 }
+::windows::core::interface_hierarchy!(IWsbApplicationAsync, ::windows::core::IUnknown);
 impl ::core::clone::Clone for IWsbApplicationAsync {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -41,14 +27,16 @@ impl ::core::fmt::Debug for IWsbApplicationAsync {
         f.debug_tuple("IWsbApplicationAsync").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for IWsbApplicationAsync {
+unsafe impl ::windows::core::Vtable for IWsbApplicationAsync {
     type Vtable = IWsbApplicationAsync_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IWsbApplicationAsync {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x0843f6f7_895c_44a6_b0c2_05a5022aa3a1);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IWsbApplicationAsync_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub QueryStatus: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, phrresult: *mut ::windows::core::HRESULT) -> ::windows::core::HRESULT,
     pub Abort: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
@@ -63,24 +51,10 @@ impl IWsbApplicationBackupSupport {
         P2: ::std::convert::Into<::windows::core::PCWSTR>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).CheckConsistency)(::windows::core::Interface::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), ::core::mem::transmute(cvolumes), ::core::mem::transmute(rgwszsourcevolumepath), ::core::mem::transmute(rgwszsnapshotvolumepath), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<IWsbApplicationAsync>(result__)
-    }
-}
-impl ::core::convert::From<IWsbApplicationBackupSupport> for ::windows::core::IUnknown {
-    fn from(value: IWsbApplicationBackupSupport) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IWsbApplicationBackupSupport> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IWsbApplicationBackupSupport) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IWsbApplicationBackupSupport> for ::windows::core::IUnknown {
-    fn from(value: &IWsbApplicationBackupSupport) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).CheckConsistency)(::windows::core::Vtable::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), cvolumes, ::core::mem::transmute(rgwszsourcevolumepath), ::core::mem::transmute(rgwszsnapshotvolumepath), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<IWsbApplicationAsync>(result__)
     }
 }
+::windows::core::interface_hierarchy!(IWsbApplicationBackupSupport, ::windows::core::IUnknown);
 impl ::core::clone::Clone for IWsbApplicationBackupSupport {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -97,14 +71,16 @@ impl ::core::fmt::Debug for IWsbApplicationBackupSupport {
         f.debug_tuple("IWsbApplicationBackupSupport").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for IWsbApplicationBackupSupport {
+unsafe impl ::windows::core::Vtable for IWsbApplicationBackupSupport {
     type Vtable = IWsbApplicationBackupSupport_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IWsbApplicationBackupSupport {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x1eff3510_4a27_46ad_b9e0_08332f0f4f6d);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IWsbApplicationBackupSupport_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub CheckConsistency: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, wszwritermetadata: ::windows::core::PCWSTR, wszcomponentname: ::windows::core::PCWSTR, wszcomponentlogicalpath: ::windows::core::PCWSTR, cvolumes: u32, rgwszsourcevolumepath: *const ::windows::core::PWSTR, rgwszsnapshotvolumepath: *const ::windows::core::PWSTR, ppasync: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
 #[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
@@ -120,7 +96,7 @@ impl IWsbApplicationRestoreSupport {
         P2: ::std::convert::Into<::windows::core::PCWSTR>,
         P3: ::std::convert::Into<super::super::Foundation::BOOLEAN>,
     {
-        (::windows::core::Interface::vtable(self).PreRestore)(::windows::core::Interface::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), bnorollforward.into()).ok()
+        (::windows::core::Vtable::vtable(self).PreRestore)(::windows::core::Vtable::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), bnorollforward.into()).ok()
     }
     #[doc = "*Required features: `\"Win32_Foundation\"`*"]
     #[cfg(feature = "Win32_Foundation")]
@@ -131,31 +107,17 @@ impl IWsbApplicationRestoreSupport {
         P2: ::std::convert::Into<::windows::core::PCWSTR>,
         P3: ::std::convert::Into<super::super::Foundation::BOOLEAN>,
     {
-        (::windows::core::Interface::vtable(self).PostRestore)(::windows::core::Interface::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), bnorollforward.into()).ok()
+        (::windows::core::Vtable::vtable(self).PostRestore)(::windows::core::Vtable::as_raw(self), wszwritermetadata.into(), wszcomponentname.into(), wszcomponentlogicalpath.into(), bnorollforward.into()).ok()
     }
     pub unsafe fn OrderComponents(&self, ccomponents: u32, rgcomponentname: *const ::windows::core::PWSTR, rgcomponentlogicalpaths: *const ::windows::core::PWSTR, prgcomponentname: *mut *mut ::windows::core::PWSTR, prgcomponentlogicalpath: *mut *mut ::windows::core::PWSTR) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).OrderComponents)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(ccomponents), ::core::mem::transmute(rgcomponentname), ::core::mem::transmute(rgcomponentlogicalpaths), ::core::mem::transmute(prgcomponentname), ::core::mem::transmute(prgcomponentlogicalpath)).ok()
+        (::windows::core::Vtable::vtable(self).OrderComponents)(::windows::core::Vtable::as_raw(self), ccomponents, ::core::mem::transmute(rgcomponentname), ::core::mem::transmute(rgcomponentlogicalpaths), ::core::mem::transmute(prgcomponentname), ::core::mem::transmute(prgcomponentlogicalpath)).ok()
     }
     pub unsafe fn IsRollForwardSupported(&self) -> ::windows::core::Result<u8> {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).IsRollForwardSupported)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u8>(result__)
-    }
-}
-impl ::core::convert::From<IWsbApplicationRestoreSupport> for ::windows::core::IUnknown {
-    fn from(value: IWsbApplicationRestoreSupport) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IWsbApplicationRestoreSupport> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IWsbApplicationRestoreSupport) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IWsbApplicationRestoreSupport> for ::windows::core::IUnknown {
-    fn from(value: &IWsbApplicationRestoreSupport) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).IsRollForwardSupported)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u8>(result__)
     }
 }
+::windows::core::interface_hierarchy!(IWsbApplicationRestoreSupport, ::windows::core::IUnknown);
 impl ::core::clone::Clone for IWsbApplicationRestoreSupport {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -172,14 +134,16 @@ impl ::core::fmt::Debug for IWsbApplicationRestoreSupport {
         f.debug_tuple("IWsbApplicationRestoreSupport").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for IWsbApplicationRestoreSupport {
+unsafe impl ::windows::core::Vtable for IWsbApplicationRestoreSupport {
     type Vtable = IWsbApplicationRestoreSupport_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IWsbApplicationRestoreSupport {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x8d3bdb38_4ee8_4718_85f9_c7dbc4ab77aa);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IWsbApplicationRestoreSupport_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_Foundation")]
     pub PreRestore: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, wszwritermetadata: ::windows::core::PCWSTR, wszcomponentname: ::windows::core::PCWSTR, wszcomponentlogicalpath: ::windows::core::PCWSTR, bnorollforward: super::super::Foundation::BOOLEAN) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Foundation"))]
@@ -197,6 +161,43 @@ pub const WSBAPP_ASYNC_IN_PROGRESS: ::windows::core::HRESULT = ::windows::core::
 pub const WSB_MAX_OB_STATUS_ENTRY: u32 = 5u32;
 #[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
 pub const WSB_MAX_OB_STATUS_VALUE_TYPE_PAIR: u32 = 5u32;
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct WSB_OB_STATUS_ENTRY_PAIR_TYPE(pub i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_UNDEFINED: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(0i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_STRING: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(1i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_NUMBER: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(2i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_DATETIME: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(3i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_TIME: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(4i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_SIZE: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(5i32);
+#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
+pub const WSB_OB_ET_MAX: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(6i32);
+impl ::core::marker::Copy for WSB_OB_STATUS_ENTRY_PAIR_TYPE {}
+impl ::core::clone::Clone for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("WSB_OB_STATUS_ENTRY_PAIR_TYPE").field(&self.0).finish()
+    }
+}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_System_ServerBackup\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
@@ -273,43 +274,6 @@ impl ::core::default::Default for WSB_OB_STATUS_ENTRY {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct WSB_OB_STATUS_ENTRY_PAIR_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_UNDEFINED: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_STRING: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_NUMBER: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(2i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_DATETIME: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(3i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_TIME: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(4i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_SIZE: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(5i32);
-#[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
-pub const WSB_OB_ET_MAX: WSB_OB_STATUS_ENTRY_PAIR_TYPE = WSB_OB_STATUS_ENTRY_PAIR_TYPE(6i32);
-impl ::core::marker::Copy for WSB_OB_STATUS_ENTRY_PAIR_TYPE {}
-impl ::core::clone::Clone for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for WSB_OB_STATUS_ENTRY_PAIR_TYPE {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("WSB_OB_STATUS_ENTRY_PAIR_TYPE").field(&self.0).finish()
-    }
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_System_ServerBackup\"`*"]
 pub struct WSB_OB_STATUS_ENTRY_VALUE_TYPE_PAIR {
