@@ -1,24 +1,177 @@
 #[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn GetDeviceID(pbwindowsaik: *mut u8, cbwindowsaik: u32, pcbresult: *mut u32, pfprotectedbytpm: *mut super::super::Foundation::BOOL) -> ::windows::core::Result<()> {
+pub unsafe fn GetDeviceID(pbwindowsaik: ::core::option::Option<&mut [u8]>, pcbresult: *mut u32, pfprotectedbytpm: ::core::option::Option<*mut super::super::Foundation::BOOL>) -> ::windows::core::Result<()> {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn GetDeviceID(pbwindowsaik: *mut u8, cbwindowsaik: u32, pcbresult: *mut u32, pfprotectedbytpm: *mut super::super::Foundation::BOOL) -> ::windows::core::HRESULT;
     }
-    GetDeviceID(::core::mem::transmute(pbwindowsaik), cbwindowsaik, ::core::mem::transmute(pcbresult), ::core::mem::transmute(pfprotectedbytpm)).ok()
+    GetDeviceID(::core::mem::transmute(pbwindowsaik.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())), pbwindowsaik.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(pcbresult), ::core::mem::transmute(pfprotectedbytpm.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
-pub unsafe fn GetDeviceIDString(pszwindowsaik: &mut [u16], pcchresult: *mut u32, pfprotectedbytpm: *mut super::super::Foundation::BOOL) -> ::windows::core::Result<()> {
+pub unsafe fn GetDeviceIDString(pszwindowsaik: ::core::option::Option<&mut [u16]>, pcchresult: *mut u32, pfprotectedbytpm: ::core::option::Option<*mut super::super::Foundation::BOOL>) -> ::windows::core::Result<()> {
     #[cfg_attr(windows, link(name = "windows"))]
     extern "system" {
         fn GetDeviceIDString(pszwindowsaik: ::windows::core::PWSTR, cchwindowsaik: u32, pcchresult: *mut u32, pfprotectedbytpm: *mut super::super::Foundation::BOOL) -> ::windows::core::HRESULT;
     }
-    GetDeviceIDString(::core::mem::transmute(::windows::core::as_mut_ptr_or_null(pszwindowsaik)), pszwindowsaik.len() as _, ::core::mem::transmute(pcchresult), ::core::mem::transmute(pfprotectedbytpm)).ok()
+    GetDeviceIDString(::core::mem::transmute(pszwindowsaik.as_deref().map_or(::core::ptr::null(), |slice| slice.as_ptr())), pszwindowsaik.as_deref().map_or(0, |slice| slice.len() as _), ::core::mem::transmute(pcchresult), ::core::mem::transmute(pfprotectedbytpm.unwrap_or(::std::ptr::null_mut()))).ok()
 }
 #[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Context_Create(pcontextparams: *const TBS_CONTEXT_PARAMS, phcontext: *mut *mut ::core::ffi::c_void) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Context_Create(pcontextparams: *const TBS_CONTEXT_PARAMS, phcontext: *mut *mut ::core::ffi::c_void) -> u32;
+    }
+    Tbsi_Context_Create(::core::mem::transmute(pcontextparams), ::core::mem::transmute(phcontext))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Create_Windows_Key(keyhandle: u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Create_Windows_Key(keyhandle: u32) -> u32;
+    }
+    Tbsi_Create_Windows_Key(keyhandle)
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_GetDeviceInfo(size: u32, info: *mut ::core::ffi::c_void) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_GetDeviceInfo(size: u32, info: *mut ::core::ffi::c_void) -> u32;
+    }
+    Tbsi_GetDeviceInfo(size, ::core::mem::transmute(info))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Get_OwnerAuth(hcontext: *const ::core::ffi::c_void, ownerauthtype: u32, poutputbuf: ::core::option::Option<*mut u8>, poutputbuflen: *mut u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Get_OwnerAuth(hcontext: *const ::core::ffi::c_void, ownerauthtype: u32, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32;
+    }
+    Tbsi_Get_OwnerAuth(::core::mem::transmute(hcontext), ownerauthtype, ::core::mem::transmute(poutputbuf.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(poutputbuflen))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Get_TCG_Log(hcontext: *const ::core::ffi::c_void, poutputbuf: ::core::option::Option<*mut u8>, poutputbuflen: *mut u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Get_TCG_Log(hcontext: *const ::core::ffi::c_void, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32;
+    }
+    Tbsi_Get_TCG_Log(::core::mem::transmute(hcontext), ::core::mem::transmute(poutputbuf.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(poutputbuflen))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Get_TCG_Log_Ex(logtype: u32, pboutput: ::core::option::Option<*mut u8>, pcboutput: *mut u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Get_TCG_Log_Ex(logtype: u32, pboutput: *mut u8, pcboutput: *mut u32) -> u32;
+    }
+    Tbsi_Get_TCG_Log_Ex(logtype, ::core::mem::transmute(pboutput.unwrap_or(::std::ptr::null_mut())), ::core::mem::transmute(pcboutput))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Physical_Presence_Command(hcontext: *const ::core::ffi::c_void, pabinput: &[u8], paboutput: *mut u8, pcboutput: *mut u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Physical_Presence_Command(hcontext: *const ::core::ffi::c_void, pabinput: *const u8, cbinput: u32, paboutput: *mut u8, pcboutput: *mut u32) -> u32;
+    }
+    Tbsi_Physical_Presence_Command(::core::mem::transmute(hcontext), ::core::mem::transmute(pabinput.as_ptr()), pabinput.len() as _, ::core::mem::transmute(paboutput), ::core::mem::transmute(pcboutput))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsi_Revoke_Attestation() -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsi_Revoke_Attestation() -> u32;
+    }
+    Tbsi_Revoke_Attestation()
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsip_Cancel_Commands(hcontext: *const ::core::ffi::c_void) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsip_Cancel_Commands(hcontext: *const ::core::ffi::c_void) -> u32;
+    }
+    Tbsip_Cancel_Commands(::core::mem::transmute(hcontext))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsip_Context_Close(hcontext: *const ::core::ffi::c_void) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsip_Context_Close(hcontext: *const ::core::ffi::c_void) -> u32;
+    }
+    Tbsip_Context_Close(::core::mem::transmute(hcontext))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+#[inline]
+pub unsafe fn Tbsip_Submit_Command(hcontext: *const ::core::ffi::c_void, locality: TBS_COMMAND_LOCALITY, priority: TBS_COMMAND_PRIORITY, pabcommand: &[u8], pabresult: *mut u8, pcbresult: *mut u32) -> u32 {
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn Tbsip_Submit_Command(hcontext: *const ::core::ffi::c_void, locality: TBS_COMMAND_LOCALITY, priority: TBS_COMMAND_PRIORITY, pabcommand: *const u8, cbcommand: u32, pabresult: *mut u8, pcbresult: *mut u32) -> u32;
+    }
+    Tbsip_Submit_Command(::core::mem::transmute(hcontext), locality, priority, ::core::mem::transmute(pabcommand.as_ptr()), pabcommand.len() as _, ::core::mem::transmute(pabresult), ::core::mem::transmute(pcbresult))
+}
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_CONTEXT_VERSION_ONE: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_CONTEXT_VERSION_TWO: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_ADMIN: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_ENDORSEMENT: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_ENDORSEMENT_20: u32 = 12u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_FULL: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_STORAGE_20: u32 = 13u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_OWNERAUTH_TYPE_USER: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_SUCCESS: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_DRTM_BOOT: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_DRTM_CURRENT: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_DRTM_RESUME: u32 = 5u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_SRTM_BOOT: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_SRTM_CURRENT: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TBS_TCGLOG_SRTM_RESUME: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_1: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_EMULATOR: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_HW: u32 = 3u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_SPB: u32 = 5u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_TRUSTZONE: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_IFTYPE_UNKNOWN: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_VERSION_12: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_VERSION_20: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_VERSION_UNKNOWN: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_WNF_INFO_CLEAR_SUCCESSFUL: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_WNF_INFO_NO_REBOOT_REQUIRED: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
+pub const TPM_WNF_INFO_OWNERSHIP_SUCCESSFUL: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct TBS_COMMAND_LOCALITY(pub u32);
@@ -196,36 +349,6 @@ impl ::core::default::Default for TBS_CONTEXT_PARAMS2_0_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_CONTEXT_VERSION_ONE: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_CONTEXT_VERSION_TWO: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_ADMIN: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_ENDORSEMENT: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_ENDORSEMENT_20: u32 = 12u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_FULL: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_STORAGE_20: u32 = 13u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_OWNERAUTH_TYPE_USER: u32 = 3u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_SUCCESS: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_DRTM_BOOT: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_DRTM_CURRENT: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_DRTM_RESUME: u32 = 5u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_SRTM_BOOT: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_SRTM_CURRENT: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TBS_TCGLOG_SRTM_RESUME: u32 = 3u32;
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
 pub struct TPM_DEVICE_INFO {
@@ -259,156 +382,33 @@ impl ::core::default::Default for TPM_DEVICE_INFO {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_1: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_EMULATOR: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_HW: u32 = 3u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_SPB: u32 = 5u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_TRUSTZONE: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_IFTYPE_UNKNOWN: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_VERSION_12: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_VERSION_20: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_VERSION_UNKNOWN: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_WNF_INFO_CLEAR_SUCCESSFUL: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_WNF_INFO_NO_REBOOT_REQUIRED: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub const TPM_WNF_INFO_OWNERSHIP_SUCCESSFUL: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Context_Create(pcontextparams: *const TBS_CONTEXT_PARAMS, phcontext: *mut *mut ::core::ffi::c_void) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Context_Create(pcontextparams: *const TBS_CONTEXT_PARAMS, phcontext: *mut *mut ::core::ffi::c_void) -> u32;
-    }
-    Tbsi_Context_Create(::core::mem::transmute(pcontextparams), ::core::mem::transmute(phcontext))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Create_Windows_Key(keyhandle: u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Create_Windows_Key(keyhandle: u32) -> u32;
-    }
-    Tbsi_Create_Windows_Key(keyhandle)
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_GetDeviceInfo(size: u32, info: *mut ::core::ffi::c_void) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_GetDeviceInfo(size: u32, info: *mut ::core::ffi::c_void) -> u32;
-    }
-    Tbsi_GetDeviceInfo(size, ::core::mem::transmute(info))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Get_OwnerAuth(hcontext: *const ::core::ffi::c_void, ownerauthtype: u32, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Get_OwnerAuth(hcontext: *const ::core::ffi::c_void, ownerauthtype: u32, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32;
-    }
-    Tbsi_Get_OwnerAuth(::core::mem::transmute(hcontext), ownerauthtype, ::core::mem::transmute(poutputbuf), ::core::mem::transmute(poutputbuflen))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Get_TCG_Log(hcontext: *const ::core::ffi::c_void, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Get_TCG_Log(hcontext: *const ::core::ffi::c_void, poutputbuf: *mut u8, poutputbuflen: *mut u32) -> u32;
-    }
-    Tbsi_Get_TCG_Log(::core::mem::transmute(hcontext), ::core::mem::transmute(poutputbuf), ::core::mem::transmute(poutputbuflen))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Get_TCG_Log_Ex(logtype: u32, pboutput: *mut u8, pcboutput: *mut u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Get_TCG_Log_Ex(logtype: u32, pboutput: *mut u8, pcboutput: *mut u32) -> u32;
-    }
-    Tbsi_Get_TCG_Log_Ex(logtype, ::core::mem::transmute(pboutput), ::core::mem::transmute(pcboutput))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Physical_Presence_Command(hcontext: *const ::core::ffi::c_void, pabinput: *const u8, cbinput: u32, paboutput: *mut u8, pcboutput: *mut u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Physical_Presence_Command(hcontext: *const ::core::ffi::c_void, pabinput: *const u8, cbinput: u32, paboutput: *mut u8, pcboutput: *mut u32) -> u32;
-    }
-    Tbsi_Physical_Presence_Command(::core::mem::transmute(hcontext), ::core::mem::transmute(pabinput), cbinput, ::core::mem::transmute(paboutput), ::core::mem::transmute(pcboutput))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsi_Revoke_Attestation() -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsi_Revoke_Attestation() -> u32;
-    }
-    Tbsi_Revoke_Attestation()
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsip_Cancel_Commands(hcontext: *const ::core::ffi::c_void) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsip_Cancel_Commands(hcontext: *const ::core::ffi::c_void) -> u32;
-    }
-    Tbsip_Cancel_Commands(::core::mem::transmute(hcontext))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsip_Context_Close(hcontext: *const ::core::ffi::c_void) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsip_Context_Close(hcontext: *const ::core::ffi::c_void) -> u32;
-    }
-    Tbsip_Context_Close(::core::mem::transmute(hcontext))
-}
-#[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-#[inline]
-pub unsafe fn Tbsip_Submit_Command(hcontext: *const ::core::ffi::c_void, locality: TBS_COMMAND_LOCALITY, priority: TBS_COMMAND_PRIORITY, pabcommand: *const u8, cbcommand: u32, pabresult: *mut u8, pcbresult: *mut u32) -> u32 {
-    #[cfg_attr(windows, link(name = "windows"))]
-    extern "system" {
-        fn Tbsip_Submit_Command(hcontext: *const ::core::ffi::c_void, locality: TBS_COMMAND_LOCALITY, priority: TBS_COMMAND_PRIORITY, pabcommand: *const u8, cbcommand: u32, pabresult: *mut u8, pcbresult: *mut u32) -> u32;
-    }
-    Tbsip_Submit_Command(::core::mem::transmute(hcontext), locality, priority, ::core::mem::transmute(pabcommand), cbcommand, ::core::mem::transmute(pabresult), ::core::mem::transmute(pcbresult))
-}
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_System_TpmBaseServices\"`*"]
-pub struct tdTPM_WNF_PROVISIONING {
+pub struct TPM_WNF_PROVISIONING {
     pub status: u32,
     pub message: [u8; 28],
 }
-impl ::core::marker::Copy for tdTPM_WNF_PROVISIONING {}
-impl ::core::clone::Clone for tdTPM_WNF_PROVISIONING {
+impl ::core::marker::Copy for TPM_WNF_PROVISIONING {}
+impl ::core::clone::Clone for TPM_WNF_PROVISIONING {
     fn clone(&self) -> Self {
         *self
     }
 }
-impl ::core::fmt::Debug for tdTPM_WNF_PROVISIONING {
+impl ::core::fmt::Debug for TPM_WNF_PROVISIONING {
     fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_struct("tdTPM_WNF_PROVISIONING").field("status", &self.status).field("message", &self.message).finish()
+        f.debug_struct("TPM_WNF_PROVISIONING").field("status", &self.status).field("message", &self.message).finish()
     }
 }
-unsafe impl ::windows::core::Abi for tdTPM_WNF_PROVISIONING {
+unsafe impl ::windows::core::Abi for TPM_WNF_PROVISIONING {
     type Abi = Self;
 }
-impl ::core::cmp::PartialEq for tdTPM_WNF_PROVISIONING {
+impl ::core::cmp::PartialEq for TPM_WNF_PROVISIONING {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<tdTPM_WNF_PROVISIONING>()) == 0 }
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<TPM_WNF_PROVISIONING>()) == 0 }
     }
 }
-impl ::core::cmp::Eq for tdTPM_WNF_PROVISIONING {}
-impl ::core::default::Default for tdTPM_WNF_PROVISIONING {
+impl ::core::cmp::Eq for TPM_WNF_PROVISIONING {}
+impl ::core::default::Default for TPM_WNF_PROVISIONING {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
     }
