@@ -10,39 +10,10 @@ impl ICoreFrameworkInputViewInterop {
         T: ::windows::core::Interface,
     {
         let mut result__ = ::core::option::Option::None;
-        (::windows::core::Interface::vtable(self).GetForWindow)(::windows::core::Interface::as_raw(self), appwindow.into(), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-}
-impl ::core::convert::From<ICoreFrameworkInputViewInterop> for ::windows::core::IUnknown {
-    fn from(value: ICoreFrameworkInputViewInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ICoreFrameworkInputViewInterop> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ICoreFrameworkInputViewInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ICoreFrameworkInputViewInterop> for ::windows::core::IUnknown {
-    fn from(value: &ICoreFrameworkInputViewInterop) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<ICoreFrameworkInputViewInterop> for ::windows::core::IInspectable {
-    fn from(value: ICoreFrameworkInputViewInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ICoreFrameworkInputViewInterop> for &'a ::windows::core::IInspectable {
-    fn from(value: &'a ICoreFrameworkInputViewInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ICoreFrameworkInputViewInterop> for ::windows::core::IInspectable {
-    fn from(value: &ICoreFrameworkInputViewInterop) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).GetForWindow)(::windows::core::Vtable::as_raw(self), appwindow.into(), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
     }
 }
+::windows::core::interface_hierarchy!(ICoreFrameworkInputViewInterop, ::windows::core::IUnknown, ::windows::core::IInspectable);
 impl ::core::clone::Clone for ICoreFrameworkInputViewInterop {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -59,14 +30,16 @@ impl ::core::fmt::Debug for ICoreFrameworkInputViewInterop {
         f.debug_tuple("ICoreFrameworkInputViewInterop").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ICoreFrameworkInputViewInterop {
+unsafe impl ::windows::core::Vtable for ICoreFrameworkInputViewInterop {
     type Vtable = ICoreFrameworkInputViewInterop_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ICoreFrameworkInputViewInterop {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x0e3da342_b11c_484b_9c1c_be0d61c2f6c5);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ICoreFrameworkInputViewInterop_Vtbl {
-    pub base__: ::windows::core::IInspectableVtbl,
+    pub base__: ::windows::core::IInspectable_Vtbl,
     #[cfg(feature = "Win32_Foundation")]
     pub GetForWindow: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, appwindow: super::super::super::Foundation::HWND, riid: *const ::windows::core::GUID, coreframeworkinputview: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Foundation"))]
