@@ -35,24 +35,10 @@ impl IDirect3DDxgiInterfaceAccess {
         T: ::windows::core::Interface,
     {
         let mut result__ = ::core::option::Option::None;
-        (::windows::core::Interface::vtable(self).GetInterface)(::windows::core::Interface::as_raw(self), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-}
-impl ::core::convert::From<IDirect3DDxgiInterfaceAccess> for ::windows::core::IUnknown {
-    fn from(value: IDirect3DDxgiInterfaceAccess) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IDirect3DDxgiInterfaceAccess> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IDirect3DDxgiInterfaceAccess) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IDirect3DDxgiInterfaceAccess> for ::windows::core::IUnknown {
-    fn from(value: &IDirect3DDxgiInterfaceAccess) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).GetInterface)(::windows::core::Vtable::as_raw(self), &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
     }
 }
+::windows::core::interface_hierarchy!(IDirect3DDxgiInterfaceAccess, ::windows::core::IUnknown);
 impl ::core::clone::Clone for IDirect3DDxgiInterfaceAccess {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -69,14 +55,16 @@ impl ::core::fmt::Debug for IDirect3DDxgiInterfaceAccess {
         f.debug_tuple("IDirect3DDxgiInterfaceAccess").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for IDirect3DDxgiInterfaceAccess {
+unsafe impl ::windows::core::Vtable for IDirect3DDxgiInterfaceAccess {
     type Vtable = IDirect3DDxgiInterfaceAccess_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IDirect3DDxgiInterfaceAccess {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xa9b3d012_3df2_4ee3_b8d1_8695f457d3c1);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IDirect3DDxgiInterfaceAccess_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub GetInterface: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, iid: *const ::windows::core::GUID, p: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
 }
 #[cfg(feature = "implement")]
