@@ -9,24 +9,10 @@ impl IIsolatedEnvironmentInterop {
         P0: ::std::convert::Into<super::super::super::Foundation::HWND>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).GetHostHwndInterop)(::windows::core::Interface::as_raw(self), containerhwnd.into(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::Foundation::HWND>(result__)
-    }
-}
-impl ::core::convert::From<IIsolatedEnvironmentInterop> for ::windows::core::IUnknown {
-    fn from(value: IIsolatedEnvironmentInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IIsolatedEnvironmentInterop> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IIsolatedEnvironmentInterop) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IIsolatedEnvironmentInterop> for ::windows::core::IUnknown {
-    fn from(value: &IIsolatedEnvironmentInterop) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).GetHostHwndInterop)(::windows::core::Vtable::as_raw(self), containerhwnd.into(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::Foundation::HWND>(result__)
     }
 }
+::windows::core::interface_hierarchy!(IIsolatedEnvironmentInterop, ::windows::core::IUnknown);
 impl ::core::clone::Clone for IIsolatedEnvironmentInterop {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -43,14 +29,16 @@ impl ::core::fmt::Debug for IIsolatedEnvironmentInterop {
         f.debug_tuple("IIsolatedEnvironmentInterop").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for IIsolatedEnvironmentInterop {
+unsafe impl ::windows::core::Vtable for IIsolatedEnvironmentInterop {
     type Vtable = IIsolatedEnvironmentInterop_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IIsolatedEnvironmentInterop {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x85713c2e_8e62_46c5_8de2_c647e1d54636);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IIsolatedEnvironmentInterop_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_Foundation")]
     pub GetHostHwndInterop: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, containerhwnd: super::super::super::Foundation::HWND, hosthwnd: *mut super::super::super::Foundation::HWND) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Foundation"))]
