@@ -9,24 +9,10 @@ impl ILearningModelDeviceFactoryNative {
         P0: ::std::convert::Into<::windows::core::InParam<'a, super::super::super::Graphics::Direct3D12::ID3D12CommandQueue>>,
     {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).CreateFromD3D12CommandQueue)(::windows::core::Interface::as_raw(self), value.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<::windows::core::IUnknown>(result__)
-    }
-}
-impl ::core::convert::From<ILearningModelDeviceFactoryNative> for ::windows::core::IUnknown {
-    fn from(value: ILearningModelDeviceFactoryNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ILearningModelDeviceFactoryNative> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ILearningModelDeviceFactoryNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ILearningModelDeviceFactoryNative> for ::windows::core::IUnknown {
-    fn from(value: &ILearningModelDeviceFactoryNative) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).CreateFromD3D12CommandQueue)(::windows::core::Vtable::as_raw(self), value.into().abi(), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<::windows::core::IUnknown>(result__)
     }
 }
+::windows::core::interface_hierarchy!(ILearningModelDeviceFactoryNative, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ILearningModelDeviceFactoryNative {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -43,14 +29,16 @@ impl ::core::fmt::Debug for ILearningModelDeviceFactoryNative {
         f.debug_tuple("ILearningModelDeviceFactoryNative").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ILearningModelDeviceFactoryNative {
+unsafe impl ::windows::core::Vtable for ILearningModelDeviceFactoryNative {
     type Vtable = ILearningModelDeviceFactoryNative_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILearningModelDeviceFactoryNative {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x1e9b31a1_662e_4ae0_af67_f63bb337e634);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILearningModelDeviceFactoryNative_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_Graphics_Direct3D12")]
     pub CreateFromD3D12CommandQueue: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, value: *mut ::core::ffi::c_void, result: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Graphics_Direct3D12"))]
@@ -64,24 +52,10 @@ impl ILearningModelOperatorProviderNative {
     #[cfg(feature = "Win32_AI_MachineLearning_WinML")]
     pub unsafe fn GetRegistry(&self) -> ::windows::core::Result<super::super::super::AI::MachineLearning::WinML::IMLOperatorRegistry> {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).GetRegistry)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::AI::MachineLearning::WinML::IMLOperatorRegistry>(result__)
-    }
-}
-impl ::core::convert::From<ILearningModelOperatorProviderNative> for ::windows::core::IUnknown {
-    fn from(value: ILearningModelOperatorProviderNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ILearningModelOperatorProviderNative> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ILearningModelOperatorProviderNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ILearningModelOperatorProviderNative> for ::windows::core::IUnknown {
-    fn from(value: &ILearningModelOperatorProviderNative) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).GetRegistry)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::AI::MachineLearning::WinML::IMLOperatorRegistry>(result__)
     }
 }
+::windows::core::interface_hierarchy!(ILearningModelOperatorProviderNative, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ILearningModelOperatorProviderNative {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -98,14 +72,16 @@ impl ::core::fmt::Debug for ILearningModelOperatorProviderNative {
         f.debug_tuple("ILearningModelOperatorProviderNative").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ILearningModelOperatorProviderNative {
+unsafe impl ::windows::core::Vtable for ILearningModelOperatorProviderNative {
     type Vtable = ILearningModelOperatorProviderNative_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILearningModelOperatorProviderNative {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x1adaa23a_eb67_41f3_aad8_5d984e9bacd4);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILearningModelOperatorProviderNative_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_AI_MachineLearning_WinML")]
     pub GetRegistry: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, ppoperatorregistry: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_AI_MachineLearning_WinML"))]
@@ -116,24 +92,10 @@ pub struct ILearningModelOperatorProviderNative_Vtbl {
 pub struct ILearningModelSessionOptionsNative(::windows::core::IUnknown);
 impl ILearningModelSessionOptionsNative {
     pub unsafe fn SetIntraOpNumThreadsOverride(&self, intraopnumthreads: u32) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).SetIntraOpNumThreadsOverride)(::windows::core::Interface::as_raw(self), intraopnumthreads).ok()
-    }
-}
-impl ::core::convert::From<ILearningModelSessionOptionsNative> for ::windows::core::IUnknown {
-    fn from(value: ILearningModelSessionOptionsNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ILearningModelSessionOptionsNative> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ILearningModelSessionOptionsNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ILearningModelSessionOptionsNative> for ::windows::core::IUnknown {
-    fn from(value: &ILearningModelSessionOptionsNative) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).SetIntraOpNumThreadsOverride)(::windows::core::Vtable::as_raw(self), intraopnumthreads).ok()
     }
 }
+::windows::core::interface_hierarchy!(ILearningModelSessionOptionsNative, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ILearningModelSessionOptionsNative {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -150,14 +112,16 @@ impl ::core::fmt::Debug for ILearningModelSessionOptionsNative {
         f.debug_tuple("ILearningModelSessionOptionsNative").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ILearningModelSessionOptionsNative {
+unsafe impl ::windows::core::Vtable for ILearningModelSessionOptionsNative {
     type Vtable = ILearningModelSessionOptionsNative_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ILearningModelSessionOptionsNative {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0xc71e953f_37b4_4564_8658_d8396866db0d);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ILearningModelSessionOptionsNative_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub SetIntraOpNumThreadsOverride: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, intraopnumthreads: u32) -> ::windows::core::HRESULT,
 }
 #[doc = "*Required features: `\"Win32_System_WinRT_ML\"`*"]
@@ -165,30 +129,16 @@ pub struct ILearningModelSessionOptionsNative_Vtbl {
 pub struct ITensorNative(::windows::core::IUnknown);
 impl ITensorNative {
     pub unsafe fn GetBuffer(&self, value: *mut *mut u8, capacity: *mut u32) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).GetBuffer)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(value), ::core::mem::transmute(capacity)).ok()
+        (::windows::core::Vtable::vtable(self).GetBuffer)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(value), ::core::mem::transmute(capacity)).ok()
     }
     #[doc = "*Required features: `\"Win32_Graphics_Direct3D12\"`*"]
     #[cfg(feature = "Win32_Graphics_Direct3D12")]
     pub unsafe fn GetD3D12Resource(&self) -> ::windows::core::Result<super::super::super::Graphics::Direct3D12::ID3D12Resource> {
         let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).GetD3D12Resource)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::Graphics::Direct3D12::ID3D12Resource>(result__)
-    }
-}
-impl ::core::convert::From<ITensorNative> for ::windows::core::IUnknown {
-    fn from(value: ITensorNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITensorNative> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITensorNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITensorNative> for ::windows::core::IUnknown {
-    fn from(value: &ITensorNative) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).GetD3D12Resource)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<super::super::super::Graphics::Direct3D12::ID3D12Resource>(result__)
     }
 }
+::windows::core::interface_hierarchy!(ITensorNative, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ITensorNative {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -205,14 +155,16 @@ impl ::core::fmt::Debug for ITensorNative {
         f.debug_tuple("ITensorNative").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITensorNative {
+unsafe impl ::windows::core::Vtable for ITensorNative {
     type Vtable = ITensorNative_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITensorNative {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x52f547ef_5b03_49b5_82d6_565f1ee0dd49);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ITensorNative_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub GetBuffer: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, value: *mut *mut u8, capacity: *mut u32) -> ::windows::core::HRESULT,
     #[cfg(feature = "Win32_Graphics_Direct3D12")]
     pub GetD3D12Resource: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, result: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
@@ -229,24 +181,10 @@ impl ITensorStaticsNative {
     where
         P0: ::std::convert::Into<::windows::core::InParam<'a, super::super::super::Graphics::Direct3D12::ID3D12Resource>>,
     {
-        (::windows::core::Interface::vtable(self).CreateFromD3D12Resource)(::windows::core::Interface::as_raw(self), value.into().abi(), ::core::mem::transmute(shape), shapecount, ::core::mem::transmute(result)).ok()
-    }
-}
-impl ::core::convert::From<ITensorStaticsNative> for ::windows::core::IUnknown {
-    fn from(value: ITensorStaticsNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a ITensorStaticsNative> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a ITensorStaticsNative) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&ITensorStaticsNative> for ::windows::core::IUnknown {
-    fn from(value: &ITensorStaticsNative) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).CreateFromD3D12Resource)(::windows::core::Vtable::as_raw(self), value.into().abi(), ::core::mem::transmute(shape), shapecount, ::core::mem::transmute(result)).ok()
     }
 }
+::windows::core::interface_hierarchy!(ITensorStaticsNative, ::windows::core::IUnknown);
 impl ::core::clone::Clone for ITensorStaticsNative {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -263,14 +201,16 @@ impl ::core::fmt::Debug for ITensorStaticsNative {
         f.debug_tuple("ITensorStaticsNative").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for ITensorStaticsNative {
+unsafe impl ::windows::core::Vtable for ITensorStaticsNative {
     type Vtable = ITensorStaticsNative_Vtbl;
+}
+unsafe impl ::windows::core::Interface for ITensorStaticsNative {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x39d055a4_66f6_4ebc_95d9_7a29ebe7690a);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ITensorStaticsNative_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     #[cfg(feature = "Win32_Graphics_Direct3D12")]
     pub CreateFromD3D12Resource: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, value: *mut ::core::ffi::c_void, shape: *mut i64, shapecount: i32, result: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
     #[cfg(not(feature = "Win32_Graphics_Direct3D12"))]
