@@ -19,7 +19,7 @@ impl IPrintManagerInterop_Vtbl {
             this.ShowPrintUIForWindowAsync(::core::mem::transmute_copy(&appwindow), ::core::mem::transmute_copy(&riid), ::core::mem::transmute_copy(&asyncoperation)).into()
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IPrintManagerInterop, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IPrintManagerInterop, OFFSET>(),
             GetForWindow: GetForWindow::<Identity, Impl, OFFSET>,
             ShowPrintUIForWindowAsync: ShowPrintUIForWindowAsync::<Identity, Impl, OFFSET>,
         }
@@ -73,7 +73,7 @@ impl IPrintWorkflowConfigurationNative_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             PrinterQueue: PrinterQueue::<Identity, Impl, OFFSET>,
             DriverProperties: DriverProperties::<Identity, Impl, OFFSET>,
             UserProperties: UserProperties::<Identity, Impl, OFFSET>,
@@ -110,7 +110,7 @@ impl IPrintWorkflowObjectModelSourceFileContentNative_Vtbl {
             }
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             StartXpsOMGeneration: StartXpsOMGeneration::<Identity, Impl, OFFSET>,
             ObjectFactory: ObjectFactory::<Identity, Impl, OFFSET>,
         }
@@ -139,7 +139,7 @@ impl IPrintWorkflowXpsObjectModelTargetPackageNative_Vtbl {
                 ::core::result::Result::Err(err) => err.into(),
             }
         }
-        Self { base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(), DocumentPackageTarget: DocumentPackageTarget::<Identity, Impl, OFFSET> }
+        Self { base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(), DocumentPackageTarget: DocumentPackageTarget::<Identity, Impl, OFFSET> }
     }
     pub fn matches(iid: &windows::core::GUID) -> bool {
         iid == &<IPrintWorkflowXpsObjectModelTargetPackageNative as ::windows::core::Interface>::IID
@@ -184,7 +184,7 @@ impl IPrintWorkflowXpsReceiver_Vtbl {
             this.Close().into()
         }
         Self {
-            base__: ::windows::core::IUnknownVtbl::new::<Identity, OFFSET>(),
+            base__: ::windows::core::IUnknown_Vtbl::new::<Identity, OFFSET>(),
             SetDocumentSequencePrintTicket: SetDocumentSequencePrintTicket::<Identity, Impl, OFFSET>,
             SetDocumentSequenceUri: SetDocumentSequenceUri::<Identity, Impl, OFFSET>,
             AddDocumentData: AddDocumentData::<Identity, Impl, OFFSET>,
@@ -237,7 +237,7 @@ impl IPrinting3DManagerInterop_Vtbl {
             this.ShowPrintUIForWindowAsync(::core::mem::transmute_copy(&appwindow), ::core::mem::transmute_copy(&riid), ::core::mem::transmute_copy(&asyncoperation)).into()
         }
         Self {
-            base__: ::windows::core::IInspectableVtbl::new::<Identity, IPrinting3DManagerInterop, OFFSET>(),
+            base__: ::windows::core::IInspectable_Vtbl::new::<Identity, IPrinting3DManagerInterop, OFFSET>(),
             GetForWindow: GetForWindow::<Identity, Impl, OFFSET>,
             ShowPrintUIForWindowAsync: ShowPrintUIForWindowAsync::<Identity, Impl, OFFSET>,
         }
