@@ -7,24 +7,10 @@ impl INotificationActivationCallback {
         P0: ::std::convert::Into<::windows::core::PCWSTR>,
         P1: ::std::convert::Into<::windows::core::PCWSTR>,
     {
-        (::windows::core::Interface::vtable(self).Activate)(::windows::core::Interface::as_raw(self), appusermodelid.into(), invokedargs.into(), ::core::mem::transmute(::windows::core::as_ptr_or_null(data)), data.len() as _).ok()
-    }
-}
-impl ::core::convert::From<INotificationActivationCallback> for ::windows::core::IUnknown {
-    fn from(value: INotificationActivationCallback) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a INotificationActivationCallback> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a INotificationActivationCallback) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&INotificationActivationCallback> for ::windows::core::IUnknown {
-    fn from(value: &INotificationActivationCallback) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
+        (::windows::core::Vtable::vtable(self).Activate)(::windows::core::Vtable::as_raw(self), appusermodelid.into(), invokedargs.into(), ::core::mem::transmute(data.as_ptr()), data.len() as _).ok()
     }
 }
+::windows::core::interface_hierarchy!(INotificationActivationCallback, ::windows::core::IUnknown);
 impl ::core::clone::Clone for INotificationActivationCallback {
     fn clone(&self) -> Self {
         Self(self.0.clone())
@@ -41,14 +27,16 @@ impl ::core::fmt::Debug for INotificationActivationCallback {
         f.debug_tuple("INotificationActivationCallback").field(&self.0).finish()
     }
 }
-unsafe impl ::windows::core::Interface for INotificationActivationCallback {
+unsafe impl ::windows::core::Vtable for INotificationActivationCallback {
     type Vtable = INotificationActivationCallback_Vtbl;
+}
+unsafe impl ::windows::core::Interface for INotificationActivationCallback {
     const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x53e31837_6600_4a81_9395_75cffe746f94);
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct INotificationActivationCallback_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
+    pub base__: ::windows::core::IUnknown_Vtbl,
     pub Activate: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, appusermodelid: ::windows::core::PCWSTR, invokedargs: ::windows::core::PCWSTR, data: *const NOTIFICATION_USER_INPUT_DATA, count: u32) -> ::windows::core::HRESULT,
 }
 #[repr(C)]
