@@ -1,34 +1,129 @@
-#[repr(C)]
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub struct COMDLG_FILTERSPEC {
-    pub pszName: ::windows::core::PCWSTR,
-    pub pszSpec: ::windows::core::PCWSTR,
+#[repr(transparent)]
+pub struct IObjectArray(::windows::core::IUnknown);
+impl IObjectArray {
+    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
+        let mut result__ = ::core::mem::MaybeUninit::zeroed();
+        (::windows::core::Vtable::vtable(self).GetCount)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
+    }
+    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
+    where
+        T: ::windows::core::Interface,
+    {
+        let mut result__ = ::core::option::Option::None;
+        (::windows::core::Vtable::vtable(self).GetAt)(::windows::core::Vtable::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
+    }
 }
-impl ::core::marker::Copy for COMDLG_FILTERSPEC {}
-impl ::core::clone::Clone for COMDLG_FILTERSPEC {
+::windows::core::interface_hierarchy!(IObjectArray, ::windows::core::IUnknown);
+impl ::core::clone::Clone for IObjectArray {
     fn clone(&self) -> Self {
-        *self
+        Self(self.0.clone())
     }
 }
-impl ::core::fmt::Debug for COMDLG_FILTERSPEC {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_struct("COMDLG_FILTERSPEC").field("pszName", &self.pszName).field("pszSpec", &self.pszSpec).finish()
-    }
-}
-unsafe impl ::windows::core::Abi for COMDLG_FILTERSPEC {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for COMDLG_FILTERSPEC {
+impl ::core::cmp::PartialEq for IObjectArray {
     fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<COMDLG_FILTERSPEC>()) == 0 }
+        self.0 == other.0
     }
 }
-impl ::core::cmp::Eq for COMDLG_FILTERSPEC {}
-impl ::core::default::Default for COMDLG_FILTERSPEC {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::cmp::Eq for IObjectArray {}
+impl ::core::fmt::Debug for IObjectArray {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("IObjectArray").field(&self.0).finish()
     }
 }
+unsafe impl ::windows::core::Vtable for IObjectArray {
+    type Vtable = IObjectArray_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IObjectArray {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x92ca9dcd_5622_4bba_a805_5e9f541bd8c9);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IObjectArray_Vtbl {
+    pub base__: ::windows::core::IUnknown_Vtbl,
+    pub GetCount: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pcobjects: *mut u32) -> ::windows::core::HRESULT,
+    pub GetAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32, riid: *const ::windows::core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+}
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+#[repr(transparent)]
+pub struct IObjectCollection(::windows::core::IUnknown);
+impl IObjectCollection {
+    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
+        let mut result__ = ::core::mem::MaybeUninit::zeroed();
+        (::windows::core::Vtable::vtable(self).base__.GetCount)(::windows::core::Vtable::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
+    }
+    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
+    where
+        T: ::windows::core::Interface,
+    {
+        let mut result__ = ::core::option::Option::None;
+        (::windows::core::Vtable::vtable(self).base__.GetAt)(::windows::core::Vtable::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
+    }
+    pub unsafe fn AddObject<'a, P0>(&self, punk: P0) -> ::windows::core::Result<()>
+    where
+        P0: ::std::convert::Into<::windows::core::InParam<'a, ::windows::core::IUnknown>>,
+    {
+        (::windows::core::Vtable::vtable(self).AddObject)(::windows::core::Vtable::as_raw(self), punk.into().abi()).ok()
+    }
+    pub unsafe fn AddFromArray<'a, P0>(&self, poasource: P0) -> ::windows::core::Result<()>
+    where
+        P0: ::std::convert::Into<::windows::core::InParam<'a, IObjectArray>>,
+    {
+        (::windows::core::Vtable::vtable(self).AddFromArray)(::windows::core::Vtable::as_raw(self), poasource.into().abi()).ok()
+    }
+    pub unsafe fn RemoveObjectAt(&self, uiindex: u32) -> ::windows::core::Result<()> {
+        (::windows::core::Vtable::vtable(self).RemoveObjectAt)(::windows::core::Vtable::as_raw(self), uiindex).ok()
+    }
+    pub unsafe fn Clear(&self) -> ::windows::core::Result<()> {
+        (::windows::core::Vtable::vtable(self).Clear)(::windows::core::Vtable::as_raw(self)).ok()
+    }
+}
+::windows::core::interface_hierarchy!(IObjectCollection, ::windows::core::IUnknown, IObjectArray);
+impl ::core::clone::Clone for IObjectCollection {
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+impl ::core::cmp::PartialEq for IObjectCollection {
+    fn eq(&self, other: &Self) -> bool {
+        self.0 == other.0
+    }
+}
+impl ::core::cmp::Eq for IObjectCollection {}
+impl ::core::fmt::Debug for IObjectCollection {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("IObjectCollection").field(&self.0).finish()
+    }
+}
+unsafe impl ::windows::core::Vtable for IObjectCollection {
+    type Vtable = IObjectCollection_Vtbl;
+}
+unsafe impl ::windows::core::Interface for IObjectCollection {
+    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x5632b1a4_e38a_400a_928a_d4cd63230295);
+}
+#[repr(C)]
+#[doc(hidden)]
+pub struct IObjectCollection_Vtbl {
+    pub base__: IObjectArray_Vtbl,
+    pub AddObject: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, punk: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+    pub AddFromArray: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, poasource: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+    pub RemoveObjectAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32) -> ::windows::core::HRESULT,
+    pub Clear: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
+}
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_GDIPLUS: u32 = 16u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_HARDCODED: u32 = 2u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_NATIVESUPPORT: u32 = 4u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_SOFTCODED: u32 = 1u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_UNDEFINED: u32 = 0u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_WMSDK: u32 = 32u32;
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const PERCEIVEDFLAG_ZIPFOLDER: u32 = 64u32;
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
@@ -88,182 +183,6 @@ impl ::core::fmt::Debug for DEVICE_SCALE_FACTOR {
 }
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 #[repr(transparent)]
-pub struct IObjectArray(::windows::core::IUnknown);
-impl IObjectArray {
-    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
-        let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).GetCount)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
-    }
-    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
-    where
-        T: ::windows::core::Interface,
-    {
-        let mut result__ = ::core::option::Option::None;
-        (::windows::core::Interface::vtable(self).GetAt)(::windows::core::Interface::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-}
-impl ::core::convert::From<IObjectArray> for ::windows::core::IUnknown {
-    fn from(value: IObjectArray) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IObjectArray> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IObjectArray) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IObjectArray> for ::windows::core::IUnknown {
-    fn from(value: &IObjectArray) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::clone::Clone for IObjectArray {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
-    }
-}
-impl ::core::cmp::PartialEq for IObjectArray {
-    fn eq(&self, other: &Self) -> bool {
-        self.0 == other.0
-    }
-}
-impl ::core::cmp::Eq for IObjectArray {}
-impl ::core::fmt::Debug for IObjectArray {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("IObjectArray").field(&self.0).finish()
-    }
-}
-unsafe impl ::windows::core::Interface for IObjectArray {
-    type Vtable = IObjectArray_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x92ca9dcd_5622_4bba_a805_5e9f541bd8c9);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IObjectArray_Vtbl {
-    pub base__: ::windows::core::IUnknownVtbl,
-    pub GetCount: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, pcobjects: *mut u32) -> ::windows::core::HRESULT,
-    pub GetAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32, riid: *const ::windows::core::GUID, ppv: *mut *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-}
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-#[repr(transparent)]
-pub struct IObjectCollection(::windows::core::IUnknown);
-impl IObjectCollection {
-    pub unsafe fn GetCount(&self) -> ::windows::core::Result<u32> {
-        let mut result__ = ::core::mem::MaybeUninit::zeroed();
-        (::windows::core::Interface::vtable(self).base__.GetCount)(::windows::core::Interface::as_raw(self), ::core::mem::transmute(result__.as_mut_ptr())).from_abi::<u32>(result__)
-    }
-    pub unsafe fn GetAt<T>(&self, uiindex: u32) -> ::windows::core::Result<T>
-    where
-        T: ::windows::core::Interface,
-    {
-        let mut result__ = ::core::option::Option::None;
-        (::windows::core::Interface::vtable(self).base__.GetAt)(::windows::core::Interface::as_raw(self), uiindex, &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
-    }
-    pub unsafe fn AddObject<'a, P0>(&self, punk: P0) -> ::windows::core::Result<()>
-    where
-        P0: ::std::convert::Into<::windows::core::InParam<'a, ::windows::core::IUnknown>>,
-    {
-        (::windows::core::Interface::vtable(self).AddObject)(::windows::core::Interface::as_raw(self), punk.into().abi()).ok()
-    }
-    pub unsafe fn AddFromArray<'a, P0>(&self, poasource: P0) -> ::windows::core::Result<()>
-    where
-        P0: ::std::convert::Into<::windows::core::InParam<'a, IObjectArray>>,
-    {
-        (::windows::core::Interface::vtable(self).AddFromArray)(::windows::core::Interface::as_raw(self), poasource.into().abi()).ok()
-    }
-    pub unsafe fn RemoveObjectAt(&self, uiindex: u32) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).RemoveObjectAt)(::windows::core::Interface::as_raw(self), uiindex).ok()
-    }
-    pub unsafe fn Clear(&self) -> ::windows::core::Result<()> {
-        (::windows::core::Interface::vtable(self).Clear)(::windows::core::Interface::as_raw(self)).ok()
-    }
-}
-impl ::core::convert::From<IObjectCollection> for ::windows::core::IUnknown {
-    fn from(value: IObjectCollection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IObjectCollection> for &'a ::windows::core::IUnknown {
-    fn from(value: &'a IObjectCollection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IObjectCollection> for ::windows::core::IUnknown {
-    fn from(value: &IObjectCollection) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::convert::From<IObjectCollection> for IObjectArray {
-    fn from(value: IObjectCollection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl<'a> ::core::convert::From<&'a IObjectCollection> for &'a IObjectArray {
-    fn from(value: &'a IObjectCollection) -> Self {
-        unsafe { ::core::mem::transmute(value) }
-    }
-}
-impl ::core::convert::From<&IObjectCollection> for IObjectArray {
-    fn from(value: &IObjectCollection) -> Self {
-        ::core::convert::From::from(::core::clone::Clone::clone(value))
-    }
-}
-impl ::core::clone::Clone for IObjectCollection {
-    fn clone(&self) -> Self {
-        Self(self.0.clone())
-    }
-}
-impl ::core::cmp::PartialEq for IObjectCollection {
-    fn eq(&self, other: &Self) -> bool {
-        self.0 == other.0
-    }
-}
-impl ::core::cmp::Eq for IObjectCollection {}
-impl ::core::fmt::Debug for IObjectCollection {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("IObjectCollection").field(&self.0).finish()
-    }
-}
-unsafe impl ::windows::core::Interface for IObjectCollection {
-    type Vtable = IObjectCollection_Vtbl;
-    const IID: ::windows::core::GUID = ::windows::core::GUID::from_u128(0x5632b1a4_e38a_400a_928a_d4cd63230295);
-}
-#[repr(C)]
-#[doc(hidden)]
-pub struct IObjectCollection_Vtbl {
-    pub base__: IObjectArray_Vtbl,
-    pub AddObject: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, punk: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-    pub AddFromArray: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, poasource: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-    pub RemoveObjectAt: unsafe extern "system" fn(this: *mut ::core::ffi::c_void, uiindex: u32) -> ::windows::core::HRESULT,
-    pub Clear: unsafe extern "system" fn(this: *mut ::core::ffi::c_void) -> ::windows::core::HRESULT,
-}
-#[repr(C)]
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub struct ITEMIDLIST {
-    pub mkid: SHITEMID,
-}
-impl ::core::marker::Copy for ITEMIDLIST {}
-impl ::core::clone::Clone for ITEMIDLIST {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-unsafe impl ::windows::core::Abi for ITEMIDLIST {
-    type Abi = Self;
-}
-impl ::core::cmp::PartialEq for ITEMIDLIST {
-    fn eq(&self, other: &Self) -> bool {
-        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ITEMIDLIST>()) == 0 }
-    }
-}
-impl ::core::cmp::Eq for ITEMIDLIST {}
-impl ::core::default::Default for ITEMIDLIST {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
-    }
-}
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-#[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct PERCEIVED(pub i32);
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
@@ -318,20 +237,6 @@ impl ::core::fmt::Debug for PERCEIVED {
     }
 }
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_GDIPLUS: u32 = 16u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_HARDCODED: u32 = 2u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_NATIVESUPPORT: u32 = 4u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_SOFTCODED: u32 = 1u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_UNDEFINED: u32 = 0u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_WMSDK: u32 = 32u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const PERCEIVEDFLAG_ZIPFOLDER: u32 = 64u32;
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 #[repr(transparent)]
 #[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct SHCOLSTATE(pub i32);
@@ -394,6 +299,91 @@ impl ::core::fmt::Debug for SHCOLSTATE {
         f.debug_tuple("SHCOLSTATE").field(&self.0).finish()
     }
 }
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+#[repr(transparent)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
+pub struct STRRET_TYPE(pub i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_WSTR: STRRET_TYPE = STRRET_TYPE(0i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_OFFSET: STRRET_TYPE = STRRET_TYPE(1i32);
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub const STRRET_CSTR: STRRET_TYPE = STRRET_TYPE(2i32);
+impl ::core::marker::Copy for STRRET_TYPE {}
+impl ::core::clone::Clone for STRRET_TYPE {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::default::Default for STRRET_TYPE {
+    fn default() -> Self {
+        Self(0)
+    }
+}
+unsafe impl ::windows::core::Abi for STRRET_TYPE {
+    type Abi = Self;
+}
+impl ::core::fmt::Debug for STRRET_TYPE {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("STRRET_TYPE").field(&self.0).finish()
+    }
+}
+#[repr(C)]
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub struct COMDLG_FILTERSPEC {
+    pub pszName: ::windows::core::PCWSTR,
+    pub pszSpec: ::windows::core::PCWSTR,
+}
+impl ::core::marker::Copy for COMDLG_FILTERSPEC {}
+impl ::core::clone::Clone for COMDLG_FILTERSPEC {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::fmt::Debug for COMDLG_FILTERSPEC {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("COMDLG_FILTERSPEC").field("pszName", &self.pszName).field("pszSpec", &self.pszSpec).finish()
+    }
+}
+unsafe impl ::windows::core::Abi for COMDLG_FILTERSPEC {
+    type Abi = Self;
+}
+impl ::core::cmp::PartialEq for COMDLG_FILTERSPEC {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<COMDLG_FILTERSPEC>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for COMDLG_FILTERSPEC {}
+impl ::core::default::Default for COMDLG_FILTERSPEC {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
+#[repr(C, packed(1))]
+#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
+pub struct ITEMIDLIST {
+    pub mkid: SHITEMID,
+}
+impl ::core::marker::Copy for ITEMIDLIST {}
+impl ::core::clone::Clone for ITEMIDLIST {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+unsafe impl ::windows::core::Abi for ITEMIDLIST {
+    type Abi = Self;
+}
+impl ::core::cmp::PartialEq for ITEMIDLIST {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<ITEMIDLIST>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for ITEMIDLIST {}
+impl ::core::default::Default for ITEMIDLIST {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 #[repr(C, packed(1))]
 #[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
 pub struct SHELLDETAILS {
@@ -500,34 +490,5 @@ impl ::core::default::Default for STRRET_0 {
         unsafe { ::core::mem::zeroed() }
     }
 }
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-#[repr(transparent)]
-#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
-pub struct STRRET_TYPE(pub i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_WSTR: STRRET_TYPE = STRRET_TYPE(0i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_OFFSET: STRRET_TYPE = STRRET_TYPE(1i32);
-#[doc = "*Required features: `\"Win32_UI_Shell_Common\"`*"]
-pub const STRRET_CSTR: STRRET_TYPE = STRRET_TYPE(2i32);
-impl ::core::marker::Copy for STRRET_TYPE {}
-impl ::core::clone::Clone for STRRET_TYPE {
-    fn clone(&self) -> Self {
-        *self
-    }
-}
-impl ::core::default::Default for STRRET_TYPE {
-    fn default() -> Self {
-        Self(0)
-    }
-}
-unsafe impl ::windows::core::Abi for STRRET_TYPE {
-    type Abi = Self;
-}
-impl ::core::fmt::Debug for STRRET_TYPE {
-    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        f.debug_tuple("STRRET_TYPE").field(&self.0).finish()
-    }
-}
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
