@@ -2,7 +2,7 @@ use super::*;
 use bindings::*;
 
 /// An error object consists of both an error code as well as detailed error information for debugging.
-#[derive(Clone, PartialEq)]
+#[derive(Clone, PartialEq, Eq)]
 pub struct Error {
     pub(crate) code: HRESULT,
     pub(crate) info: Option<IRestrictedErrorInfo>,
@@ -17,16 +17,16 @@ impl Error {
     pub fn new(code: HRESULT, message: HSTRING) -> Self {
         unsafe {
             if let Ok(function) = delay_load(s!("combase.dll"), s!("RoOriginateError")) {
-                let function: RoOriginateError = core::mem::transmute(function);
-                function(code, core::mem::transmute_copy(&message));
+                let function: RoOriginateError = std::mem::transmute(function);
+                function(code, std::mem::transmute_copy(&message));
             }
-            let info = GetErrorInfo(0).and_then(|e| e.cast()).ok();
+            let info = GetErrorInfo().and_then(|e| e.cast()).ok();
             Self { code, info }
         }
     }
 
     pub fn from_win32() -> Self {
-        unsafe { Self { code: GetLastError().into(), info: None } }
+        unsafe { Self { code: HRESULT::from_win32(GetLastError()), info: None } }
     }
 
     /// The error code describing the error.
@@ -62,38 +62,50 @@ impl Error {
     }
 }
 
-impl core::convert::From<Error> for HRESULT {
+impl std::convert::From<Error> for HRESULT {
     fn from(error: Error) -> Self {
         let code = error.code;
-        let info = error.info.and_then(|info| info.cast().ok());
+        let info: Option<IErrorInfo> = error.info.and_then(|info| info.cast().ok());
 
         unsafe {
-            let _ = SetErrorInfo(0, info.as_ref());
+            let _ = SetErrorInfo(0, info.abi());
         }
 
         code
     }
 }
 
-impl core::convert::From<Error> for std::io::Error {
+impl std::convert::From<Error> for std::io::Error {
     fn from(from: Error) -> Self {
         Self::from_raw_os_error(from.code.0)
     }
 }
 
+impl std::convert::From<std::string::FromUtf16Error> for Error {
+    fn from(_: std::string::FromUtf16Error) -> Self {
+        Self { code: HRESULT::from_win32(ERROR_NO_UNICODE_TRANSLATION), info: None }
+    }
+}
+
+impl std::convert::From<std::string::FromUtf8Error> for Error {
+    fn from(_: std::string::FromUtf8Error) -> Self {
+        Self { code: HRESULT::from_win32(ERROR_NO_UNICODE_TRANSLATION), info: None }
+    }
+}
+
 // Unfortunately this is needed to make types line up. The Rust type system does
 // not know the `Infallible` can never be constructed. This code needs to be here
 // to satesify the type checker but it will never be run. Once `!` is stabilizied
 // this can be removed.
-impl core::convert::From<core::convert::Infallible> for Error {
-    fn from(from: core::convert::Infallible) -> Self {
+impl std::convert::From<std::convert::Infallible> for Error {
+    fn from(_: std::convert::Infallible) -> Self {
         unreachable!()
     }
 }
 
-impl core::convert::From<HRESULT> for Error {
+impl std::convert::From<HRESULT> for Error {
     fn from(code: HRESULT) -> Self {
-        let info: Option<IRestrictedErrorInfo> = unsafe { GetErrorInfo(0).and_then(|e| e.cast()).ok() };
+        let info: Option<IRestrictedErrorInfo> = GetErrorInfo().and_then(|e| e.cast()).ok();
 
         if let Some(info) = info {
             // If it does (and therefore running on a recent version of Windows)
@@ -108,7 +120,7 @@ impl core::convert::From<HRESULT> for Error {
             return Self { code, info: Some(info) };
         }
 
-        if let Ok(info) = unsafe { GetErrorInfo(0) } {
+        if let Ok(info) = GetErrorInfo() {
             let message = unsafe { info.GetDescription().unwrap_or_default() };
             Self::new(code, HSTRING::from_wide(message.as_wide()))
         } else {
@@ -117,19 +129,29 @@ impl core::convert::From<HRESULT> for Error {
     }
 }
 
-impl core::fmt::Debug for Error {
-    fn fmt(&self, fmt: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+impl std::fmt::Debug for Error {
+    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut debug = fmt.debug_struct("Error");
-        debug.field("code", &format_args!("{:#010X}", self.code.0)).field("message", &self.message()).finish()
+        debug.field("code", &self.code).field("message", &self.message()).finish()
     }
 }
 
-impl core::fmt::Display for Error {
-    fn fmt(&self, fmt: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
-        core::write!(fmt, "{}", self.message())
+impl std::fmt::Display for Error {
+    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let message = self.message();
+        if message.is_empty() {
+            std::write!(fmt, "{}", self.code())
+        } else {
+            std::write!(fmt, "{} ({})", self.message(), self.code())
+        }
     }
 }
 
 impl std::error::Error for Error {}
 
-type RoOriginateError = extern "system" fn(code: HRESULT, message: core::mem::ManuallyDrop<HSTRING>) -> BOOL;
+type RoOriginateError = extern "system" fn(code: HRESULT, message: std::mem::ManuallyDrop<HSTRING>) -> i32;
+
+fn GetErrorInfo() -> Result<IErrorInfo> {
+    let mut result = std::mem::MaybeUninit::zeroed();
+    unsafe { bindings::GetErrorInfo(0, result.as_mut_ptr()).from_abi(result) }
+}
