@@ -1,18 +1,18 @@
 use super::*;
 use bindings::*;
-use core::marker::PhantomData;
-use core::sync::atomic::{AtomicPtr, Ordering};
+use std::marker::PhantomData;
+use std::sync::atomic::{AtomicPtr, Ordering};
 
 #[doc(hidden)]
 pub struct FactoryCache<C, I> {
-    shared: AtomicPtr<core::ffi::c_void>,
+    shared: AtomicPtr<std::ffi::c_void>,
     _c: PhantomData<C>,
     _i: PhantomData<I>,
 }
 
 impl<C, I> FactoryCache<C, I> {
     pub const fn new() -> Self {
-        Self { shared: AtomicPtr::new(core::ptr::null_mut()), _c: PhantomData, _i: PhantomData }
+        Self { shared: AtomicPtr::new(std::ptr::null_mut()), _c: PhantomData, _i: PhantomData }
     }
 }
 
@@ -24,7 +24,7 @@ impl<C: RuntimeName, I: Interface> FactoryCache<C, I> {
 
             // If a pointer is found, the cache is primed and we're good to go.
             if !ptr.is_null() {
-                return callback(unsafe { core::mem::transmute(&ptr) });
+                return callback(unsafe { std::mem::transmute(&ptr) });
             }
 
             // Otherwise, we load the factory the usual way.
@@ -32,8 +32,8 @@ impl<C: RuntimeName, I: Interface> FactoryCache<C, I> {
 
             // If the factory is agile, we can safely cache it.
             if factory.cast::<IAgileObject>().is_ok() {
-                if self.shared.compare_exchange_weak(core::ptr::null_mut(), factory.as_raw(), Ordering::Relaxed, Ordering::Relaxed).is_ok() {
-                    core::mem::forget(factory);
+                if self.shared.compare_exchange_weak(std::ptr::null_mut(), factory.as_raw(), Ordering::Relaxed, Ordering::Relaxed).is_ok() {
+                    std::mem::forget(factory);
                 }
             } else {
                 // Otherwise, for non-agile factories we simply use the factory
@@ -45,29 +45,30 @@ impl<C: RuntimeName, I: Interface> FactoryCache<C, I> {
 }
 
 // This is safe because `FactoryCache` only holds agile factory pointers, which are safe to cache and share between threads.
-unsafe impl<C, I> ::core::marker::Sync for FactoryCache<C, I> {}
+unsafe impl<C, I> std::marker::Sync for FactoryCache<C, I> {}
 
-/// Attempts to load the factory interface for the given WinRT class
+/// Attempts to load the factory object for the given WinRT class.
+/// This can be used to access COM interfaces implemented on a Windows Runtime class factory.
 pub fn factory<C: RuntimeName, I: Interface>() -> Result<I> {
     let mut factory: Option<I> = None;
     let name = HSTRING::from(C::NAME);
 
     let code = if let Ok(function) = unsafe { delay_load(s!("combase.dll"), s!("RoGetActivationFactory")) } {
         unsafe {
-            let function: RoGetActivationFactory = core::mem::transmute(function);
-            let mut code = function(core::mem::transmute_copy(&name), &I::IID, &mut factory as *mut _ as *mut _);
+            let function: RoGetActivationFactory = std::mem::transmute(function);
+            let mut code = function(std::mem::transmute_copy(&name), &I::IID, &mut factory as *mut _ as *mut _);
 
             // If RoGetActivationFactory fails because combase hasn't been loaded yet then load combase
             // automatically so that it "just works" for apartment-agnostic code.
             if code == CO_E_NOTINITIALIZED {
                 if let Ok(mta) = delay_load(s!("ole32.dll"), s!("CoIncrementMTAUsage")) {
-                    let mta: CoIncrementMTAUsage = core::mem::transmute(mta);
-                    let mut cookie = core::ptr::null_mut();
+                    let mta: CoIncrementMTAUsage = std::mem::transmute(mta);
+                    let mut cookie = std::ptr::null_mut();
                     let _ = mta(&mut cookie);
                 }
 
                 // Now try a second time to get the activation factory via the OS.
-                code = function(core::mem::transmute_copy(&name), &I::IID, &mut factory as *mut _ as *mut _);
+                code = function(std::mem::transmute_copy(&name), &I::IID, &mut factory as *mut _ as *mut _);
             }
 
             code
@@ -121,14 +122,14 @@ where
 
 unsafe fn get_activation_factory(library: PCSTR, name: &HSTRING) -> Result<IGenericFactory> {
     let function = delay_load(library, s!("DllGetActivationFactory"))?;
-    let function: DllGetActivationFactory = core::mem::transmute(function);
-    let mut abi = core::mem::MaybeUninit::zeroed();
-    function(core::mem::transmute_copy(name), abi.as_mut_ptr()).from_abi(abi)
+    let function: DllGetActivationFactory = std::mem::transmute(function);
+    let mut abi = std::mem::MaybeUninit::zeroed();
+    function(std::mem::transmute_copy(name), abi.as_mut_ptr()).from_abi(abi)
 }
 
-type CoIncrementMTAUsage = extern "system" fn(cookie: *mut *mut core::ffi::c_void) -> HRESULT;
-type RoGetActivationFactory = extern "system" fn(hstring: core::mem::ManuallyDrop<HSTRING>, interface: &GUID, result: *mut *mut core::ffi::c_void) -> HRESULT;
-type DllGetActivationFactory = extern "system" fn(name: core::mem::ManuallyDrop<HSTRING>, factory: *mut *mut core::ffi::c_void) -> HRESULT;
+type CoIncrementMTAUsage = extern "system" fn(cookie: *mut *mut std::ffi::c_void) -> HRESULT;
+type RoGetActivationFactory = extern "system" fn(hstring: std::mem::ManuallyDrop<HSTRING>, interface: &GUID, result: *mut *mut std::ffi::c_void) -> HRESULT;
+type DllGetActivationFactory = extern "system" fn(name: std::mem::ManuallyDrop<HSTRING>, factory: *mut *mut std::ffi::c_void) -> HRESULT;
 
 #[cfg(test)]
 mod tests {
